@@ -25,7 +25,7 @@ class Configure(config.base.Configure):
       - If the path ends in ".lib" return it unchanged
       - If the path is absolute and the filename is "lib"<name>, return -L<dir> -l<name> (optionally including rpath flag)
       - If the filename is "lib"<name>, return -l<name>
-      - If the path ends in ".so" return it unchanged
+      - If the path ends in ".so" or ".dylib" return it unchanged
       - If the path ends in ".o" return it unchanged
       - If the path is absolute, return it unchanged
       - Otherwise return -l<library>'''
@@ -55,7 +55,7 @@ class Configure(config.base.Configure):
         return ['-L'+dirname,'-l'+name]
       else:
         return ['-l'+name]
-    if os.path.splitext(library)[1] == '.so' or os.path.splitext(library)[1] == '.o':
+    if os.path.splitext(library)[1] == '.so' or os.path.splitext(library)[1] == '.o' or os.path.splitext(library)[1] == '.dylib':
       return [library]
     if os.path.isabs(library):
       return [library]
@@ -133,7 +133,7 @@ class Configure(config.base.Configure):
       # remove duplicate -L, -Wl,-rpath options - and only consecutive -l options
       if j in newldflags and any([j.startswith(flg) for flg in dupflags]): continue
       if newlibs and j == newlibs[-1]: continue
-      if j.startswith('-l') or j.endswith('.lib') or j.endswith('.a') or j.endswith('.o') or j == '-Wl,-Bstatic' or j == '-Wl,-Bdynamic' or j == '-Wl,--start-group' or j == '-Wl,--end-group':
+      if list(filter(j.startswith,['-l'])) or list(filter(j.endswith,['.lib','.a','.so','.o'])) or j in ['-Wl,-Bstatic','-Wl,-Bdynamic','-Wl,--start-group','-Wl,--end-group']:
         newlibs.append(j)
       else:
         newldflags.append(j)
@@ -254,13 +254,17 @@ extern "C" {
             break
 
     if found and self.checkLink(includes, body, linkLanguage=linklang, examineOutput=examineOutput):
-      # define the symbol as found
-      if functionDefine: [self.addDefine(self.getDefineNameFunc(fname), 1) for f, fname in enumerate(funcs)]
-      # add to list of found libraries
-      elif libName:
-        for lib in libName:
-          shortlib = self.getShortLibName(lib)
-          if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
+      if hasattr(self.compilers, 'FC') and self.language[-1] == 'C':
+        if self.compilers.checkCrossLink(includes+'\nvoid dummy(void) {'+body+'}\n',"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C',language2='FC'):
+          # define the symbol as found
+          if functionDefine: [self.addDefine(self.getDefineNameFunc(fname), 1) for f, fname in enumerate(funcs)]
+          # add to list of found libraries
+          elif libName:
+            for lib in libName:
+              shortlib = self.getShortLibName(lib)
+              if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
+        else:
+          found = 0
     else:
       found = 0
     self.setCompilers.LIBS = oldLibs
