@@ -10,7 +10,7 @@ class Configure(config.package.GNUPackage):
     self.liblist          = [['libadolc.a']]
     self.functions        = ['myalloc2','myfree2']
     self.cxx              = 1
-    self.requirescxx11    = 1
+    self.minCxxVersion    = 'c++11'
     self.precisions       = ['double']
     self.complex          = 0
     self.downloaddirnames = ['ADOL-C']
