@@ -8,7 +8,7 @@ class Configure(config.package.Package):
     self.includes      = ['codi/adjointInterface.hpp']
     self.liblist       = []
     self.cxx           = 1
-    self.requirescxx11 = 1
+    self.minCxxVersion = 'c++11'
     return
 
   def setupDependencies(self, framework):
@@ -19,10 +19,9 @@ class Configure(config.package.Package):
     import os
 
     self.logPrintBox('Copying CoDiPack include files to install location')
-    self.installDirProvider.printSudoPasswordMessage()
     includedir = os.path.join(self.installDir, 'include')
     output2,err2,ret2  = config.package.Package.executeShellCommandSeq([
-      self.withSudo('mkdir', '-p', includedir),
-      self.withSudo('cp', '-rf', os.path.join('include', 'codi'), os.path.join('include', 'codi.hpp'), includedir),
+      ['mkdir', '-p', includedir],
+      ['cp', '-rf', os.path.join('include', 'codi'), os.path.join('include', 'codi.hpp'), includedir],
       ], cwd=self.packageDir, timeout=250, log = self.log)
     return self.installDir
