@@ -4,29 +4,37 @@ import os
 class Configure(config.package.CMakePackage):
   def __init__(self, framework):
     config.package.CMakePackage.__init__(self, framework)
-    self.gitcommit        = '3.2.00'
+    self.gitcommit        = '54e4213ca028163a76639d23b1204b213203bc79' # develop of 2021-04-28
     self.versionname      = 'KOKKOS_KERNELS_VERSION'  # It looks kokkos-kernels does not yet have a macro for version number
     self.download         = ['git://https://github.com/kokkos/kokkos-kernels.git']
+    # See also kokkos.py. Cannot test includes with standard approaches since that requires Kokkos nvcc_wapper that we do not handle in configure
+    self.doNotCheckIncludes = 1
     self.includes         = ['KokkosBlas.hpp','KokkosSparse_CrsMatrix.hpp']
     self.liblist          = [['libkokkoskernels.a']]
     self.functions        = ['']
     # I don't know how to make it work since all KK routines are templated and always need Kokkos::View. So I cheat here and use functionCxx from Kokkos.
     self.functionsCxx     = [1,'namespace Kokkos {void initialize(int&,char*[]);}','int one = 1;char* args[1];Kokkos::initialize(one,args);']
     self.cxx              = 1
-    self.requirescxx11    = 1
     self.downloadonWindows= 0
     self.hastests         = 1
     self.requiresrpath    = 1
     return
 
   def __str__(self):
-    output  = config.package.Package.__str__(self)
+    output  = config.package.CMakePackage.__str__(self)
     if hasattr(self,'system'): output += '  Backend: '+self.system+'\n'
     return output
 
+  def setupHelp(self, help):
+    import nargs
+    config.package.CMakePackage.setupHelp(self, help)
+    help.addArgument('KOKKOS-KERNELS', '-with-kokkos-kernels-tpl=<bool>', nargs.ArgBool(None, 1, 'Indicate if you wish to let Kokkos-Kernels use Third-Party Libraries (TPLs)'))
+    return
+
   def setupDependencies(self, framework):
     config.package.CMakePackage.setupDependencies(self, framework)
     self.externalpackagesdir = framework.require('PETSc.options.externalpackagesdir',self)
+    self.scalarTypes         = framework.require('PETSc.options.scalarTypes',self)
     self.kokkos              = framework.require('config.packages.kokkos',self)
     self.deps                = [self.kokkos]
     self.cuda                = framework.require('config.packages.cuda',self)
@@ -49,26 +57,40 @@ class Configure(config.package.CMakePackage):
 
   def formCMakeConfigureArgs(self):
     args = config.package.CMakePackage.formCMakeConfigureArgs(self)
-    KokkosRoot = self.kokkos.installDir
+    KokkosRoot = self.kokkos.directory
     args.append('-DKokkos_ROOT='+KokkosRoot)
-    # By default it installs in lib64, change it to lib
-    args.append('-DCMAKE_INSTALL_LIBDIR:STRING=lib')
-    if self.cuda.found:
-      self.system = 'CUDA'
-      args.append('-DCMAKE_CXX_COMPILER='+os.path.join(KokkosRoot,'bin','nvcc_wrapper'))
-      # as of version 3.2.00 Cuda 11 is not supported
-      # identifier "cusparseXcsrgemmNnz" is undefined
-      if self.cuda.version_tuple >= (11,0):
-        args.append('-DKokkosKernels_ENABLE_TPL_CUSPARSE=OFF')
+    if self.scalarTypes.scalartype == 'complex':
+      if self.scalarTypes.precision == 'double':
+        args.append('-DKokkosKernels_INST_COMPLEX_DOUBLE=ON')
+      elif self.scalarTypes.precision == 'single':
+        args.append('-DKokkosKernels_INST_COMPLEX_FLOAT=ON')
 
+    # By default it installs in lib64, change it to lib
+    if self.checkSharedLibrariesEnabled():
+      args.append('-DCMAKE_INSTALL_RPATH_USE_LINK_PATH:BOOL=ON')
+      args.append('-DCMAKE_BUILD_WITH_INSTALL_RPATH:BOOL=ON')
+    if self.cuda.found:
+      args = self.rmArgsStartsWith(args,'-DCMAKE_CXX_COMPILER=')
+      args.append('-DCMAKE_CXX_COMPILER='+self.getCompiler('Cxx')) # use the host CXX compiler, let Kokkos handle the nvcc_wrapper business
+      # as of version 3.2.00 Cuda 11 is not supported, e.g., identifier "cusparseXcsrgemmNnz" is undefined
+      if not self.argDB['with-kokkos-kernels-tpl'] or self.cuda.version_tuple >= (11,0):
+        args.append('-DKokkosKernels_ENABLE_TPL_CUBLAS=OFF')
+        args.append('-DKokkosKernels_ENABLE_TPL_CUSPARSE=OFF')
     elif self.hip.found:
       self.system = 'HIP'
-      self.pushLanguage('HIP')
-      petscHipcc = self.getCompiler()
-      self.popLanguage()
-      self.getExecutable(petscHipcc,getFullPath=1,resultName='systemHipcc')
-      if not hasattr(self,'systemHipcc'):
-        raise RuntimeError('HIP error: could not find path of hipcc')
+      with self.Language('HIP'):
+        petscHipc = self.getCompiler()
+        hipFlags = self.updatePackageCxxFlags(self.getCompilerFlags())
+        # kokkos uses clang and offload flag
+        hipFlags = ' '.join([i for i in hipFlags.split() if '--amdgpu-target' not in i])
+      self.getExecutable(petscHipc,getFullPath=1,resultName='systemHipc')
+      if not hasattr(self,'systemHipc'):
+        raise RuntimeError('HIP error: could not find path of hipc')
       args = self.rmArgsStartsWith(args,'-DCMAKE_CXX_COMPILER=')
-      args.append('-DCMAKE_CXX_COMPILER='+self.systemHipcc)
+      args.append('-DCMAKE_CXX_COMPILER='+self.systemHipc)
+      args = self.rmArgsStartsWith(args, '-DCMAKE_CXX_FLAGS')
+      args.append('-DCMAKE_CXX_FLAGS="' + hipFlags + '"')
+
+    # -DCMAKE_CXX_STANDARD= will be taken from Kokkos
+    args = self.rmArgsStartsWith(args,'-DCMAKE_CXX_STANDARD=')
     return args
