@@ -10,12 +10,14 @@ class Configure(config.package.Package):
     self.useddirectly           = 0
     self.linkedbypetsc          = 0
     self.builtafterpetsc        = 1
+    self.PrefixWriteCheck       = 0
     return
 
   def setupHelp(self,help):
     import nargs
     help.addArgument('PETSc', '-with-petsc4py=<bool>', nargs.ArgBool(None, False, 'Build PETSc Python bindings (petsc4py)'))
     help.addArgument('PETSc', '-with-petsc4py-test-np=<np>',nargs.ArgInt(None, None, min=1, help='Number of processes to use for petsc4py tests'))
+    help.addArgument('PETSc', '-with-numpy-include=<dir>', nargs.Arg(None, None, 'Path to numpy headers from numpy.get_include() (default: autodetect)'))
     return
 
   def setupDependencies(self, framework):
@@ -24,6 +26,7 @@ class Configure(config.package.Package):
     self.setCompilers    = framework.require('config.setCompilers',self)
     self.sharedLibraries = framework.require('PETSc.options.sharedLibraries', self)
     self.installdir      = framework.require('PETSc.options.installDir',self)
+    self.mpi             = framework.require('config.packages.MPI',self)
     return
 
   def getDir(self):
@@ -56,6 +59,11 @@ class Configure(config.package.Package):
 
     newdir += 'MPICC=${PCC} '
 
+    # Pass to setup.py if given, otherwise setup.py will autodetect
+    numpy_include = self.argDB.get('with-numpy-include')
+    if numpy_include is not None:
+      newdir += 'NUMPY_INCLUDE="'+numpy_include+'" '
+
     self.addDefine('HAVE_PETSC4PY',1)
     self.addDefine('PETSC4PY_INSTALL_PATH','"'+os.path.join(self.installdir.dir,'lib')+'"')
     self.addMakeMacro('PETSC4PY','yes')
@@ -83,6 +91,8 @@ class Configure(config.package.Package):
                           '@echo "====================================="'])
 
     np = self.make.make_test_np
+    if self.mpi.usingMPIUni:
+      np = 1
     # TODO: some tests currently have issues with np > 4, this should be fixed
     np = min(np,4)
     if 'with-petsc4py-test-np' in self.argDB and self.argDB['with-petsc4py-test-np']:
@@ -90,8 +100,8 @@ class Configure(config.package.Package):
     self.addMakeMacro('PETSC4PY_NP',np)
     self.addMakeRule('petsc4pytest', '',
         ['@echo "*** Testing petsc4py on ${PETSC4PY_NP} processes ***"',
-         '@PYTHONPATH=%s:${PYTHONPATH} ${MPIEXEC} -n ${PETSC4PY_NP} %s %s --verbose' % \
-             (installLibPath, self.python.pyexe, os.path.join(self.packageDir, 'test', 'runtests.py')),
+         '@PYTHONPATH=%s:${PETSC_MPI4PY_PYTHONPATH}:${PYTHONPATH} PETSC_OPTIONS="%s" ${MPIEXEC} -n ${PETSC4PY_NP} %s %s --verbose' % \
+             (installLibPath, '{PETSC_OPTIONS} -check_pointer_intensity 0 -error_output_stdout -malloc_dump ${PETSC_TEST_OPTIONS}', self.python.pyexe, os.path.join(self.packageDir, 'test', 'runtests.py')),
          '@echo "====================================="'])
 
     if self.argDB['prefix'] and not 'package-prefix-hash' in self.argDB:
