@@ -29,18 +29,11 @@ class Configure(config.package.Package):
     #includeDir = self.packageDir
     srcdir     = os.path.join(self.packageDir, 'viennacl')
     destdir    = os.path.join(self.installDir, 'include', 'viennacl')
-    if self.installSudo:
-      self.installDirProvider.printSudoPasswordMessage()
-      try:
-        output,err,ret  = config.package.Package.executeShellCommand(self.installSudo+'mkdir -p '+destdir+' && '+self.installSudo+'rm -rf '+destdir+'  && '+self.installSudo+'cp -rf '+srcdir+' '+destdir, timeout=6000, log = self.log)
-      except RuntimeError as e:
-        raise RuntimeError('Error copying ViennaCL include files from '+os.path.join(self.packageDir, 'ViennaCL')+' to '+packageDir)
-    else:
-      try:
-        if os.path.isdir(destdir): shutil.rmtree(destdir)
-        shutil.copytree(srcdir,destdir)
-      except RuntimeError as e:
-        raise RuntimeError('Error installing ViennaCL include files: '+str(e))
+    try:
+      if os.path.isdir(destdir): shutil.rmtree(destdir)
+      shutil.copytree(srcdir,destdir)
+    except RuntimeError as e:
+      raise RuntimeError('Error installing ViennaCL include files: '+str(e))
     return self.installDir
 
   def configureLibrary(self):
