@@ -2,6 +2,7 @@ from __future__ import generators
 import config.base
 import config
 import os
+import contextlib
 from functools import reduce
 
 # not sure how to handle this with 'self' so its outside the class
@@ -110,14 +111,14 @@ class Configure(config.base.Configure):
     help.addArgument('Compilers', '-CUDAC_LINKER_FLAGS=<string>',        nargs.Arg(None, [], 'Specify the CUDA linker flags'))
 
     help.addArgument('Compilers', '-HIPPP=<prog>', nargs.Arg(None, None, 'Specify the HIP preprocessor'))
-    help.addArgument('Compilers', '-HIPPPFLAGS=<string>', nargs.Arg(None, '-Wno-deprecated-gpu-targets', 'Specify the HIPpreprocessor options'))
+    help.addArgument('Compilers', '-HIPPPFLAGS=<string>', nargs.Arg(None, None, 'Specify the HIP preprocessor options'))
     help.addArgument('Compilers', '-with-hipc=<prog>', nargs.Arg(None, None, 'Specify the HIP compiler'))
     help.addArgument('Compilers', '-HIPC=<prog>',         nargs.Arg(None, None, 'Specify the HIP compiler'))
     help.addArgument('Compilers', '-HIPFLAGS=<string>',   nargs.Arg(None, None, 'Specify the HIP compiler options'))
     help.addArgument('Compilers', '-HIPC_LINKER_FLAGS=<string>',        nargs.Arg(None, [], 'Specify the HIP linker flags'))
 
     help.addArgument('Compilers', '-SYCLPP=<prog>', nargs.Arg(None, None, 'Specify the SYCL preprocessor'))
-    help.addArgument('Compilers', '-SYCLPPFLAGS=<string>', nargs.Arg(None, '-Wno-deprecated-gpu-targets', 'Specify the SYCL preprocessor options'))
+    help.addArgument('Compilers', '-SYCLPPFLAGS=<string>', nargs.Arg(None, None, 'Specify the SYCL preprocessor options'))
     help.addArgument('Compilers', '-with-syclcxx=<prog>', nargs.Arg(None, None, 'Specify the SYCLcompiler'))
     help.addArgument('Compilers', '-SYCLCXX=<prog>',         nargs.Arg(None, None, 'Specify the SYCL compiler'))
     help.addArgument('Compilers', '-SYCLCXXFLAGS=<string>',   nargs.Arg(None, None, 'Specify the SYCL compiler options'))
@@ -154,7 +155,8 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' -V',checkCommand = noCheck, log = log)
       output = output + error
-      if output.find('NAGWare Fortran') >= 0 or output.find('The Numerical Algorithms Group Ltd') >= 0:
+      found = any([s in output for s in ['NAGWare Fortran','The Numerical Algorithms Group Ltd']])
+      if found:
         if log: log.write('Detected NAG Fortran compiler\n')
         return 1
     except RuntimeError:
@@ -191,6 +193,7 @@ class Configure(config.base.Configure):
                                          ]])
               and not any([s in output for s in ['Intel(R)',
                                                  'Unrecognised option --help passed to ld', # NAG f95 compiler
+                                                 'IBM XL', # XL compiler
                                                  ]]))
       if found:
         if log: log.write('Detected GNU compiler\n')
@@ -235,12 +238,24 @@ class Configure(config.base.Configure):
     except RuntimeError:
       pass
 
+  @staticmethod
+  def isNVC(compiler, log):
+    '''Returns true if the compiler is an NVIDIA (former PGI) compiler'''
+    try:
+      (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
+      output = output + error
+      if 'NVIDIA Compilers and Tools' in output:
+        if log: log.write('Detected NVIDIA compiler\n')
+        return 1
+    except RuntimeError:
+      pass
+
   @staticmethod
   def isGcc110plus(compiler, log):
     '''returns true if the compiler is gcc-11.0.x or later'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       strmatch = re.match('gcc\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
@@ -256,7 +271,7 @@ class Configure(config.base.Configure):
     '''returns true if the compiler is gfortran-4.5.x'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       if re.match(r'GNU Fortran \(.*\) (4.5.\d+|4.6.0 20100703)', output):
         if log: log.write('Detected GFortran45x compiler\n')
@@ -269,7 +284,7 @@ class Configure(config.base.Configure):
     '''returns true if the compiler is gfortran-4.6.x or later'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
@@ -285,7 +300,7 @@ class Configure(config.base.Configure):
     '''returns true if the compiler is gfortran-4.7.x or later'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
@@ -301,7 +316,7 @@ class Configure(config.base.Configure):
     '''returns true if the compiler is gfortran-10.0.x or later'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
@@ -317,7 +332,7 @@ class Configure(config.base.Configure):
     '''returns true if the compiler is gfortran-8 or later'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version', log = log)
-      output = output +  error
+      output = output + error
       import re
       strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
@@ -334,9 +349,9 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --help | head -n 20', log = log)
       output = output + error
-      if output.find('Unrecognised option --help passed to ld') >=0:    # NAG f95 compiler
+      if 'Unrecognised option --help passed to ld' in output:    # NAG f95 compiler
         return 0
-      if output.find('http://www.g95.org') >= 0:
+      if 'http://www.g95.org' in output:
         if log: log.write('Detected g95 compiler\n')
         return 1
     except RuntimeError:
@@ -348,9 +363,10 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --help | head -n 20', log = log)
       output = output + error
-      if output.find('Unrecognised option --help passed to ld') >=0:    # NAG f95 compiler
+      if 'Unrecognised option --help passed to ld' in output:    # NAG f95 compiler
         return 0
-      if output.find('Compaq Visual Fortran') >= 0 or output.find('Digital Visual Fortran') >=0 :
+      found = any([s in output for s in ['Compaq Visual Fortran','Digital Visual Fortran']])
+      if found:
         if log: log.write('Detected Compaq Visual Fortran compiler\n')
         return 1
     except RuntimeError:
@@ -362,7 +378,8 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' -V',checkCommand = noCheck, log = log)
       output = output + error
-      if output.find(' Sun ') >= 0:
+      found = any([s in output for s in [' Sun C ',' Sun C++ ', ' Sun Fortran ']])
+      if found:
         if log: log.write('Detected Sun/Oracle compiler\n')
         return 1
     except RuntimeError:
@@ -386,7 +403,7 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --help | head -n 20', log = log)
       output = output + error
-      if output.find('Intel') >= 0:
+      if 'Intel' in output:
         if log: log.write('Detected Intel compiler\n')
         return 1
     except RuntimeError:
@@ -406,12 +423,32 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' -V', log = log)
       output = output + error
-      if output.find('Cray Standard C') >= 0 or output.find('Cray C++') >= 0 or output.find('Cray Fortran') >= 0:
+      found = any([s in output for s in ['Cray C ','Cray Standard C','Cray C++ ','Cray Fortran ']])
+      if found:
         if log: log.write('Detected Cray compiler\n')
         return 1
     except RuntimeError:
       pass
 
+  @staticmethod
+  def isCrayPEWrapper(compiler, log):
+    '''Returns true if the compiler is a Cray Programming Environment (PE) wrapper compiler'''
+    # Note with Cray module PrgEnv-gnu, cc is a Cray PE wrapper around gcc, but not a Cray compiler on its own.
+    try:
+      (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --help', log = log)
+      output = output + error
+      # On OLCF Spock, with PrgEnv-cray
+      #     $ cc --help |& grep "\-craype\-"
+      #     Use --craype-help for CrayPE specific options.
+      # with PrgEnv-gnu, the output is
+      #     -craype-verbose    Print the command which is forwarded
+      #     ...
+      if output.find('-craype-') >= 0:
+        if log: log.write('Detected Cray PE wrapper compiler\n')
+        return 1
+    except RuntimeError:
+      pass
+
   @staticmethod
   def isCrayVector(compiler, log):
     '''Returns true if the compiler is a Cray compiler for a Cray Vector system'''
@@ -432,19 +469,32 @@ class Configure(config.base.Configure):
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(compiler+' -V',checkCommand = noCheck, log = log)
       output = output + error
-      if output.find('The Portland Group') >= 0 or output.find('PGI Compilers and Tools') >= 0:
+      found = any([s in output for s in ['The Portland Group','PGI Compilers and Tools']])
+      if found:
         if log: log.write('Detected PGI compiler\n')
         return 1
     except RuntimeError:
       pass
 
+  @staticmethod
+  def isNEC(compiler, log):
+    '''Returns true if the compiler is a NEC compiler'''
+    try:
+      (output, error, status) = config.base.Configure.executeShellCommand(compiler+' --version',checkCommand = noCheck, log = log)
+      output = output + error
+      if output.find('NEC Corporation') >= 0:
+        if log: log.write('Detected NEC compiler\n')
+        return 1
+    except RuntimeError:
+      pass
+
   @staticmethod
   def isSolarisAR(ar, log):
     '''Returns true AR is solaris'''
     try:
       (output, error, status) = config.base.Configure.executeShellCommand(ar + ' -V',checkCommand = noCheck, log = log)
       output = output + error
-      if output.find('Software Generation Utilities') >= 0:
+      if 'Software Generation Utilities' in output:
         return 1
     except RuntimeError:
       pass
@@ -590,15 +640,20 @@ class Configure(config.base.Configure):
       self.popLanguage()
       raise RuntimeError(msg)
     oldlibs = self.LIBS
-    self.LIBS += ' -lpetsc-ufod4vtr9mqHvKIQiVAm'
-    if self.checkLink(linkLanguage=linkLanguage):
-      msg = language + ' compiler ' + self.getCompiler()+ ''' is broken! It is returning a zero error when the linking failed! Either
+    if linkLanguage: llang = linkLanguage
+    else: llang = language
+    compiler = self.framework.getCompilerObject(llang)
+    if not hasattr(compiler,'linkerrorcodecheck'):
+      self.LIBS += ' -lpetsc-ufod4vtr9mqHvKIQiVAm'
+      if self.checkLink(linkLanguage=linkLanguage):
+        msg = language + ' compiler ' + self.getCompiler()+ ''' is broken! It is returning a zero error when the linking failed! Either
  1) switch to another compiler suite or
  2) report this entire error message to your compiler/linker suite vendor and ask for fix for this issue.'''
-      self.popLanguage()
+        self.popLanguage()
+        self.LIBS = oldlibs
+        raise RuntimeError(msg)
       self.LIBS = oldlibs
-      raise RuntimeError(msg)
-    self.LIBS = oldlibs
+      compiler.linkerrorcodecheck = 1
     if not self.argDB['with-batch']:
       if not self.checkRun(linkLanguage=linkLanguage):
         msg = 'Cannot run executables created with '+language+'. If this machine uses a batch system \nto submit jobs you will need to configure using ./configure with the additional option  --with-batch.\n Otherwise there is problem with the compilers. Can you compile and run code with your compiler \''+ self.getCompiler()+'\'?\n'
@@ -680,6 +735,7 @@ class Configure(config.base.Configure):
       raise RuntimeError('C compiler you provided with -CC='+self.argDB['CC']+' cannot be found or does not work.'+'\n'+self.mesg)
     elif self.useMPICompilers() and 'with-mpi-dir' in self.argDB and os.path.isdir(os.path.join(self.argDB['with-mpi-dir'], 'bin')):
       self.usedMPICompilers = 1
+      yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpincc')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpiicc')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpicc')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpcc')
@@ -708,6 +764,7 @@ class Configure(config.base.Configure):
           if cross_cc:
             delattr(self, 'cross_cc')
             delattr(self, 'cross_LIBS')
+        yield 'mpincc'
         yield 'mpicc'
         yield 'mpiicc'
         yield 'mpcc_r'
@@ -715,6 +772,7 @@ class Configure(config.base.Configure):
         yield 'mpxlc'
         yield 'hcc'
         self.usedMPICompilers = 0
+      yield 'ncc'
       yield 'gcc'
       yield 'clang'
       yield 'icc'
@@ -908,11 +966,28 @@ class Configure(config.base.Configure):
     return
 
   def generateHIPPreprocessorGuesses(self):
-    ''' Placeholder for now '''
+    '''Determines the HIP preprocessor from --with-hipcpp, then HIPPP, then the HIP compiler'''
+    if 'with-hipcpp' in self.argDB:
+      yield self.argDB['with-cudacpp']
+    elif 'HIPPP' in self.argDB:
+      yield self.argDB['HIPPP']
+    else:
+      if hasattr(self, 'HIPC'):
+        yield self.HIPC+' -E'
     return
 
   def checkHIPPreprocessor(self):
-    ''' Placeholder for now '''
+    '''Locate a functional HIP preprocessor'''
+    for compiler in self.generateHIPPreprocessorGuesses():
+      try:
+        if self.getExecutable(compiler, resultName = 'HIPPP'):
+          self.pushLanguage('HIP')
+          if not self.checkPreprocess('#include <stdlib.h>\n__global__ void testFunction() {return;};'):
+            raise RuntimeError('Cannot preprocess HIP with '+self.HIPPP+'.')
+          self.popLanguage()
+          return
+      except RuntimeError as e:
+        self.popLanguage()
     return
 
   def generateSYCLCompilerGuesses(self):
@@ -990,6 +1065,7 @@ class Configure(config.base.Configure):
         yield self.argDB['CXX']
       raise RuntimeError('C++ compiler you provided with -CXX='+self.argDB['CXX']+' cannot be found or does not work.'+'\n'+self.mesg)
     elif self.usedMPICompilers and 'with-mpi-dir' in self.argDB and os.path.isdir(os.path.join(self.argDB['with-mpi-dir'], 'bin')):
+      yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpinc++')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpiicpc')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpicxx')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'hcp')
@@ -1008,6 +1084,7 @@ class Configure(config.base.Configure):
             self.log.write('Cray system using C++ cross compiler:'+cross_CC+'\n')
           yield 'CC'
           if cross_CC: delattr(self, 'cross_CC')
+        yield 'mpinc++'
         yield 'mpicxx'
         yield 'mpiicpc'
         yield 'mpCC_r'
@@ -1029,6 +1106,8 @@ class Configure(config.base.Configure):
           yield 'icpc'
         elif self.CC == 'xlc':
           yield 'xlC'
+        elif self.CC == 'ncc':
+          yield 'nc++'
         yield 'g++'
         yield 'clang++'
         yield 'c++'
@@ -1130,6 +1209,7 @@ class Configure(config.base.Configure):
       yield self.argDB['FC']
       raise RuntimeError('Fortran compiler you provided with -FC='+self.argDB['FC']+' cannot be found or does not work.'+'\n'+self.mesg)
     elif self.usedMPICompilers and 'with-mpi-dir' in self.argDB and os.path.isdir(os.path.join(self.argDB['with-mpi-dir'], 'bin')):
+      yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpinfort')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpiifort')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpif90')
       yield os.path.join(self.argDB['with-mpi-dir'], 'bin', 'mpf90')
@@ -1149,6 +1229,7 @@ class Configure(config.base.Configure):
             self.log.write('Cray system using Fortran cross compiler:'+cross_fc+'\n')
           yield 'ftn'
           if cross_fc: delattr(self, 'cross_fc')
+        yield 'mpinfort'
         yield 'mpif90'
         yield 'mpiifort'
         yield 'mpxlf_r'
@@ -1165,6 +1246,8 @@ class Configure(config.base.Configure):
         elif self.CC == 'xlc':
           yield 'xlf90'
           yield 'xlf'
+        elif self.CC == 'ncc':
+          yield 'nfort'
         elif self.CC.find('win32fe cl') >= 0:
           yield 'win32fe f90'
           yield 'win32fe ifc'
@@ -1255,23 +1338,17 @@ class Configure(config.base.Configure):
 
   def containsInvalidFlag(self, output):
     '''If the output contains evidence that an invalid flag was used, return True'''
-    if (output.find('Unrecognized command line option') >= 0 or output.find('Unrecognised command line option') >= 0 or
-        output.find('unrecognized command line option') >= 0 or output.find('unrecognized option') >= 0 or output.find('unrecognised option') >= 0 or
-        output.find('not recognized') >= 0 or output.find('not recognised') >= 0 or
-        output.find('unknown option') >= 0 or output.find('unknown flag') >= 0 or output.find('Unknown switch') >= 0 or
-        output.find('ignoring option') >= 0 or output.find('ignored') >= 0 or
-        output.find('argument unused') >= 0 or output.find('not supported') >= 0 or
-        # When checking for the existence of 'attribute'
-        output.find('is unsupported and will be skipped') >= 0 or
-        output.find('illegal option') >= 0 or output.find('Invalid option') >= 0 or
-        (output.find('bad ') >= 0 and output.find(' option') >= 0) or
-        output.find('linker input file unused because linking not done') >= 0 or
-        output.find('PETSc Error') >= 0 or
-        output.find('Unbekannte Option') >= 0 or
-        output.find('warning: // comments are not allowed in this language') >= 0 or
-        output.find('no se reconoce la opci') >= 0) or output.find('non reconnue') >= 0:
-      return 1
-    return 0
+    substrings = ('unrecognized command line option','unrecognised command line option',
+                  'unrecognized option','unrecognised option','not recognized',
+                  'not recognised','unknown option','unknown warning option',
+                  'unknown flag','unknown switch','ignoring option','ignored','argument unused',
+                  'not supported','is unsupported and will be skipped','illegal option',
+                  'invalid option','invalid suboption','bad ',' option','petsc error',
+                  'unbekannte option','linker input file unused because linking not done',
+                  'warning: // comments are not allowed in this language',
+                  'no se reconoce la opci','non reconnue')
+    outlo = output.lower()
+    return any(sub.lower() in outlo for sub in substrings)
 
   def checkCompilerFlag(self, flag, includes = '', body = '', compilerOnly = 0):
     '''Determine whether the compiler accepts the given flag'''
@@ -1279,21 +1356,17 @@ class Configure(config.base.Configure):
     oldFlags = getattr(self, flagsArg)
     setattr(self, flagsArg, oldFlags+' '+flag)
     (output, error, status) = self.outputCompile(includes, body)
-    output += error
+    output = self.filterCompileOutput(output+'\n'+error)
     self.logPrint('Output from compiling with '+oldFlags+' '+flag+'\n'+output)
-    valid   = 1
     setattr(self, flagsArg, oldFlags)
     # Please comment each entry and provide an example line
     if status:
-      valid = 0
       self.logPrint('Rejecting compiler flag '+flag+' due to nonzero status from link')
-    # Lahaye F95
-    if output.find('Invalid suboption') >= 0:
-      valid = 0
-    if self.containsInvalidFlag(output):
-      valid = 0
+      return False
+    elif self.containsInvalidFlag(output):
       self.logPrint('Rejecting compiler flag '+flag+' due to \n'+output)
-    return valid
+      return False
+    return True
 
   def insertCompilerFlag(self, flag, compilerOnly):
     '''DANGEROUS: Put in the compiler flag without checking'''
@@ -1310,14 +1383,54 @@ class Configure(config.base.Configure):
       return
     raise RuntimeError('Bad compiler flag: '+flag)
 
+  @contextlib.contextmanager
+  def extraCompilerFlags(self, extraFlags, lang = None):
+    assert isinstance(extraFlags,(list,tuple)), "extraFlags must be either a list or tuple"
+    if lang:
+      self.pushLanguage(lang)
+    flagsArg  = self.getCompilerFlagsArg()
+    oldCompilerFlags = getattr(self,flagsArg)
+    skipFlags = []
+    try:
+      for i,flag in enumerate(extraFlags):
+        try:
+          self.addCompilerFlag(flag)
+        except RuntimeError:
+          skipFlags.append((i,flag))
+      yield skipFlags
+    finally:
+      # This last finally is a bit of deep magic, it makes it so that if the code in the
+      # resulting yield throws some unrelated exception which is meant to be caught
+      # outside this ctx manager then the flags and languages are still reset
+      if lang:
+        oldLang = self.popLanguage()
+      setattr(self,flagsArg,oldCompilerFlags)
+
+  def checkPragma(self):
+    '''Check for all available applicable languages whether they complain (including warnings!) about potentially unknown pragmas'''
+    usePragma = {}
+    langMap = {'C':'CC','Cxx':'CXX','CUDA':'CUDAC','HIP':'HIPC','SYCL':'SYCLCXX'}
+    for lang in langMap:
+      if hasattr(self,langMap[lang]):
+        usePragma[lang] = False
+    for lang in usePragma.keys():
+      with self.Language(lang):
+        with self.extraCompilerFlags(['-Wunknown-pragmas']) as skipFlags:
+          if not skipFlags:
+            usePragma[lang] = self.checkCompile('#pragma GCC poison TEST')
+    if all(usePragma.values()): self.framework.enablepoison = True
+    return
+
   def generatePICGuesses(self):
     if self.language[-1] == 'CUDA':
       yield '-Xcompiler -fPIC'
       return
     if config.setCompilers.Configure.isGNU(self.getCompiler(), self.log):
       PICFlags = ['-fPIC']
+    elif config.setCompilers.Configure.isIBM(self.getCompiler(), self.log):
+      PICFlags = ['-qPIC']
     else:
-      PICFlags = ['-PIC','-fPIC','-KPIC','-qpic']
+      PICFlags = ['-PIC','-qPIC','-KPIC','-fPIC','-fpic']
     try:
       output = self.executeShellCommand(self.getCompiler() + ' -show', log = self.log)[0]
     except:
@@ -1607,12 +1720,14 @@ class Configure(config.base.Configure):
       yield (self.CC, ['-dynamiclib -single_module', '-undefined dynamic_lookup', '-multiply_defined suppress', '-no_compact_unwind'], 'dylib')
     if hasattr(self, 'CXX') and self.mainLanguage == 'Cxx':
       # C++ compiler default
+      yield (self.CXX, ['-qmkshrobj'], 'so')
       yield (self.CXX, ['-shared'], 'so')
       yield (self.CXX, ['-dynamic'], 'so')
+      yield (self.CC, ['-shared'], 'dll')
     # C compiler default
+    yield (self.CC, ['-qmkshrobj'], 'so')
     yield (self.CC, ['-shared'], 'so')
     yield (self.CC, ['-dynamic'], 'so')
-    yield (self.CC, ['-qmkshrobj'], 'so')
     yield (self.CC, ['-shared'], 'dll')
     # Windows default
     if self.CC.find('win32fe') >=0:
@@ -1711,6 +1826,7 @@ class Configure(config.base.Configure):
 
   def checkLinkerMac(self):
     '''Tests some Apple Mac specific linker flags'''
+    self.addDefine('PETSC_USING_DARWIN', 1)
     langMap = {'C':'CC','FC':'FC','Cxx':'CXX','CUDA':'CUDAC','HIP':'HIPC','SYCL':'SYCLCXX'}
     languages = ['C']
     if hasattr(self, 'CXX'):
@@ -1957,9 +2073,9 @@ if (dlclose(handle)) {
     This usually prevents mpi compilers from being used - so issue a warning'''
 
     if 'with-mpi-dir' in self.argDB and self.argDB['with-mpi-compilers']:
-      optcplrs = [(['with-cc','CC'],['mpiicc','mpicc','mpcc','hcc','mpcc_r']),
-              (['with-fc','FC'],['mpiifort','mpif90','mpxlf95_r','mpxlf90_r','mpxlf_r','mpf90']),
-              (['with-cxx','CXX'],['mpiicpc','mpicxx','hcp','mpic++','mpiCC','mpCC_r'])]
+      optcplrs = [(['with-cc','CC'],['mpincc','mpiicc','mpicc','mpcc','hcc','mpcc_r']),
+              (['with-fc','FC'],['mpinfort','mpiifort','mpif90','mpxlf95_r','mpxlf90_r','mpxlf_r','mpf90']),
+              (['with-cxx','CXX'],['mpinc++','mpiicpc','mpicxx','hcp','mpic++','mpiCC','mpCC_r'])]
       for opts,cplrs in optcplrs:
         for opt in opts:
           if (opt in self.argDB  and self.argDB[opt] != '0'):
@@ -2070,6 +2186,7 @@ if (dlclose(handle)) {
     self.executeTest(self.checkSharedLinkerPaths)
     self.executeTest(self.checkLibC)
     self.executeTest(self.checkDynamicLinker)
+    self.executeTest(self.checkPragma)
     self.executeTest(self.output)
     return
 
