@@ -9,7 +9,7 @@ except ImportError:
 try:
   import urlparse as urlparse_local # novermin
 except ImportError:
-  from urllib import parse as urlparse_local
+  from urllib import parse as urlparse_local # novermin
 import config.base
 import socket
 import shutil
