@@ -10,20 +10,26 @@ if __name__ == '__main__':
   import configure
   configure_options = [
     '--package-prefix-hash='+petsc_hash_pkgs,
-    '--with-cc=/scratch/soft/mpich/bin/mpicc',
-    '--with-cxx=/scratch/soft/mpich/bin/mpicxx',
-    '--with-fc=/scratch/soft/mpich/bin/mpif90',
+    '--with-mpi-dir=/scratch/soft/mpich',
+    '--download-fblaslapack',
+    '--download-cmake',
     'LDFLAGS=-L/opt/rh/devtoolset-7/root/usr/lib/gcc/x86_64-redhat-linux/7/lib -lquadmath',
     'COPTFLAGS=-g -O',
     'FOPTFLAGS=-g -O',
     'CXXOPTFLAGS=-g -O',
+    'HIPOPTFLAGS=-g -O',
     '--with-cuda=0',
     '--with-hip=1',
-    '--with-hipc=hipcc',
+    '--with-hipc=/opt/rocm/bin/hipcc',
     '--with-hip-dir=/opt/rocm',
     '--with-precision=double',
     '--with-clanguage=c',
-    '--download-fblaslapack=1',
+    '--download-kokkos',
+    '--download-kokkos-kernels',
+    '--download-hypre',
+    '--download-hypre-configure-arguments=--enable-unified-memory',
+    '--download-magma',
+    '--with-magma-fortran-bindings=0',
   ]
 
   configure.petsc_configure(configure_options)
