@@ -44,6 +44,7 @@ configure_options = [
   '--download-moab=1',
   '--download-saws',
   '--download-revolve=1',
+  '--download-cams=1',
   '--download-ctetgen=1',
   '--download-tetgen=1',
   '--download-mfem=1',
@@ -56,6 +57,7 @@ configure_options = [
   '--download-parmmg=1',
   '--download-kokkos=1',
   '--download-kokkos-kernels=1',
+  '--download-htool=1',
   ]
 
 if __name__ == '__main__':
