@@ -99,6 +99,10 @@ class generateExamples(Petsc):
     # Set locations to handle movement
     self.inInstallDir=self.getInInstallDir(thisscriptdir)
 
+    # Special configuration for CI testing
+    if self.petsc_arch.find('valgrind') >= 0:
+      self.conf['PETSCTEST_VALGRIND']=1
+
     if self.inInstallDir:
       # Case 2 discussed above
       # set PETSC_ARCH to install directory to allow script to work in both
@@ -380,6 +384,12 @@ class generateExamples(Petsc):
     subst['petsc_index_size']=str(self.conf['PETSC_INDEX_SIZE'])
     subst['petsc_scalar_size']=str(self.conf['PETSC_SCALAR_SIZE'])
 
+    if 'PETSC_OPTIONS' in os.environ:
+      subst['petsc_options']=os.environ['PETSC_OPTIONS']
+    else:
+      subst['petsc_options']=''
+    subst['petsc_test_options']=self.conf['PETSC_TEST_OPTIONS']
+
     #Conf vars
     if self.petsc_arch.find('valgrind')>=0:
       subst['mpiexec']='petsc_mpiexec_valgrind ' + self.conf['MPIEXEC']
@@ -757,7 +767,7 @@ class generateExamples(Petsc):
           testDict['SKIP'].append("Requires DATAFILESPATH")
           continue
         # Defines -- not sure I have comments matching
-        if "define(" in requirement.lower():
+        if "defined(" in requirement.lower():
           reqdef=requirement.split("(")[1].split(")")[0]
           if reqdef in self.conf:
             if isNull:
