@@ -8,15 +8,21 @@
 typedef struct PetscSectionClosurePermKey {
   PetscInt    depth, size;
 } PetscSectionClosurePermKey;
+
 typedef struct {
   PetscInt *perm, *invPerm;
 } PetscSectionClosurePermVal;
-PETSC_STATIC_INLINE PetscHash_t PetscSectionClosurePermHash(PetscSectionClosurePermKey k) {
+
+PETSC_STATIC_INLINE PetscHash_t PetscSectionClosurePermHash(PetscSectionClosurePermKey k)
+{
   return PetscHashCombine(PetscHashInt(k.depth), PetscHashInt(k.size));
 }
-PETSC_STATIC_INLINE int PetscSectionClosurePermEqual(PetscSectionClosurePermKey k1, PetscSectionClosurePermKey k2) {
+
+PETSC_STATIC_INLINE int PetscSectionClosurePermEqual(PetscSectionClosurePermKey k1, PetscSectionClosurePermKey k2)
+{
   return k1.depth == k2.depth && k1.size == k2.size;
 }
+
 static PetscSectionClosurePermVal PetscSectionClosurePermVal_Empty = {NULL, NULL};
 PETSC_HASH_MAP(ClPerm, PetscSectionClosurePermKey, PetscSectionClosurePermVal, PetscSectionClosurePermHash, PetscSectionClosurePermEqual, PetscSectionClosurePermVal_Empty)
 
@@ -25,6 +31,7 @@ struct _p_PetscSection {
   PetscInt                      pStart, pEnd; /* The chart: all points are contained in [pStart, pEnd) */
   IS                            perm;         /* A permutation of [0, pEnd-pStart) */
   PetscBool                     pointMajor;   /* True if the offsets are point major, otherwise they are fieldMajor */
+  PetscBool                     includesConstraints; /* True if constrained dofs are included when computing offsets */
   PetscInt                     *atlasDof;     /* Describes layout of storage, point --> # of values */
   PetscInt                     *atlasOff;     /* Describes layout of storage, point --> offset into storage */
   PetscInt                      maxDof;       /* Maximum dof on any point */
@@ -73,5 +80,8 @@ PETSC_EXTERN PetscErrorCode PetscSectionSetClosurePermutation_Internal(PetscSect
 PETSC_EXTERN PetscErrorCode PetscSectionGetClosurePermutation_Internal(PetscSection, PetscObject, PetscInt, PetscInt, const PetscInt *[]);
 PETSC_EXTERN PetscErrorCode PetscSectionGetClosureInversePermutation_Internal(PetscSection, PetscObject, PetscInt, PetscInt, const PetscInt *[]);
 PETSC_EXTERN PetscErrorCode ISIntersect_Caching_Internal(IS, IS, IS *);
-
+#if defined(PETSC_HAVE_HDF5)
+PETSC_INTERN PetscErrorCode PetscSectionView_HDF5_Internal(PetscSection, PetscViewer);
+PETSC_INTERN PetscErrorCode PetscSectionLoad_HDF5_Internal(PetscSection, PetscViewer);
+#endif
 #endif
