@@ -116,10 +116,10 @@ PETSC_EXTERN PetscErrorCode PetscDTIndexToGradedOrder(PetscInt,PetscInt,PetscInt
 /*MC
    PetscDTFactorial - Approximate n! as a real number
 
-   Input Arguments:
+   Input Parameter:
 .  n - a non-negative integer
 
-   Output Arguments:
+   Output Parameter:
 .  factorial - n!
 
    Level: beginner
@@ -140,10 +140,10 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTFactorial(PetscInt n, PetscReal *facto
 /*MC
    PetscDTFactorialInt - Compute n! as an integer
 
-   Input Arguments:
+   Input Parameter:
 .  n - a non-negative integer
 
-   Output Arguments:
+   Output Parameter:
 .  factorial - n!
 
    Level: beginner
@@ -172,11 +172,11 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTFactorialInt(PetscInt n, PetscInt *fac
 /*MC
    PetscDTBinomial - Approximate the binomial coefficient "n choose k"
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer
 -  k - an integer between 0 and n, inclusive
 
-   Output Arguments:
+   Output Parameter:
 .  binomial - approximation of the binomial coefficient n choose k
 
    Level: beginner
@@ -204,11 +204,11 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTBinomial(PetscInt n, PetscInt k, Petsc
 /*MC
    PetscDTBinomialInt - Compute the binomial coefficient "n choose k"
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer
 -  k - an integer between 0 and n, inclusive
 
-   Output Arguments:
+   Output Parameter:
 .  binomial - the binomial coefficient n choose k
 
    Note: this is limited by integers that can be represented by PetscInt
@@ -248,11 +248,11 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTBinomialInt(PetscInt n, PetscInt k, Pe
    (n - i).  This sequence of n-1 differences [d_0, ..., d_{n-2}] is encoded as the number
    (n-1)! * d_0 + (n-2)! * d_1 + ... + 1! * d_{n-2}.
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer (see note about limits below)
 -  k - an integer in [0, n!)
 
-   Output Arguments:
+   Output Parameters:
 +  perm - the permuted list of the integers [0, ..., n-1]
 -  isOdd - if not NULL, returns wether the permutation used an even or odd number of swaps.
 
@@ -291,11 +291,11 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTEnumPerm(PetscInt n, PetscInt k, Petsc
 /*MC
    PetscDTPermIndex - Encode a permutation of n into an integer in [0, n!).  This inverts PetscDTEnumPerm.
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer (see note about limits below)
 -  perm - the permuted list of the integers [0, ..., n-1]
 
-   Output Arguments:
+   Output Parameters:
 +  k - an integer in [0, n!)
 -  isOdd - if not NULL, returns wether the permutation used an even or odd number of swaps.
 
@@ -339,12 +339,12 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTPermIndex(PetscInt n, const PetscInt *
    PetscDTEnumSubset - Get an ordered subset of the integers [0, ..., n - 1] from its encoding as an integers in [0, n choose k).
    The encoding is in lexicographic order.
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer (see note about limits below)
 .  k - an integer in [0, n]
 -  j - an index in [0, n choose k)
 
-   Output Arguments:
+   Output Parameter:
 .  subset - the jth subset of size k of the integers [0, ..., n - 1]
 
    Note: this is limited by arguments such that n choose k can be represented by PetscInt
@@ -378,12 +378,12 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTEnumSubset(PetscInt n, PetscInt k, Pet
 /*MC
    PetscDTSubsetIndex - Convert an ordered subset of k integers from the set [0, ..., n - 1] to its encoding as an integers in [0, n choose k) in lexicographic order.  This is the inverse of PetscDTEnumSubset.
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer (see note about limits below)
 .  k - an integer in [0, n]
 -  subset - an ordered subset of the integers [0, ..., n - 1]
 
-   Output Arguments:
+   Output Parameter:
 .  index - the rank of the subset in lexicographic order
 
    Note: this is limited by arguments such that n choose k can be represented by PetscInt
@@ -419,12 +419,12 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTSubsetIndex(PetscInt n, PetscInt k, co
 /*MC
    PetscDTEnumSubset - Split the integers [0, ..., n - 1] into two complementary ordered subsets, the first subset of size k and being the jth subset of that size in lexicographic order.
 
-   Input Arguments:
+   Input Parameters:
 +  n - a non-negative integer (see note about limits below)
 .  k - an integer in [0, n]
 -  j - an index in [0, n choose k)
 
-   Output Arguments:
+   Output Parameters:
 +  perm - the jth subset of size k of the integers [0, ..., n - 1], followed by its complementary set.
 -  isOdd - if not NULL, return whether perm is an even or odd permutation.
 
@@ -467,7 +467,7 @@ PETSC_STATIC_INLINE PetscErrorCode PetscDTEnumSplit(PetscInt n, PetscInt k, Pets
 }
 
 struct _p_PetscTabulation {
-  PetscInt    K;    /* Indicates a k-jet, namely tabulated derviatives up to order k */
+  PetscInt    K;    /* Indicates a k-jet, namely tabulated derivatives up to order k */
   PetscInt    Nr;   /* The number of tabulation replicas (often 1) */
   PetscInt    Np;   /* The number of tabulation points in a replica */
   PetscInt    Nb;   /* The number of functions tabulated */
