@@ -68,7 +68,6 @@
 #define PetscStringizeArg(a) #a
 #define PetscStringize(a) PetscStringizeArg(a)
 
-
 /*MC
    SETERRQ - Macro to be called when an error has been detected,
 
@@ -96,7 +95,7 @@
       SETERRQ() may be called from Fortran subroutines but SETERRA() must be called from the
       Fortran main program.
 
-.seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), CHKERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ3(), CHKERRMPI()
+.seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), CHKERRQ(), CHKMEMQ, SETERRA(), SETERRQ1(), SETERRQ2(), SETERRQ3(), CHKERRMPI()
 M*/
 #define SETERRQ(comm,ierr,s) return PetscError(comm,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr,PETSC_ERROR_INITIAL,s)
 
@@ -108,7 +107,6 @@ M*/
 PETSC_EXTERN PetscMPIInt PETSC_MPI_ERROR_CLASS;
 PETSC_EXTERN PetscMPIInt PETSC_MPI_ERROR_CODE;
 
-
 /*MC
    SETERRMPI - Macro to be called when an error has been detected within an MPI callback function
 
@@ -417,6 +415,32 @@ M*/
 M*/
 #define SETERRQ9(comm,ierr,s,a1,a2,a3,a4,a5,a6,a7,a8,a9) return PetscError(comm,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr,PETSC_ERROR_INITIAL,s,a1,a2,a3,a4,a5,a6,a7,a8,a9)
 
+/*MC
+   SETERRA - Fortran-only macro that can be called when an error has been detected from the main program
+
+   Synopsis:
+   #include <petscsys.h>
+   PetscErrorCode SETERRA(MPI_Comm comm,PetscErrorCode ierr,char *message)
+
+   Collective
+
+   Input Parameters:
++  comm - A communicator, so that the error can be collective
+.  ierr - nonzero error code, see the list of standard error codes in include/petscerror.h
+-  message - error message in the printf format
+
+  Level: beginner
+
+   Notes:
+    This should only be used with Fortran. With C/C++, use SETERRQ().
+
+   Fortran Notes:
+      SETERRQ() may be called from Fortran subroutines but SETERRA() must be called from the
+      Fortran main program.
+
+.seealso: SETERRQ(), SETERRABORT(), CHKERRQ(), CHKERRA(), CHKERRABORT()
+M*/
+
 /*MC
    SETERRABORT - Macro that can be called when an error has been detected,
 
@@ -474,10 +498,40 @@ M*/
       CHKERRQ() may be called from Fortran subroutines but CHKERRA() must be called from the
       Fortran main program.
 
-.seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ2()
+.seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ2(), CHKERRA()
 M*/
+#if !defined(PETSC_CLANG_STATIC_ANALYZER)
 #define CHKERRQ(ierr)          do {PetscErrorCode ierr__ = (ierr); if (PetscUnlikely(ierr__)) return PetscError(PETSC_COMM_SELF,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr__,PETSC_ERROR_REPEAT," ");} while (0)
 #define CHKERRV(ierr)          do {PetscErrorCode ierr__ = (ierr); if (PetscUnlikely(ierr__)) {PetscError(PETSC_COMM_SELF,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr__,PETSC_ERROR_REPEAT," ");return;}} while (0)
+#else
+#define CHKERRQ(ierr)
+#define CHKERRV(ierr)
+#endif
+
+/*MC
+   CHKERRA - Fortran-only replacement for CHKERRQ in the main program, which aborts immediately
+
+   Synopsis:
+   #include <petscsys.h>
+   PetscErrorCode CHKERRA(PetscErrorCode ierr)
+
+   Not Collective
+
+   Input Parameters:
+.  ierr - nonzero error code, see the list of standard error codes in include/petscerror.h
+
+  Level: beginner
+
+   Notes:
+      This should only be used with Fortran. With C/C++, use CHKERRQ() in normal usage,
+      or CHKERRABORT() if wanting to abort immediately on error.
+
+   Fortran Notes:
+      CHKERRQ() may be called from Fortran subroutines but CHKERRA() must be called from the
+      Fortran main program.
+
+.seealso: CHKERRQ(), CHKERRABORT(), SETERRA(), SETERRQ(), SETERRABORT()
+M*/
 
 /*MC
    CHKERRABORT - Checks error code returned from PETSc function. If non-zero it aborts immediately.
@@ -495,8 +549,13 @@ M*/
 
 .seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ2(), SETERRABORT(), CHKERRMPI()
 M*/
+#if !defined(PETSC_CLANG_STATIC_ANALYZER)
 #define CHKERRABORT(comm,ierr) do {PetscErrorCode ierr__ = (ierr); if (PetscUnlikely(ierr__)) {PetscError(PETSC_COMM_SELF,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr__,PETSC_ERROR_REPEAT," ");MPI_Abort(comm,ierr);}} while (0)
 #define CHKERRCONTINUE(ierr)   do {PetscErrorCode ierr__ = (ierr); if (PetscUnlikely(ierr__)) {PetscError(PETSC_COMM_SELF,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr__,PETSC_ERROR_REPEAT," ");}} while (0)
+#else
+#define CHKERRABORT(comm,ierr)
+#define CHKERRCONTINUE(ierr)
+#endif
 
 PETSC_EXTERN PetscErrorCode PetscAbortFindSourceFile_Private(const char*,PetscInt*);
 PETSC_EXTERN PetscBool petscwaitonerrorflg;
@@ -559,6 +618,7 @@ M*/
 
 .seealso: CHKERRQ(), PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ2(), SETERRMPI(), SETERRABORT(), CHKERRABORT()
 M*/
+#if !defined(PETSC_CLANG_STATIC_ANALYZER)
 #define CHKERRMPI(ierr) \
 do { \
   PetscErrorCode _7_errorcode = (ierr); \
@@ -569,6 +629,9 @@ do { \
     SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_MPI,"MPI error %d %s",(int)_7_errorcode,_7_errorstring); \
   } \
 } while (0)
+#else
+#define CHKERRMPI(ierr)
+#endif
 
 #ifdef PETSC_CLANGUAGE_CXX
 
@@ -595,27 +658,32 @@ do { \
 .seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKERRQ(), CHKMEMQ
 M*/
 #define CHKERRXX(ierr)  do {if (PetscUnlikely(ierr)) {PetscError(PETSC_COMM_SELF,__LINE__,PETSC_FUNCTION_NAME,__FILE__,ierr,PETSC_ERROR_IN_CXX,0);}} while (0)
-
 #endif
 
-#if defined(PETSC_HAVE_CUDA)
-#include <cusolverDn.h>
-#include <cusolverSp.h>
-PETSC_EXTERN const char* PetscCUSolverGetErrorName(cusolverStatus_t);
-#define CHKERRCUSOLVER(stat)                       \
-  do {                 \
-   if (PetscUnlikely(stat)) { \
-     const char *name = PetscCUSolverGetErrorName(stat);                     \
-     if ((stat == CUSOLVER_STATUS_NOT_INITIALIZED) || (stat == CUSOLVER_STATUS_ALLOC_FAILED) || (stat == CUSOLVER_STATUS_INTERNAL_ERROR)) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_GPU_RESOURCE,"cuSolver error %d (%s). This indicates the GPU has run out resources",(int)stat,name); \
-     else SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_GPU,"cuSolver error %d (%s)",(int)stat,name); \
-   } \
-} while (0)
-#endif
+/*MC
+   CHKERRCXX - Checks C++ function calls and if they throw an exception, catch it and then return a PETSc error code
+
+   Synopsis:
+   #include <petscsys.h>
+   CHKERRCXX(func);
+
+   Not Collective
+
+   Input Parameters:
+.  func - C++ function calls
+
+  Level: beginner
+
+  Notes:
+   For example,
+
+$     void foo(int x) {throw std::runtime_error("error");}
+$     CHKERRCXX(foo(1));
+
+.seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKERRQ(), CHKMEMQ
+M*/
+#define CHKERRCXX(func) do {try {func;} catch (const std::exception& e) { SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"%s", e.what()); }} while (0)
 
-/* TODO: SEK:  Need to figure out the hipsolver issues */
-#if defined(PETSC_HAVE_HIP)
-#define CHKERRHIPSOLVER(err) do {if (PetscUnlikely(err)) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"HIPSOLVER error %d",err);} while (0)
-#endif
 /*MC
    CHKMEMQ - Checks the memory for corruption, calls error handler if any is detected
 
@@ -643,10 +711,14 @@ PETSC_EXTERN const char* PetscCUSolverGetErrorName(cusolverStatus_t);
 .seealso: PetscTraceBackErrorHandler(), PetscPushErrorHandler(), PetscError(), SETERRQ(), CHKMEMQ, SETERRQ1(), SETERRQ2(), SETERRQ3(),
           PetscMallocValidate()
 M*/
+#if !defined(PETSC_CLANG_STATIC_ANALYZER)
 #define CHKMEMQ do {PetscErrorCode _7_ierr = PetscMallocValidate(__LINE__,PETSC_FUNCTION_NAME,__FILE__);CHKERRQ(_7_ierr);} while (0)
 
 #define CHKMEMA PetscMallocValidate(__LINE__,PETSC_FUNCTION_NAME,__FILE__)
-
+#else
+#define CHKMEMQ
+#define CHKMEMA
+#endif
 /*E
   PetscErrorType - passed to the PETSc error handling routines indicating if this is the first or a later call to the error handlers
 
@@ -693,7 +765,7 @@ PETSC_DEPRECATED_FUNCTION("Use PetscSignalSegvCheckPointerOrMpi() (since version
 
     Not Collective
 
-    Input Parameters:
+    Input Parameter:
 .   format - the usual printf() format string
 
    Options Database Keys:
@@ -718,7 +790,6 @@ $     PetscErrorPrintf = PetscErrorPrintfDefault; to turn it back on or you can
     Fortran Note:
     This routine is not supported in Fortran.
 
-
 .seealso: PetscFPrintf(), PetscSynchronizedPrintf(), PetscHelpPrintf(), PetscPrintf(), PetscPushErrorHandler(), PetscVFPrintf(), PetscHelpPrintf()
 M*/
 PETSC_EXTERN PetscErrorCode (*PetscErrorPrintf)(const char[],...);
@@ -733,21 +804,24 @@ PETSC_EXTERN PetscErrorCode PetscDetermineInitialFPTrap(void);
       Allows the code to build a stack frame as it runs
 */
 
+#if defined(PETSC_USE_DEBUG)
 #define PETSCSTACKSIZE 64
-
 typedef struct  {
-  const char      *function[PETSCSTACKSIZE];
-  const char      *file[PETSCSTACKSIZE];
-        int       line[PETSCSTACKSIZE];
-        PetscBool petscroutine[PETSCSTACKSIZE];
-        int       currentsize;
-        int       hotdepth;
+  const char *function[PETSCSTACKSIZE];
+  const char *file[PETSCSTACKSIZE];
+        int  line[PETSCSTACKSIZE];
+        int  petscroutine[PETSCSTACKSIZE]; /* 0 external called from petsc, 1 petsc functions, 2 petsc user functions */
+        int  currentsize;
+        int  hotdepth;
+  PetscBool  check; /* runtime option to check for correct Push/Pop semantics at runtime */
 } PetscStack;
+PETSC_EXTERN PetscStack petscstack;
+#else
+typedef struct {
+  char Silence_empty_struct_has_size_0_in_C_size_1_in_Cpp;
+} PetscStack;
+#endif
 
-PETSC_EXTERN PetscStack *petscstack;
-
-PetscErrorCode  PetscStackCopy(PetscStack*,PetscStack*);
-PetscErrorCode  PetscStackPrint(PetscStack *,FILE*);
 #if defined(PETSC_SERIALIZE_FUNCTIONS)
 #include <petsc/private/petscfptimpl.h>
 /*
@@ -765,47 +839,64 @@ PetscErrorCode  PetscStackPrint(PetscStack *,FILE*);
 #define PetscRegister__FUNCT__()
 #endif
 
+#if !defined(PETSC_CLANG_STATIC_ANALYZER)
 #if defined(PETSC_USE_DEBUG)
-PETSC_STATIC_INLINE PetscBool PetscStackActive(void)
-{
-  return(petscstack ? PETSC_TRUE : PETSC_FALSE);
-}
 
 /* Stack handling is based on the following two "NoCheck" macros.  These should only be called directly by other error
  * handling macros.  We record the line of the call, which may or may not be the location of the definition.  But is at
  * least more useful than "unknown" because it can distinguish multiple calls from the same function.
  */
-
-#define PetscStackPushNoCheck(funct,petsc_routine,hot)                        \
-  do {                                                                        \
-    PetscStackSAWsTakeAccess();                                                \
-    if (petscstack && (petscstack->currentsize < PETSCSTACKSIZE)) {         \
-      petscstack->function[petscstack->currentsize]  = funct;               \
-      petscstack->file[petscstack->currentsize]      = __FILE__;            \
-      petscstack->line[petscstack->currentsize]      = __LINE__;            \
-      petscstack->petscroutine[petscstack->currentsize] = petsc_routine;    \
-      petscstack->currentsize++;                                             \
-    }                                                                         \
-    if (petscstack) {                                                        \
-      petscstack->hotdepth += (hot || petscstack->hotdepth);                \
-    }                                                                         \
-    PetscStackSAWsGrantAccess();                                               \
+#define PetscStackPushNoCheck(funct,petsc_routine,hot) do {             \
+    PetscStackSAWsTakeAccess();                                         \
+    if (petscstack.currentsize < PETSCSTACKSIZE) {                      \
+      petscstack.function[petscstack.currentsize]     = funct;          \
+      petscstack.file[petscstack.currentsize]         = __FILE__;       \
+      petscstack.line[petscstack.currentsize]         = __LINE__;       \
+      petscstack.petscroutine[petscstack.currentsize] = petsc_routine;  \
+    }                                                                   \
+    ++petscstack.currentsize;                                           \
+    petscstack.hotdepth += (hot || petscstack.hotdepth);                \
+    PetscStackSAWsGrantAccess();                                        \
   } while (0)
 
-#define PetscStackPopNoCheck                                            \
-  do {                                                                  \
-    PetscStackSAWsTakeAccess();                                          \
-    if (petscstack && petscstack->currentsize > 0) {                  \
-      petscstack->currentsize--;                                       \
-      petscstack->function[petscstack->currentsize]  = NULL;             \
-      petscstack->file[petscstack->currentsize]      = NULL;             \
-      petscstack->line[petscstack->currentsize]      = 0;             \
-      petscstack->petscroutine[petscstack->currentsize] = PETSC_FALSE;\
+#define PetscStackPopNoCheck(funct)                    do {             \
+    PetscStackSAWsTakeAccess();                                         \
+    if (PetscUnlikely(petscstack.currentsize <= 0)) {                   \
+      if (PetscUnlikely(petscstack.check)) {                            \
+        printf("Invalid stack size %d, pop %s\n",                       \
+               petscstack.currentsize,funct);                           \
+      }                                                                 \
+    } else {                                                            \
+      if (--petscstack.currentsize < PETSCSTACKSIZE) {                  \
+        if (PetscUnlikely(                                              \
+              petscstack.check                                &&        \
+              petscstack.petscroutine[petscstack.currentsize] &&        \
+              (petscstack.function[petscstack.currentsize]    !=        \
+               (const char*)funct))) {                                  \
+          printf("Invalid stack: push from %s, pop from %s\n",          \
+                 petscstack.function[petscstack.currentsize],funct);    \
+        }                                                               \
+        petscstack.function[petscstack.currentsize] = PETSC_NULLPTR;    \
+        petscstack.file[petscstack.currentsize]     = PETSC_NULLPTR;    \
+        petscstack.line[petscstack.currentsize]     = 0;                \
+        petscstack.petscroutine[petscstack.currentsize] = 0;            \
+      }                                                                 \
+      petscstack.hotdepth = PetscMax(petscstack.hotdepth-1,0);          \
     }                                                                   \
-    if (petscstack) {                                                  \
-      petscstack->hotdepth = PetscMax(petscstack->hotdepth-1,0);      \
+    PetscStackSAWsGrantAccess();                                        \
+  } while (0)
+
+#define PetscStackClearTop                             do {             \
+    PetscStackSAWsTakeAccess();                                         \
+    if (petscstack.currentsize > 0 &&                                   \
+        --petscstack.currentsize < PETSCSTACKSIZE) {                    \
+      petscstack.function[petscstack.currentsize]     = PETSC_NULLPTR;  \
+      petscstack.file[petscstack.currentsize]         = PETSC_NULLPTR;  \
+      petscstack.line[petscstack.currentsize]         = 0;              \
+      petscstack.petscroutine[petscstack.currentsize] = 0;              \
     }                                                                   \
-    PetscStackSAWsGrantAccess();                                         \
+    petscstack.hotdepth = PetscMax(petscstack.hotdepth-1,0);            \
+    PetscStackSAWsGrantAccess();                                        \
   } while (0)
 
 /*MC
@@ -835,9 +926,9 @@ PETSC_STATIC_INLINE PetscBool PetscStackActive(void)
 .seealso: PetscFunctionReturn(), PetscFunctionBeginHot(), PetscFunctionBeginUser()
 
 M*/
-#define PetscFunctionBegin do {                                        \
-    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,PETSC_TRUE,PETSC_FALSE); \
-    PetscRegister__FUNCT__();                                          \
+#define PetscFunctionBegin do {                               \
+    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,1,PETSC_FALSE); \
+    PetscRegister__FUNCT__();                                 \
   } while (0)
 
 /*MC
@@ -865,9 +956,9 @@ M*/
 .seealso: PetscFunctionBegin, PetscFunctionReturn()
 
 M*/
-#define PetscFunctionBeginHot do {                                     \
-    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,PETSC_TRUE,PETSC_TRUE);  \
-    PetscRegister__FUNCT__();                                          \
+#define PetscFunctionBeginHot do {                           \
+    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,1,PETSC_TRUE); \
+    PetscRegister__FUNCT__();                                \
   } while (0)
 
 /*MC
@@ -899,23 +990,19 @@ M*/
 .seealso: PetscFunctionReturn(), PetscFunctionBegin, PetscFunctionBeginHot
 
 M*/
-#define PetscFunctionBeginUser                                          \
-  do {                                                                  \
-    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,PETSC_FALSE,PETSC_FALSE); \
-    PetscRegister__FUNCT__();                                           \
+#define PetscFunctionBeginUser do {                           \
+    PetscStackPushNoCheck(PETSC_FUNCTION_NAME,2,PETSC_FALSE); \
+    PetscRegister__FUNCT__();                                 \
   } while (0)
 
-
-#define PetscStackPush(n) \
-  do {                                                                  \
-    PetscStackPushNoCheck(n,PETSC_FALSE,PETSC_FALSE);                   \
-    CHKMEMQ;                                                            \
+#define PetscStackPush(n)       do {        \
+    PetscStackPushNoCheck(n,0,PETSC_FALSE); \
+    CHKMEMQ;                                \
   } while (0)
 
-#define PetscStackPop                           \
-    do {                                        \
-      CHKMEMQ;                                  \
-      PetscStackPopNoCheck;                     \
+#define PetscStackPop           do {             \
+      CHKMEMQ;                                   \
+      PetscStackPopNoCheck(PETSC_FUNCTION_NAME); \
     } while (0)
 
 /*MC
@@ -943,30 +1030,29 @@ M*/
 .seealso: PetscFunctionBegin()
 
 M*/
-#define PetscFunctionReturn(a) \
-  do {                                                                \
-    PetscStackPopNoCheck;                                             \
-    return(a);} while (0)
+#define PetscFunctionReturn(a)    do {          \
+    PetscStackPopNoCheck(PETSC_FUNCTION_NAME);  \
+    return a;                                   \
+  } while (0)
 
-#define PetscFunctionReturnVoid() \
-  do {                                                                \
-    PetscStackPopNoCheck;                                             \
-    return;} while (0)
+#define PetscFunctionReturnVoid() do {          \
+    PetscStackPopNoCheck(PETSC_FUNCTION_NAME);  \
+    return;                                     \
+  } while (0)
+#else /* PETSC_USE_DEBUG */
 
-#else
-
-PETSC_STATIC_INLINE PetscBool PetscStackActive(void) {return PETSC_FALSE;}
-#define PetscStackPushNoCheck(funct,petsc_routine,hot) do {} while (0)
-#define PetscStackPopNoCheck                           do {} while (0)
+#define PetscStackPushNoCheck(funct,petsc_routine,hot)
+#define PetscStackPopNoCheck
+#define PetscStackClearTop
 #define PetscFunctionBegin
 #define PetscFunctionBeginUser
 #define PetscFunctionBeginHot
-#define PetscFunctionReturn(a)    return(a)
+#define PetscFunctionReturn(a)    return a
 #define PetscFunctionReturnVoid() return
 #define PetscStackPop             CHKMEMQ
 #define PetscStackPush(f)         CHKMEMQ
 
-#endif
+#endif /* PETSC_USE_DEBUG */
 
 /*
     PetscStackCall - Calls an external library routine or user function after pushing the name of the routine on the stack.
@@ -979,8 +1065,6 @@ PETSC_STATIC_INLINE PetscBool PetscStackActive(void) {return PETSC_FALSE;}
 
    Developer Note: this is so that when a user or external library routine results in a crash or corrupts memory, they get blamed instead of PETSc.
 
-
-
 */
 #define PetscStackCall(name,routine) do { PetscStackPush(name);routine;PetscStackPop; } while (0)
 
@@ -1005,8 +1089,19 @@ PETSC_STATIC_INLINE PetscBool PetscStackActive(void) {return PETSC_FALSE;}
     if (__ierr) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_LIB,"Error in %s(): error code %d",#func,(int)__ierr); \
   } while (0)
 
-PETSC_EXTERN PetscErrorCode PetscStackCreate(void);
-PETSC_EXTERN PetscErrorCode PetscStackView(FILE*);
-PETSC_EXTERN PetscErrorCode PetscStackDestroy(void);
+#else /* !PETSC_CLANG_STATIC_ANALYZER */
+#define PetscStackPushNoCheck(funct,petsc_routine,hot)
+#define PetscStackPopNoCheck
+#define PetscStackClearTop
+#define PetscFunctionBegin
+#define PetscFunctionBeginUser
+#define PetscFunctionBeginHot
+#define PetscFunctionReturn(a)    return a
+#define PetscFunctionReturnVoid() return
+#define PetscStackPop
+#define PetscStackPush(f)
+#define PetscStackCall(name,routine)
+#define PetscStackCallStandard(name,routine)
+#endif /* !PETSC_CLANG_STATIC_ANALYZER */
 
 #endif
