@@ -25,131 +25,135 @@
     Real number definitions
  */
 #if defined(PETSC_USE_REAL_SINGLE)
-#define PetscSqrtReal(a)    sqrtf(a)
-#define PetscCbrtReal(a)    cbrtf(a)
-#define PetscHypotReal(a,b) hypotf(a,b)
-#define PetscAtan2Real(a,b) atan2f(a,b)
-#define PetscPowReal(a,b)   powf(a,b)
-#define PetscExpReal(a)     expf(a)
-#define PetscLogReal(a)     logf(a)
-#define PetscLog10Real(a)   log10f(a)
-#define PetscLog2Real(a)    log2f(a)
-#define PetscSinReal(a)     sinf(a)
-#define PetscCosReal(a)     cosf(a)
-#define PetscTanReal(a)     tanf(a)
-#define PetscAsinReal(a)    asinf(a)
-#define PetscAcosReal(a)    acosf(a)
-#define PetscAtanReal(a)    atanf(a)
-#define PetscSinhReal(a)    sinhf(a)
-#define PetscCoshReal(a)    coshf(a)
-#define PetscTanhReal(a)    tanhf(a)
-#define PetscAsinhReal(a)   asinhf(a)
-#define PetscAcoshReal(a)   acoshf(a)
-#define PetscAtanhReal(a)   atanhf(a)
-#define PetscCeilReal(a)    ceilf(a)
-#define PetscFloorReal(a)   floorf(a)
-#define PetscFmodReal(a,b)  fmodf(a,b)
-#define PetscTGamma(a)      tgammaf(a)
+#define PetscSqrtReal(a)       sqrtf(a)
+#define PetscCbrtReal(a)       cbrtf(a)
+#define PetscHypotReal(a,b)    hypotf(a,b)
+#define PetscAtan2Real(a,b)    atan2f(a,b)
+#define PetscPowReal(a,b)      powf(a,b)
+#define PetscExpReal(a)        expf(a)
+#define PetscLogReal(a)        logf(a)
+#define PetscLog10Real(a)      log10f(a)
+#define PetscLog2Real(a)       log2f(a)
+#define PetscSinReal(a)        sinf(a)
+#define PetscCosReal(a)        cosf(a)
+#define PetscTanReal(a)        tanf(a)
+#define PetscAsinReal(a)       asinf(a)
+#define PetscAcosReal(a)       acosf(a)
+#define PetscAtanReal(a)       atanf(a)
+#define PetscSinhReal(a)       sinhf(a)
+#define PetscCoshReal(a)       coshf(a)
+#define PetscTanhReal(a)       tanhf(a)
+#define PetscAsinhReal(a)      asinhf(a)
+#define PetscAcoshReal(a)      acoshf(a)
+#define PetscAtanhReal(a)      atanhf(a)
+#define PetscCeilReal(a)       ceilf(a)
+#define PetscFloorReal(a)      floorf(a)
+#define PetscFmodReal(a,b)     fmodf(a,b)
+#define PetscCopysignReal(a,b) copysignf(a,b)
+#define PetscTGamma(a)         tgammaf(a)
 #if defined(PETSC_HAVE_LGAMMA_IS_GAMMA)
-#define PetscLGamma(a)      gammaf(a)
+#define PetscLGamma(a)         gammaf(a)
 #else
-#define PetscLGamma(a)      lgammaf(a)
+#define PetscLGamma(a)         lgammaf(a)
 #endif
 
 #elif defined(PETSC_USE_REAL_DOUBLE)
-#define PetscSqrtReal(a)    sqrt(a)
-#define PetscCbrtReal(a)    cbrt(a)
-#define PetscHypotReal(a,b) hypot(a,b)
-#define PetscAtan2Real(a,b) atan2(a,b)
-#define PetscPowReal(a,b)   pow(a,b)
-#define PetscExpReal(a)     exp(a)
-#define PetscLogReal(a)     log(a)
-#define PetscLog10Real(a)   log10(a)
-#define PetscLog2Real(a)    log2(a)
-#define PetscSinReal(a)     sin(a)
-#define PetscCosReal(a)     cos(a)
-#define PetscTanReal(a)     tan(a)
-#define PetscAsinReal(a)    asin(a)
-#define PetscAcosReal(a)    acos(a)
-#define PetscAtanReal(a)    atan(a)
-#define PetscSinhReal(a)    sinh(a)
-#define PetscCoshReal(a)    cosh(a)
-#define PetscTanhReal(a)    tanh(a)
-#define PetscAsinhReal(a)   asinh(a)
-#define PetscAcoshReal(a)   acosh(a)
-#define PetscAtanhReal(a)   atanh(a)
-#define PetscCeilReal(a)    ceil(a)
-#define PetscFloorReal(a)   floor(a)
-#define PetscFmodReal(a,b)  fmod(a,b)
-#define PetscTGamma(a)      tgamma(a)
+#define PetscSqrtReal(a)       sqrt(a)
+#define PetscCbrtReal(a)       cbrt(a)
+#define PetscHypotReal(a,b)    hypot(a,b)
+#define PetscAtan2Real(a,b)    atan2(a,b)
+#define PetscPowReal(a,b)      pow(a,b)
+#define PetscExpReal(a)        exp(a)
+#define PetscLogReal(a)        log(a)
+#define PetscLog10Real(a)      log10(a)
+#define PetscLog2Real(a)       log2(a)
+#define PetscSinReal(a)        sin(a)
+#define PetscCosReal(a)        cos(a)
+#define PetscTanReal(a)        tan(a)
+#define PetscAsinReal(a)       asin(a)
+#define PetscAcosReal(a)       acos(a)
+#define PetscAtanReal(a)       atan(a)
+#define PetscSinhReal(a)       sinh(a)
+#define PetscCoshReal(a)       cosh(a)
+#define PetscTanhReal(a)       tanh(a)
+#define PetscAsinhReal(a)      asinh(a)
+#define PetscAcoshReal(a)      acosh(a)
+#define PetscAtanhReal(a)      atanh(a)
+#define PetscCeilReal(a)       ceil(a)
+#define PetscFloorReal(a)      floor(a)
+#define PetscFmodReal(a,b)     fmod(a,b)
+#define PetscCopysignReal(a,b) copysign(a,b)
+#define PetscTGamma(a)         tgamma(a)
 #if defined(PETSC_HAVE_LGAMMA_IS_GAMMA)
-#define PetscLGamma(a)      gamma(a)
+#define PetscLGamma(a)         gamma(a)
 #else
-#define PetscLGamma(a)      lgamma(a)
+#define PetscLGamma(a)         lgamma(a)
 #endif
 
 #elif defined(PETSC_USE_REAL___FLOAT128)
-#define PetscSqrtReal(a)    sqrtq(a)
-#define PetscCbrtReal(a)    cbrtq(a)
-#define PetscHypotReal(a,b) hypotq(a,b)
-#define PetscAtan2Real(a,b) atan2q(a,b)
-#define PetscPowReal(a,b)   powq(a,b)
-#define PetscExpReal(a)     expq(a)
-#define PetscLogReal(a)     logq(a)
-#define PetscLog10Real(a)   log10q(a)
-#define PetscLog2Real(a)    log2q(a)
-#define PetscSinReal(a)     sinq(a)
-#define PetscCosReal(a)     cosq(a)
-#define PetscTanReal(a)     tanq(a)
-#define PetscAsinReal(a)    asinq(a)
-#define PetscAcosReal(a)    acosq(a)
-#define PetscAtanReal(a)    atanq(a)
-#define PetscSinhReal(a)    sinhq(a)
-#define PetscCoshReal(a)    coshq(a)
-#define PetscTanhReal(a)    tanhq(a)
-#define PetscAsinhReal(a)   asinhq(a)
-#define PetscAcoshReal(a)   acoshq(a)
-#define PetscAtanhReal(a)   atanhq(a)
-#define PetscCeilReal(a)    ceilq(a)
-#define PetscFloorReal(a)   floorq(a)
-#define PetscFmodReal(a,b)  fmodq(a,b)
-#define PetscTGamma(a)      tgammaq(a)
+#define PetscSqrtReal(a)       sqrtq(a)
+#define PetscCbrtReal(a)       cbrtq(a)
+#define PetscHypotReal(a,b)    hypotq(a,b)
+#define PetscAtan2Real(a,b)    atan2q(a,b)
+#define PetscPowReal(a,b)      powq(a,b)
+#define PetscExpReal(a)        expq(a)
+#define PetscLogReal(a)        logq(a)
+#define PetscLog10Real(a)      log10q(a)
+#define PetscLog2Real(a)       log2q(a)
+#define PetscSinReal(a)        sinq(a)
+#define PetscCosReal(a)        cosq(a)
+#define PetscTanReal(a)        tanq(a)
+#define PetscAsinReal(a)       asinq(a)
+#define PetscAcosReal(a)       acosq(a)
+#define PetscAtanReal(a)       atanq(a)
+#define PetscSinhReal(a)       sinhq(a)
+#define PetscCoshReal(a)       coshq(a)
+#define PetscTanhReal(a)       tanhq(a)
+#define PetscAsinhReal(a)      asinhq(a)
+#define PetscAcoshReal(a)      acoshq(a)
+#define PetscAtanhReal(a)      atanhq(a)
+#define PetscCeilReal(a)       ceilq(a)
+#define PetscFloorReal(a)      floorq(a)
+#define PetscFmodReal(a,b)     fmodq(a,b)
+#define PetscCopysignReal(a,b) copysignq(a,b)
+#define PetscTGamma(a)         tgammaq(a)
 #if defined(PETSC_HAVE_LGAMMA_IS_GAMMA)
-#define PetscLGamma(a)      gammaq(a)
+#define PetscLGamma(a)         gammaq(a)
 #else
-#define PetscLGamma(a)      lgammaq(a)
+#define PetscLGamma(a)         lgammaq(a)
 #endif
 
 #elif defined(PETSC_USE_REAL___FP16)
-#define PetscSqrtReal(a)    sqrtf(a)
-#define PetscCbrtReal(a)    cbrtf(a)
-#define PetscHypotReal(a,b) hypotf(a,b)
-#define PetscAtan2Real(a,b) atan2f(a,b)
-#define PetscPowReal(a,b)   powf(a,b)
-#define PetscExpReal(a)     expf(a)
-#define PetscLogReal(a)     logf(a)
-#define PetscLog10Real(a)   log10f(a)
-#define PetscLog2Real(a)    log2f(a)
-#define PetscSinReal(a)     sinf(a)
-#define PetscCosReal(a)     cosf(a)
-#define PetscTanReal(a)     tanf(a)
-#define PetscAsinReal(a)    asinf(a)
-#define PetscAcosReal(a)    acosf(a)
-#define PetscAtanReal(a)    atanf(a)
-#define PetscSinhReal(a)    sinhf(a)
-#define PetscCoshReal(a)    coshf(a)
-#define PetscTanhReal(a)    tanhf(a)
-#define PetscAsinhReal(a)   asinhf(a)
-#define PetscAcoshReal(a)   acoshf(a)
-#define PetscAtanhReal(a)   atanhf(a)
-#define PetscCeilReal(a)    ceilf(a)
-#define PetscFloorReal(a)   floorf(a)
-#define PetscFmodReal(a,b)  fmodf(a,b)
-#define PetscTGamma(a)      tgammaf(a)
+#define PetscSqrtReal(a)       sqrtf(a)
+#define PetscCbrtReal(a)       cbrtf(a)
+#define PetscHypotReal(a,b)    hypotf(a,b)
+#define PetscAtan2Real(a,b)    atan2f(a,b)
+#define PetscPowReal(a,b)      powf(a,b)
+#define PetscExpReal(a)        expf(a)
+#define PetscLogReal(a)        logf(a)
+#define PetscLog10Real(a)      log10f(a)
+#define PetscLog2Real(a)       log2f(a)
+#define PetscSinReal(a)        sinf(a)
+#define PetscCosReal(a)        cosf(a)
+#define PetscTanReal(a)        tanf(a)
+#define PetscAsinReal(a)       asinf(a)
+#define PetscAcosReal(a)       acosf(a)
+#define PetscAtanReal(a)       atanf(a)
+#define PetscSinhReal(a)       sinhf(a)
+#define PetscCoshReal(a)       coshf(a)
+#define PetscTanhReal(a)       tanhf(a)
+#define PetscAsinhReal(a)      asinhf(a)
+#define PetscAcoshReal(a)      acoshf(a)
+#define PetscAtanhReal(a)      atanhf(a)
+#define PetscCeilReal(a)       ceilf(a)
+#define PetscFloorReal(a)      floorf(a)
+#define PetscFmodReal(a,b)     fmodf(a,b)
+#define PetscCopySignReal(a,b) copysignf(a,b)
+#define PetscTGamma(a)         tgammaf(a)
 #if defined(PETSC_HAVE_LGAMMA_IS_GAMMA)
-#define PetscLGamma(a)      gammaf(a)
+#define PetscLGamma(a)         gammaf(a)
 #else
-#define PetscLGamma(a)      lgammaf(a)
+#define PetscLGamma(a)         lgammaf(a)
 #endif
 
 #endif /* PETSC_USE_REAL_* */
@@ -198,7 +202,7 @@ M*/
     Complex number definitions
  */
 #if defined(PETSC_HAVE_COMPLEX)
-#if defined(__cplusplus)
+#if defined(__cplusplus) && !defined(PETSC_USE_REAL___FLOAT128)
 /* C++ support of complex number */
 
 #define PetscRealPartComplex(a)      (a).real()
@@ -380,7 +384,7 @@ PETSC_EXTERN PetscComplex PETSC_i;
 */
 PETSC_STATIC_INLINE PetscComplex PetscCMPLX(PetscReal x, PetscReal y)
 {
-#if defined(__cplusplus)
+#if defined(__cplusplus) && !defined(PETSC_USE_REAL___FLOAT128)
   return PetscComplex(x,y);
 #elif defined(_Imaginary_I)
   return x + y * _Imaginary_I;
@@ -592,7 +596,7 @@ M*/
 
    Not Collective
 
-   Input Parameter:
+   Input Parameters:
 +  v1 - first value to find minimum of
 -  v2 - second value to find minimum of
 
@@ -615,7 +619,7 @@ M*/
 
    Not Collective
 
-   Input Parameter:
+   Input Parameters:
 +  v1 - first value to find maximum of
 -  v2 - second value to find maximum of
 
@@ -638,7 +642,7 @@ M*/
 
    Not Collective
 
-   Input Parameter:
+   Input Parameters:
 +  x - value to use if within interval [a,b]
 .  a - lower end of interval
 -  b - upper end of interval
@@ -684,7 +688,6 @@ M*/
    Input Parameter:
 .   v1 - the double
 
-
    Level: beginner
 
 .seealso: PetscMax(), PetscMin(), PetscAbsInt(), PetscSqr()
@@ -803,12 +806,22 @@ typedef PetscReal MatReal;
 struct petsc_mpiu_2scalar {PetscScalar a,b;};
 PETSC_EXTERN MPI_Datatype MPIU_2SCALAR PetscAttrMPITypeTagLayoutCompatible(struct petsc_mpiu_2scalar);
 
+/*
+   MPI Datatypes for composite reductions:
+   MPIU_REAL_INT -> struct { PetscReal; PetscInt; }
+   MPIU_SCALAR_INT -> struct { PetscScalar; PetscInt; }
+*/
+PETSC_EXTERN MPI_Datatype MPIU_REAL_INT;
+PETSC_EXTERN MPI_Datatype MPIU_SCALAR_INT;
+
 #if defined(PETSC_USE_64BIT_INDICES)
 struct petsc_mpiu_2int {PetscInt a,b;};
 PETSC_EXTERN MPI_Datatype MPIU_2INT PetscAttrMPITypeTagLayoutCompatible(struct petsc_mpiu_2int);
 #else
 #define MPIU_2INT MPI_2INT
 #endif
+PETSC_EXTERN MPI_Datatype MPI_4INT;
+PETSC_EXTERN MPI_Datatype MPIU_4INT;
 
 PETSC_STATIC_INLINE PetscInt PetscPowInt(PetscInt base,PetscInt power)
 {
@@ -924,6 +937,5 @@ M*/
 M*/
 #define PetscGTE(x,b)  ((x) >= (PetscRealConstant(b)-PETSC_SMALL))
 
-
 PETSC_EXTERN PetscErrorCode PetscLinearRegression(PetscInt,const PetscReal[],const PetscReal[],PetscReal*,PetscReal*);
 #endif
