@@ -1,6 +1,16 @@
 #if !defined(PETSCVEC_KOKKOS_HPP)
 #define PETSCVEC_KOKKOS_HPP
 
+#include <petscconf.h>
+
+#if defined(PETSC_HAVE_KOKKOS)
+  #if defined(petsccomplexlib)
+    #error "Error: You must include petscvec_kokkos.hpp before other petsc headers in this C++ file to use petsc complex with Kokkos"
+  #endif
+
+  #define PETSC_DESIRE_KOKKOS_COMPLEX   1   /* To control the definition of petsccomplexlib in petscsystypes.h */
+#endif
+
 #include <petscvec.h>
 
 #if defined(PETSC_HAVE_KOKKOS)
