@@ -3,18 +3,18 @@
 
 #define PETSC_VERSION_RELEASE    1
 #define PETSC_VERSION_MAJOR      3
-#define PETSC_VERSION_MINOR      15
-#define PETSC_VERSION_SUBMINOR   5
+#define PETSC_VERSION_MINOR      16
+#define PETSC_VERSION_SUBMINOR   6
 #define PETSC_VERSION_PATCH      0
-#define PETSC_RELEASE_DATE       "Mar 30, 2021"
-#define PETSC_VERSION_DATE       "Sep 29, 2021"
+#define PETSC_RELEASE_DATE       "Sep 29, 2021"
+#define PETSC_VERSION_DATE       "Mar 30, 2022"
 
 #if !defined (PETSC_VERSION_GIT)
-#define PETSC_VERSION_GIT        "v3.15.5"
+#define PETSC_VERSION_GIT        "v3.16.6"
 #endif
 
 #if !defined(PETSC_VERSION_DATE_GIT)
-#define PETSC_VERSION_DATE_GIT   "2021-09-29 14:18:19 -0500"
+#define PETSC_VERSION_DATE_GIT   "2022-03-30 19:13:58 -0500"
 #endif
 
 #define PETSC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
