@@ -6,22 +6,22 @@
 #include <petscsys.h>
 
 /*
-* Program: Stream
-* Programmer: Joe R. Zagar
-* Revision: 4.0-BETA, October 24, 1995
-* Original code developed by John D. McCalpin
-*
-* This program measures memory transfer rates in MB/s for simple
-* computational kernels coded in C.  These numbers reveal the quality
-* of code generation for simple uncacheable kernels as well as showing
-* the cost of floating-point operations relative to memory accesses.
-*
-* INSTRUCTIONS:
-*
-*       1) Stream requires a good bit of memory to run.  Adjust the
-*          value of 'N' (below) to give a 'timing calibration' of
-*          at least 20 clock-ticks.  This will provide rate estimates
-*          that should be good to about 5% precision.
+  Program: Stream
+  Programmer: Joe R. Zagar
+  Revision: 4.0-BETA, October 24, 1995
+  Original code developed by John D. McCalpin
+
+  This program measures memory transfer rates in MB/s for simple
+  computational kernels coded in C.  These numbers reveal the quality
+  of code generation for simple uncacheable kernels as well as showing
+  the cost of floating-point operations relative to memory accesses.
+
+  INSTRUCTIONS:
+
+        1) Stream requires a good bit of memory to run.  Adjust the
+           value of 'N' (below) to give a 'timing calibration' of
+           at least 20 clock-ticks.  This will provide rate estimates
+           that should be good to about 5% precision.
 */
 
 # define N      2000000
@@ -29,25 +29,24 @@
 # define OFFSET 0
 
 /*
-*      3) Compile the code with full optimization.  Many compilers
-*         generate unreasonably bad code before the optimizer tightens
-*         things up.  If the results are unreasonably good, on the
-*         other hand, the optimizer might be too smart for me!
-*
-*         Try compiling with:
-*               cc -O stream_d.c second.c -o stream_d -lm
-*
-*         This is known to work on Cray, SGI, IBM, and Sun machines.
-*
-*
-*      4) Mail the results to mccalpin@cs.virginia.edu
-*         Be sure to include:
-*              a) computer hardware model number and software revision
-*              b) the compiler flags
-*              c) all of the output from the test case.
-* Thanks!
-*
-*/
+       3) Compile the code with full optimization.  Many compilers
+          generate unreasonably bad code before the optimizer tightens
+          things up.  If the results are unreasonably good, on the
+          other hand, the optimizer might be too smart for me!
+
+          Try compiling with:
+                cc -O stream_d.c second.c -o stream_d -lm
+
+          This is known to work on Cray, SGI, IBM, and Sun machines.
+
+       4) Mail the results to mccalpin@cs.virginia.edu
+          Be sure to include:
+               a) computer hardware model number and software revision
+               b) the compiler flags
+               c) all of the output from the test case.
+  Thanks!
+
+ */
 
 # define HLINE "-------------------------------------------------------------\n"
 
@@ -91,7 +90,7 @@ int main(int argc,char **args)
     hostname[j] = 0;
   }
   ierr = MPI_Get_processor_name(hostname,&resultlen);if (ierr) return ierr;
-  if (!rank) {
+  if (rank == 0) {
     for (j=1; j<size; j++) {
       ierr = MPI_Recv(hostname,MPI_MAX_PROCESSOR_NAME,MPI_CHAR,j,0,MPI_COMM_WORLD,&status);if (ierr) return ierr;
     }
@@ -102,7 +101,7 @@ int main(int argc,char **args)
 
   /* --- SETUP --- determine precision and check timing --- */
 
-  if (!rank) {
+  if (rank == 0) {
     /*printf(HLINE);
     printf("Array size = %d, Offset = %d\n" , N, OFFSET);
     printf("Total memory required = %.1f MB.\n", (3 * N * BytesPerWord) / 1048576.0);
@@ -122,7 +121,7 @@ int main(int argc,char **args)
     c[j] = 0.0;
   }
 
-  if (!rank) {
+  if (rank == 0) {
     if  ((quantum = checktick()) >= 1) ; /* printf("Your clock granularity/precision appears to be %d microseconds.\n", quantum); */
     else ; /* printf("Your clock granularity appears to be less than one microsecond.\n");*/
   }
@@ -131,7 +130,7 @@ int main(int argc,char **args)
   for (j = 0; j < N; j++) a[j] = 2.0E0 * a[j];
   t = 1.0E6 * (MPI_Wtime() - t);
 
-  if (!rank) {
+  if (rank == 0) {
     /*  printf("Each test below will take on the order of %d microseconds.\n", (int) t);
     printf("   (= %d clock ticks)\n", (int) (t/quantum));
     printf("Increase the size of the arrays if this shows that\n");
@@ -139,7 +138,6 @@ int main(int argc,char **args)
     printf(HLINE);*/
   }
 
-
   /*   --- MAIN LOOP --- repeat test cases NTIMES times --- */
 
   scalar = 3.0;
@@ -181,7 +179,7 @@ int main(int argc,char **args)
   ierr = MPI_Reduce(irate,rate,4,MPI_DOUBLE,MPI_SUM,0,MPI_COMM_WORLD);
   if (ierr) printf("Error calling MPI\n");
 
-  if (!rank) {
+  if (rank == 0) {
     if (size == 1) {
       printf("%d %11.4f   Rate (MB/s)\n",size, rate[3]);
       fd = fopen("flops","w");
@@ -215,10 +213,10 @@ int checktick(void)
   }
 
 /*
-* Determine the minimum difference between these M values.
-* This result will be our estimate (in microseconds) for the
-* clock granularity.
-*/
+  Determine the minimum difference between these M values.
+  This result will be our estimate (in microseconds) for the
+  clock granularity.
+ */
 
   minDelta = 1000000;
   for (i = 1; i < M; i++) {
