@@ -513,7 +513,7 @@ static PetscErrorCode PetscFEOpenCLLogResidual(PetscFE fem, PetscLogDouble time,
   PetscFunctionReturn(0);
 }
 
-static PetscErrorCode PetscFEIntegrateResidual_OpenCL(PetscDS prob, PetscHashFormKey key, PetscInt Ne, PetscFEGeom *cgeom,
+static PetscErrorCode PetscFEIntegrateResidual_OpenCL(PetscDS prob, PetscFormKey key, PetscInt Ne, PetscFEGeom *cgeom,
                                                       const PetscScalar coefficients[], const PetscScalar coefficients_t[], PetscDS probAux, const PetscScalar coefficientsAux[], PetscReal t, PetscScalar elemVec[])
 {
   /* Nbc = batchSize */
@@ -585,7 +585,7 @@ static PetscErrorCode PetscFEIntegrateResidual_OpenCL(PetscDS prob, PetscHashFor
   global_work_size[1] = y * local_work_size[1];
   global_work_size[2] = z * local_work_size[2];
   ierr = PetscInfo7(fem, "GPU layout grid(%d,%d,%d) block(%d,%d,%d) with %d batches\n", x, y, z, local_work_size[0], local_work_size[1], local_work_size[2], N_cb);CHKERRQ(ierr);
-  ierr = PetscInfo2(fem, " N_t: %d, N_cb: %d\n", N_t, N_cb);
+  ierr = PetscInfo2(fem, " N_t: %d, N_cb: %d\n", N_t, N_cb);CHKERRQ(ierr);
   /* Generate code */
   if (probAux) {
     PetscSpace P;
