@@ -1,5 +1,6 @@
 #include <petsc/private/petscfvimpl.h> /*I "petscfv.h" I*/
 #include <petscdmplex.h>
+#include <petscdmplextransform.h>
 #include <petscds.h>
 
 PetscClassId PETSCLIMITER_CLASSID = 0;
@@ -151,7 +152,7 @@ PetscErrorCode  PetscLimiterViewFromOptions(PetscLimiter A,PetscObject obj,const
 
   Collective on lim
 
-  Input Parameter:
+  Input Parameters:
 + lim - the PetscLimiter object to view
 - v   - the viewer
 
@@ -1069,7 +1070,7 @@ PetscErrorCode  PetscFVViewFromOptions(PetscFV A,PetscObject obj,const char name
 
   Collective on fvm
 
-  Input Parameter:
+  Input Parameters:
 + fvm - the PetscFV object to view
 - v   - the viewer
 
@@ -1631,7 +1632,7 @@ PetscErrorCode PetscFVSetDualSpace(PetscFV fvm, PetscDualSpace sp)
 . fvm - The PetscFV object
 
   Output Parameter:
-. T - The basis function values and derviatives at quadrature points
+. T - The basis function values and derivatives at quadrature points
 
   Note:
 $ T->T[0] = B[(p*pdim + i)*Nc + c] is the value at point p for basis function i and component c
@@ -1670,7 +1671,7 @@ PetscErrorCode PetscFVGetCellTabulation(PetscFV fvm, PetscTabulation *T)
 - K       - The order of derivative to tabulate
 
   Output Parameter:
-. T - The basis function values and derviative at tabulation points
+. T - The basis function values and derivative at tabulation points
 
   Note:
 $ T->T[0] = B[(p*pdim + i)*Nc + c] is the value at point p for basis function i and component c
@@ -1753,7 +1754,7 @@ PetscErrorCode PetscFVComputeGradient(PetscFV fvm, PetscInt numFaces, PetscScala
 . uL           - The state from the cell on the left
 - uR           - The state from the cell on the right
 
-  Output Parameter:
+  Output Parameters:
 + fluxL        - the left fluxes for each face
 - fluxR        - the right fluxes for each face
 
@@ -1793,7 +1794,7 @@ PetscErrorCode PetscFVRefine(PetscFV fv, PetscFV *fvRef)
   DM                K, Kref;
   PetscQuadrature   q, qref;
   DMPolytopeType    ct;
-  DMPlexCellRefiner cr;
+  DMPlexTransform   tr;
   PetscReal        *v0;
   PetscReal        *jac, *invjac;
   PetscInt          numComp, numSubelements, s;
@@ -1817,8 +1818,9 @@ PetscErrorCode PetscFVRefine(PetscFV fv, PetscFV *fvRef)
   ierr = PetscFVSetUp(*fvRef);CHKERRQ(ierr);
   /* Create quadrature */
   ierr = DMPlexGetCellType(K, 0, &ct);CHKERRQ(ierr);
-  ierr = DMPlexCellRefinerCreate(K, &cr);CHKERRQ(ierr);
-  ierr = DMPlexCellRefinerGetAffineTransforms(cr, ct, &numSubelements, &v0, &jac, &invjac);CHKERRQ(ierr);
+  ierr = DMPlexTransformCreate(PETSC_COMM_SELF, &tr);CHKERRQ(ierr);
+  ierr = DMPlexTransformSetType(tr, DMPLEXREFINEREGULAR);CHKERRQ(ierr);
+  ierr = DMPlexRefineRegularGetAffineTransforms(tr, ct, &numSubelements, &v0, &jac, &invjac);CHKERRQ(ierr);
   ierr = PetscQuadratureExpandComposite(q, numSubelements, v0, jac, &qref);CHKERRQ(ierr);
   ierr = PetscDualSpaceSimpleSetDimension(Qref, numSubelements);CHKERRQ(ierr);
   for (s = 0; s < numSubelements; ++s) {
@@ -1839,7 +1841,7 @@ PetscErrorCode PetscFVRefine(PetscFV fv, PetscFV *fvRef)
     ierr = PetscQuadratureDestroy(&qs);CHKERRQ(ierr);
   }
   ierr = PetscFVSetQuadrature(*fvRef, qref);CHKERRQ(ierr);
-  ierr = DMPlexCellRefinerDestroy(&cr);CHKERRQ(ierr);
+  ierr = DMPlexTransformDestroy(&tr);CHKERRQ(ierr);
   ierr = PetscQuadratureDestroy(&qref);CHKERRQ(ierr);
   ierr = PetscDualSpaceDestroy(&Qref);CHKERRQ(ierr);
   PetscFunctionReturn(0);
