@@ -455,7 +455,7 @@ static PetscErrorCode DMFieldInitialize_DA(DMField field)
       }
     }
     ierr = VecRestoreArrayRead(coords,&array);CHKERRQ(ierr);
-    ierr = MPIU_Allreduce((PetscReal *) mins,&(dafield->coordRange[0][0]),2*dim,MPIU_REAL,MPI_MIN,PetscObjectComm((PetscObject)dm));CHKERRQ(ierr);
+    ierr = MPIU_Allreduce((PetscReal *) mins,&(dafield->coordRange[0][0]),2*dim,MPIU_REAL,MPI_MIN,PetscObjectComm((PetscObject)dm));CHKERRMPI(ierr);
     for (j = 0; j < dim; j++) {
       dafield->coordRange[j][1] = -dafield->coordRange[j][1];
     }
