@@ -8,10 +8,9 @@
     DMCompositeSetCoupling - Sets user provided routines that compute the coupling between the
       separate components (DMs) in a DMto build the correct matrix nonzero structure.
 
-
     Logically Collective
 
-    Input Parameter:
+    Input Parameters:
 +   dm - the composite object
 -   formcouplelocations - routine to set the nonzero locations in the matrix
 
@@ -151,7 +150,6 @@ PetscErrorCode  DMCompositeGetNumberDM(DM dm,PetscInt *nDM)
   PetscFunctionReturn(0);
 }
 
-
 /*@C
     DMCompositeGetAccess - Allows one to access the individual packed vectors in their global
        representation.
@@ -338,6 +336,7 @@ PetscErrorCode  DMCompositeGetLocalAccessArray(DM dm,Vec pvec,PetscInt nwanted,c
         const PetscScalar *array;
         ierr = VecGetArrayRead(pvec,&array);CHKERRQ(ierr);
         ierr = VecPlaceArray(v,array+nlocal);CHKERRQ(ierr);
+        // this method does not make sense. The local vectors are not updated with a global-to-local and the user can not do it because it is locked
         ierr = VecLockReadPush(v);CHKERRQ(ierr);
         ierr = VecRestoreArrayRead(pvec,&array);CHKERRQ(ierr);
       } else {
@@ -561,7 +560,7 @@ PetscErrorCode  DMCompositeScatter(DM dm,Vec gvec,...)
     if (local) {
       Vec               global;
       const PetscScalar *array;
-      PetscValidHeaderSpecific(local,VEC_CLASSID,cnt);
+      PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(PetscValidHeaderSpecific(local,VEC_CLASSID,cnt));
       ierr = DMGetGlobalVector(next->dm,&global);CHKERRQ(ierr);
       ierr = VecGetArrayRead(gvec,&array);CHKERRQ(ierr);
       ierr = VecPlaceArray(global,array+next->rstart);CHKERRQ(ierr);
@@ -637,7 +636,7 @@ PetscErrorCode  DMCompositeScatterArray(DM dm,Vec gvec,Vec *lvecs)
 
     Collective on dm
 
-    Input Parameter:
+    Input Parameters:
 +    dm - the packer object
 .    gvec - the global vector
 .    imode - INSERT_VALUES or ADD_VALUES
@@ -663,7 +662,7 @@ PetscErrorCode  DMCompositeGather(DM dm,InsertMode imode,Vec gvec,...)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  PetscValidHeaderSpecific(gvec,VEC_CLASSID,2);
+  PetscValidHeaderSpecific(gvec,VEC_CLASSID,3);
   ierr = PetscObjectTypeCompare((PetscObject)dm,DMCOMPOSITE,&flg);CHKERRQ(ierr);
   if (!flg) SETERRQ1(PetscObjectComm((PetscObject)dm),PETSC_ERR_USER,"Not for type %s",((PetscObject)dm)->type_name);
   if (!com->setup) {
@@ -678,7 +677,7 @@ PetscErrorCode  DMCompositeGather(DM dm,InsertMode imode,Vec gvec,...)
     if (local) {
       PetscScalar *array;
       Vec         global;
-      PetscValidHeaderSpecific(local,VEC_CLASSID,cnt);
+      PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(PetscValidHeaderSpecific(local,VEC_CLASSID,cnt));
       ierr = DMGetGlobalVector(next->dm,&global);CHKERRQ(ierr);
       ierr = VecGetArray(gvec,&array);CHKERRQ(ierr);
       ierr = VecPlaceArray(global,array+next->rstart);CHKERRQ(ierr);
@@ -698,7 +697,7 @@ PetscErrorCode  DMCompositeGather(DM dm,InsertMode imode,Vec gvec,...)
 
     Collective on dm
 
-    Input Parameter:
+    Input Parameters:
 +    dm - the packer object
 .    gvec - the global vector
 .    imode - INSERT_VALUES or ADD_VALUES
@@ -723,7 +722,7 @@ PetscErrorCode  DMCompositeGatherArray(DM dm,InsertMode imode,Vec gvec,Vec *lvec
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm,DM_CLASSID,1);
-  PetscValidHeaderSpecific(gvec,VEC_CLASSID,2);
+  PetscValidHeaderSpecific(gvec,VEC_CLASSID,3);
   ierr = PetscObjectTypeCompare((PetscObject)dm,DMCOMPOSITE,&flg);CHKERRQ(ierr);
   if (!flg) SETERRQ1(PetscObjectComm((PetscObject)dm),PETSC_ERR_USER,"Not for type %s",((PetscObject)dm)->type_name);
   if (!com->setup) {
@@ -735,7 +734,7 @@ PetscErrorCode  DMCompositeGatherArray(DM dm,InsertMode imode,Vec gvec,Vec *lvec
     if (lvecs[i]) {
       PetscScalar *array;
       Vec         global;
-      PetscValidHeaderSpecific(lvecs[i],VEC_CLASSID,3);
+      PetscValidHeaderSpecific(lvecs[i],VEC_CLASSID,4);
       ierr = DMGetGlobalVector(next->dm,&global);CHKERRQ(ierr);
       ierr = VecGetArray(gvec,&array);CHKERRQ(ierr);
       ierr = VecPlaceArray(global,array+next->rstart);CHKERRQ(ierr);
@@ -754,7 +753,7 @@ PetscErrorCode  DMCompositeGatherArray(DM dm,InsertMode imode,Vec gvec,Vec *lvec
 
     Collective on dm
 
-    Input Parameter:
+    Input Parameters:
 +    dmc - the DMComposite (packer) object
 -    dm - the DM object
 
@@ -981,10 +980,10 @@ PetscErrorCode  DMCompositeGetISLocalToGlobalMappings(DM dm,ISLocalToGlobalMappi
 
    Not Collective
 
-   Input Arguments:
+   Input Parameter:
 . dm - composite DM
 
-   Output Arguments:
+   Output Parameter:
 . is - array of serial index sets for each each component of the DMComposite
 
    Level: intermediate
@@ -1172,8 +1171,6 @@ PetscErrorCode DMCreateFieldDecomposition_Composite(DM dm, PetscInt *len,char **
   PetscFunctionReturn(0);
 }
 
-
-
 /* -------------------------------------------------------------------------------------*/
 /*@C
     DMCompositeGetLocalVectors - Gets local vectors for each part of a DMComposite.
@@ -1572,7 +1569,6 @@ static PetscErrorCode DMGetLocalToGlobalMapping_Composite(DM dm)
   PetscFunctionReturn(0);
 }
 
-
 PetscErrorCode  DMCreateColoring_Composite(DM dm,ISColoringType ctype,ISColoring *coloring)
 {
   PetscErrorCode  ierr;
@@ -1791,7 +1787,6 @@ PetscErrorCode  DMLocalToLocalEnd_Composite(DM dm,Vec lvec,InsertMode mode,Vec g
 .seealso: DMType, DM, DMDACreate(), DMCreate(), DMSetType(), DMCompositeCreate()
 M*/
 
-
 PETSC_EXTERN PetscErrorCode DMCreate_Composite(DM p)
 {
   PetscErrorCode ierr;
