@@ -80,7 +80,7 @@ static PetscErrorCode DMView_DA_1d(DM da,PetscViewer viewer)
 
     ierr = PetscDrawCollectiveBegin(draw);CHKERRQ(ierr);
     /* first processor draws all node lines */
-    if (!rank) {
+    if (rank == 0) {
       PetscInt xmin_tmp;
       ymin = 0.0; ymax = 0.3;
       for (xmin_tmp=0; xmin_tmp < dd->M; xmin_tmp++) {
@@ -123,7 +123,6 @@ static PetscErrorCode DMView_DA_1d(DM da,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
-
 PetscErrorCode  DMSetUp_DA_1D(DM da)
 {
   DM_DA            *dd   = (DM_DA*)da->data;
@@ -310,7 +309,6 @@ PetscErrorCode  DMSetUp_DA_1D(DM da)
   PetscFunctionReturn(0);
 }
 
-
 /*@C
    DMDACreate1d - Creates an object that will manage the communication of  one-dimensional
    regular array data that is distributed across some processors.
