@@ -1,13 +1,12 @@
 #include <petscsf.h>
 #include <petsc/private/dmdaimpl.h>     /*I  "petscdmda.h"   I*/
 
-
 /*@
   DMDAConvertToCell - Convert (i,j,k) to local cell number
 
   Not Collective
 
-  Input Parameter:
+  Input Parameters:
 + da - the distributed array
 - s - A MatStencil giving (i,j,k)
 
