@@ -12,11 +12,17 @@
 
    Input Parameters:
 +  da - the distributed array
--  x,y,z - the physical coordinates
+.  x  - the first physical coordinate
+.  y  - the second physical coordinate
+-  z  - the third physical coordinate
 
    Output Parameters:
-+   II, JJ, KK - the logical coordinate (-1 on processes that do not contain that point)
--   X, Y, Z, - (optional) the coordinates of the located grid point
++  II - the first logical coordinate (-1 on processes that do not contain that point)
+.  JJ - the second logical coordinate (-1 on processes that do not contain that point)
+.  KK - the third logical coordinate (-1 on processes that do not contain that point)
+.  X  - (optional) the first coordinate of the located grid point
+.  Y  - (optional) the second coordinate of the located grid point
+-  Z  - (optional) the third coordinate of the located grid point
 
    Level: advanced
 
@@ -55,7 +61,7 @@ PetscErrorCode  DMDAGetLogicalCoordinate(DM da,PetscScalar x,PetscScalar y,Petsc
       }
     }
   }
-  ierr = MPIU_Allreduce(&D,&Dv,1,MPIU_REAL,MPIU_MIN,PetscObjectComm((PetscObject)da));CHKERRQ(ierr);
+  ierr = MPIU_Allreduce(&D,&Dv,1,MPIU_REAL,MPIU_MIN,PetscObjectComm((PetscObject)da));CHKERRMPI(ierr);
   if (D != Dv) {
     *II  = -1;
     *JJ  = -1;
@@ -66,7 +72,7 @@ PetscErrorCode  DMDAGetLogicalCoordinate(DM da,PetscScalar x,PetscScalar y,Petsc
     ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)da),&rank);CHKERRMPI(ierr);
     rank++;
   }
-  ierr = MPIU_Allreduce(&rank,&root,1,MPI_INT,MPI_SUM,PetscObjectComm((PetscObject)da));CHKERRQ(ierr);
+  ierr = MPIU_Allreduce(&rank,&root,1,MPI_INT,MPI_SUM,PetscObjectComm((PetscObject)da));CHKERRMPI(ierr);
   root--;
   ierr = MPI_Bcast(X,1,MPIU_SCALAR,root,PetscObjectComm((PetscObject)da));CHKERRMPI(ierr);
   ierr = MPI_Bcast(Y,1,MPIU_SCALAR,root,PetscObjectComm((PetscObject)da));CHKERRMPI(ierr);
@@ -81,7 +87,6 @@ PetscErrorCode  DMDAGetLogicalCoordinate(DM da,PetscScalar x,PetscScalar y,Petsc
 
    Input Parameters:
 +  da - the distributed array
-.  vec - the vector
 .  dir - Cartesian direction, either DM_X, DM_Y, or DM_Z
 -  gp - global grid point number in this direction
 
@@ -109,7 +114,7 @@ PetscErrorCode  DMDAGetRay(DM da,DMDirection dir,PetscInt gp,Vec *newvec,VecScat
   if (da->dim == 3) SETERRQ(PetscObjectComm((PetscObject) da), PETSC_ERR_SUP, "Cannot get slice from 3d DMDA");
   ierr = MPI_Comm_rank(PetscObjectComm((PetscObject) da), &rank);CHKERRMPI(ierr);
   ierr = DMDAGetAO(da, &ao);CHKERRQ(ierr);
-  if (!rank) {
+  if (rank == 0) {
     if (da->dim == 1) {
       if (dir == DM_X) {
         ierr = PetscMalloc1(dd->w, &indices);CHKERRQ(ierr);
@@ -174,7 +179,7 @@ PetscErrorCode  DMDAGetRay(DM da,DMDirection dir,PetscInt gp,Vec *newvec,VecScat
 .  dir - Cartesian direction, either DM_X, DM_Y, or DM_Z
 -  gp - global grid point number in this direction
 
-   Output Parameters:
+   Output Parameter:
 .  comm - new communicator
 
    Level: advanced
@@ -248,7 +253,7 @@ PetscErrorCode  DMDAGetProcessorSubset(DM da,DMDirection dir,PetscInt gp,MPI_Com
 +  da - the distributed array
 -  dir - Cartesian direction, either DM_X, DM_Y, or DM_Z
 
-   Output Parameters:
+   Output Parameter:
 .  subcomm - new communicator
 
    Level: advanced
