@@ -29,7 +29,7 @@ PetscErrorCode DMLabelCreate(MPI_Comm comm, const char name[], DMLabel *label)
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  PetscValidPointer(label,2);
+  PetscValidPointer(label,3);
   ierr = DMInitializePackage();CHKERRQ(ierr);
 
   ierr = PetscHeaderCreate(*label,DMLABEL_CLASSID,"DMLabel","DMLabel","DM",comm,DMLabelDestroy,DMLabelView);CHKERRQ(ierr);
@@ -120,7 +120,7 @@ static PetscErrorCode DMLabelMakeAllValid_Private(DMLabel label)
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  for (v = 0; v < label->numStrata; v++){
+  for (v = 0; v < label->numStrata; v++) {
     ierr = DMLabelMakeValid_Private(label, v);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
@@ -266,7 +266,7 @@ PETSC_STATIC_INLINE PetscErrorCode DMLabelLookupAddStratum(DMLabel label, PetscI
 /*@
   DMLabelAddStratum - Adds a new stratum value in a DMLabel
 
-  Input Parameter:
+  Input Parameters:
 + label - The DMLabel
 - value - The stratum value
 
@@ -290,7 +290,7 @@ PetscErrorCode DMLabelAddStratum(DMLabel label, PetscInt value)
 
   Not collective
 
-  Input Parameter:
+  Input Parameters:
 + label - The DMLabel
 . numStrata - The number of stratum values
 - stratumValues - The stratum values
@@ -354,7 +354,7 @@ PetscErrorCode DMLabelAddStrata(DMLabel label, PetscInt numStrata, const PetscIn
 
   Not collective
 
-  Input Parameter:
+  Input Parameters:
 + label - The DMLabel
 - valueIS - Index set with stratum values
 
@@ -1008,7 +1008,7 @@ PetscErrorCode DMLabelInsertIS(DMLabel label, IS is, PetscInt value)
   Input Parameter:
 . label - the DMLabel
 
-  Output Paramater:
+  Output Parameter:
 . numValues - the number of values
 
   Level: intermediate
@@ -1032,11 +1032,14 @@ PetscErrorCode DMLabelGetNumValues(DMLabel label, PetscInt *numValues)
   Input Parameter:
 . label - the DMLabel
 
-  Output Paramater:
+  Output Parameter:
 . is    - the value IS
 
   Level: intermediate
 
+  Notes:
+  The output IS should be destroyed when no longer needed.
+
 .seealso: DMLabelCreate(), DMLabelGetValue(), DMLabelSetValue(), DMLabelClearValue()
 @*/
 PetscErrorCode DMLabelGetValueIS(DMLabel label, IS *values)
@@ -1050,6 +1053,36 @@ PetscErrorCode DMLabelGetValueIS(DMLabel label, IS *values)
   PetscFunctionReturn(0);
 }
 
+/*@
+  DMLabelGetValueIndex - Get the index of a given value in the list of values for the DMlabel, or -1 if it is not present
+
+  Not collective
+
+  Input Parameters:
++ label - the DMLabel
+- value - the value
+
+  Output Parameter:
+. index - the index of value in the list of values
+
+  Level: intermediate
+
+.seealso: DMLabelGetValueIS(), DMLabelCreate(), DMLabelGetValue(), DMLabelSetValue(), DMLabelClearValue()
+@*/
+PetscErrorCode DMLabelGetValueIndex(DMLabel label, PetscInt value, PetscInt *index)
+{
+  PetscInt v;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(label, DMLABEL_CLASSID, 1);
+  PetscValidPointer(index, 3);
+  /* Do not assume they are sorted */
+  for (v = 0; v < label->numStrata; ++v) if (label->stratumValues[v] == value) break;
+  if (v >= label->numStrata) *index = -1;
+  else                       *index = v;
+  PetscFunctionReturn(0);
+}
+
 /*@
   DMLabelHasStratum - Determine whether points exist with the given value
 
@@ -1059,7 +1092,7 @@ PetscErrorCode DMLabelGetValueIS(DMLabel label, IS *values)
 + label - the DMLabel
 - value - the stratum value
 
-  Output Paramater:
+  Output Parameter:
 . exists - Flag saying whether points exist
 
   Level: intermediate
@@ -1088,7 +1121,7 @@ PetscErrorCode DMLabelHasStratum(DMLabel label, PetscInt value, PetscBool *exist
 + label - the DMLabel
 - value - the stratum value
 
-  Output Paramater:
+  Output Parameter:
 . size - The number of points in the stratum
 
   Level: intermediate
@@ -1120,7 +1153,7 @@ PetscErrorCode DMLabelGetStratumSize(DMLabel label, PetscInt value, PetscInt *si
 + label - the DMLabel
 - value - the stratum value
 
-  Output Paramaters:
+  Output Parameters:
 + start - the smallest point in the stratum
 - end - the largest point in the stratum
 
@@ -1156,7 +1189,7 @@ PetscErrorCode DMLabelGetStratumBounds(DMLabel label, PetscInt value, PetscInt *
 + label - the DMLabel
 - value - the stratum value
 
-  Output Paramater:
+  Output Parameter:
 . points - The stratum points
 
   Level: intermediate
@@ -1306,6 +1339,42 @@ PetscErrorCode DMLabelSetStratumBounds(DMLabel label, PetscInt value, PetscInt p
   PetscFunctionReturn(0);
 }
 
+/*@
+  DMLabelGetStratumPointIndex - Get the index of a point in a given stratum
+
+  Not collective
+
+  Input Parameters:
++ label  - The DMLabel
+. value  - The label value
+- p      - A point with this value
+
+  Output Parameter:
+. index  - The index of this point in the stratum, or -1 if the point is not in the stratum or the stratum does not exist
+
+  Level: intermediate
+
+.seealso: DMLabelGetValueIndex(), DMLabelGetStratumIS(), DMLabelCreate()
+@*/
+PetscErrorCode DMLabelGetStratumPointIndex(DMLabel label, PetscInt value, PetscInt p, PetscInt *index)
+{
+  const PetscInt *indices;
+  PetscInt        v;
+  PetscErrorCode  ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(label, DMLABEL_CLASSID, 1);
+  PetscValidPointer(index, 4);
+  *index = -1;
+  ierr = DMLabelLookupStratum(label, value, &v);CHKERRQ(ierr);
+  if (v < 0) PetscFunctionReturn(0);
+  ierr = DMLabelMakeValid_Private(label, v);CHKERRQ(ierr);
+  ierr = ISGetIndices(label->points[v], &indices);CHKERRQ(ierr);
+  ierr = PetscFindInt(p, label->stratumSizes[v], indices, index);CHKERRQ(ierr);
+  ierr = ISRestoreIndices(label->points[v], &indices);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@
   DMLabelFilter - Remove all points outside of [start, end)
 
@@ -1503,19 +1572,19 @@ PetscErrorCode DMLabelDistribute(DMLabel label, PetscSF sf, DMLabel *labelNew)
   ierr = PetscObjectGetComm((PetscObject)sf, &comm);CHKERRQ(ierr);
   ierr = MPI_Comm_rank(comm, &rank);CHKERRMPI(ierr);
   /* Bcast name */
-  if (!rank) {
+  if (rank == 0) {
     ierr = PetscObjectGetName((PetscObject) label, &lname);CHKERRQ(ierr);
     ierr = PetscStrlen(lname, &len);CHKERRQ(ierr);
   }
   nameSize = len;
   ierr = MPI_Bcast(&nameSize, 1, MPIU_INT, 0, comm);CHKERRMPI(ierr);
   ierr = PetscMalloc1(nameSize+1, &name);CHKERRQ(ierr);
-  if (!rank) {ierr = PetscArraycpy(name, lname, nameSize+1);CHKERRQ(ierr);}
+  if (rank == 0) {ierr = PetscArraycpy(name, lname, nameSize+1);CHKERRQ(ierr);}
   ierr = MPI_Bcast(name, nameSize+1, MPI_CHAR, 0, comm);CHKERRMPI(ierr);
   ierr = DMLabelCreate(PETSC_COMM_SELF, name, labelNew);CHKERRQ(ierr);
   ierr = PetscFree(name);CHKERRQ(ierr);
   /* Bcast defaultValue */
-  if (!rank) (*labelNew)->defaultValue = label->defaultValue;
+  if (rank == 0) (*labelNew)->defaultValue = label->defaultValue;
   ierr = MPI_Bcast(&(*labelNew)->defaultValue, 1, MPIU_INT, 0, comm);CHKERRMPI(ierr);
   /* Distribute stratum values over the SF and get the point mapping on the receiver */
   ierr = DMLabelDistribute_Internal(label, sf, &leafSection, &leafStrata);CHKERRQ(ierr);
@@ -1620,14 +1689,14 @@ PetscErrorCode DMLabelGather(DMLabel label, PetscSF sf, DMLabel *labelNew)
   ierr = MPI_Comm_rank(comm, &rank);CHKERRMPI(ierr);
   ierr = MPI_Comm_size(comm, &size);CHKERRMPI(ierr);
   /* Bcast name */
-  if (!rank) {
+  if (rank == 0) {
     ierr = PetscObjectGetName((PetscObject) label, &lname);CHKERRQ(ierr);
     ierr = PetscStrlen(lname, &len);CHKERRQ(ierr);
   }
   nameSize = len;
   ierr = MPI_Bcast(&nameSize, 1, MPIU_INT, 0, comm);CHKERRMPI(ierr);
   ierr = PetscMalloc1(nameSize+1, &name);CHKERRQ(ierr);
-  if (!rank) {ierr = PetscArraycpy(name, lname, nameSize+1);CHKERRQ(ierr);}
+  if (rank == 0) {ierr = PetscArraycpy(name, lname, nameSize+1);CHKERRQ(ierr);}
   ierr = MPI_Bcast(name, nameSize+1, MPI_CHAR, 0, comm);CHKERRMPI(ierr);
   ierr = DMLabelCreate(PETSC_COMM_SELF, name, labelNew);CHKERRQ(ierr);
   ierr = PetscFree(name);CHKERRQ(ierr);
