@@ -70,7 +70,7 @@ int main(int argc,char *argv[])
 
   ierr = VecGhostGetLocalForm(x,&lf);CHKERRQ(ierr);
   ierr = VecGetSize(lf,&m);CHKERRQ(ierr);
-  if (m != (n+2)*bs) SETERRQ2(PETSC_COMM_SELF,1,"size of local form %D, expected %D",m,(n+2)*bs);
+  if (m != (n+2)*bs) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_SIZ,"size of local form %D, expected %D",m,(n+2)*bs);
   ierr = VecGetArray(lf,&xx);CHKERRQ(ierr);
   for (i=0; i<n; i++) {
     PetscInt        row[2],col[9],im,ip;
@@ -105,7 +105,7 @@ int main(int argc,char *argv[])
       xx[2*i]   = 0.2*PetscExpReal(-PetscSqr(xref)/(2*PetscSqr(sigma)));
       xx[2*i+1] = 0;
       break;
-    default: SETERRQ1(PETSC_COMM_SELF,1,"not implemented for block size %D",bs);
+    default: SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_SUP,"not implemented for block size %D",bs);
     }
   }
   ierr = VecRestoreArray(lf,&xx);CHKERRQ(ierr);
@@ -121,7 +121,7 @@ int main(int argc,char *argv[])
   /* Update the ghosted values, view the result on rank 0. */
   ierr = VecGhostUpdateBegin(b,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
   ierr = VecGhostUpdateEnd(b,INSERT_VALUES,SCATTER_FORWARD);CHKERRQ(ierr);
-  if (!rank) {
+  if (rank == 0) {
     ierr = VecGhostGetLocalForm(b,&lf);CHKERRQ(ierr);
     ierr = PetscViewerASCIIPrintf(PETSC_VIEWER_STDOUT_SELF,"Local form of b on rank 0, last two nodes are ghost nodes\n");CHKERRQ(ierr);
     ierr = VecView(lf,PETSC_VIEWER_STDOUT_SELF);CHKERRQ(ierr);
@@ -136,7 +136,6 @@ int main(int argc,char *argv[])
   return ierr;
 }
 
-
 /*TEST
 
    test:
