@@ -21,7 +21,7 @@ static PetscErrorCode KSPAllocateVectors_FCG(KSP ksp, PetscInt nvecsneeded, Pets
 
   PetscFunctionBegin;
   /* Allocate enough new vectors to add chunksize new vectors, reach nvecsneedtotal, or to reach mmax+1, whichever is smallest */
-  if (fcg->nvecs < PetscMin(fcg->mmax+1,nvecsneeded)){
+  if (fcg->nvecs < PetscMin(fcg->mmax+1,nvecsneeded)) {
     nvecsprev = fcg->nvecs;
     nnewvecs = PetscMin(PetscMax(nvecsneeded-fcg->nvecs,chunksize),fcg->mmax+1-fcg->nvecs);
     ierr = KSPCreateVecs(ksp,nnewvecs,&fcg->pCvecs[fcg->nchunks],0,NULL);CHKERRQ(ierr);
@@ -29,7 +29,7 @@ static PetscErrorCode KSPAllocateVectors_FCG(KSP ksp, PetscInt nvecsneeded, Pets
     ierr = KSPCreateVecs(ksp,nnewvecs,&fcg->pPvecs[fcg->nchunks],0,NULL);CHKERRQ(ierr);
     ierr = PetscLogObjectParents((PetscObject)ksp,nnewvecs,fcg->pPvecs[fcg->nchunks]);CHKERRQ(ierr);
     fcg->nvecs += nnewvecs;
-    for (i=0;i<nnewvecs;++i){
+    for (i=0;i<nnewvecs;++i) {
       fcg->Cvecs[nvecsprev + i] = fcg->pCvecs[fcg->nchunks][i];
       fcg->Pvecs[nvecsprev + i] = fcg->pPvecs[fcg->nchunks][i];
     }
@@ -58,7 +58,7 @@ static PetscErrorCode    KSPSetUp_FCG(KSP ksp)
   ierr = PetscLogObjectMemory((PetscObject)ksp,2*(fcg->mmax+1)*sizeof(Vec*) + 2*(fcg->mmax + 1)*sizeof(Vec**) + (fcg->mmax + 2)*sizeof(PetscInt));CHKERRQ(ierr);
 
   /* If the requested number of preallocated vectors is greater than mmax reduce nprealloc */
-  if (fcg->nprealloc > fcg->mmax+1){
+  if (fcg->nprealloc > fcg->mmax+1) {
     ierr = PetscInfo2(NULL,"Requested nprealloc=%d is greater than m_max+1=%d. Resetting nprealloc = m_max+1.\n",fcg->nprealloc, fcg->mmax+1);CHKERRQ(ierr);
   }
 
@@ -146,7 +146,7 @@ static PetscErrorCode KSPSolve_FCG(KSP ksp)
   if (ksp->reason) PetscFunctionReturn(0);
 
   /* Apply PC if not already done for convergence check */
-  if (ksp->normtype == KSP_NORM_UNPRECONDITIONED || ksp->normtype == KSP_NORM_NONE){
+  if (ksp->normtype == KSP_NORM_UNPRECONDITIONED || ksp->normtype == KSP_NORM_NONE) {
     ierr = KSP_PCApply(ksp,R,Z);CHKERRQ(ierr);               /*   z <- Br         */
   }
 
@@ -163,7 +163,7 @@ static PetscErrorCode KSPSolve_FCG(KSP ksp)
     Ccurr = fcg->Cvecs[idx];
 
     /* number of old directions to orthogonalize against */
-    switch(fcg->truncstrat){
+    switch(fcg->truncstrat) {
       case KSP_FCD_TRUNC_TYPE_STANDARD:
         mi = fcg->mmax;
         break;
@@ -182,19 +182,19 @@ static PetscErrorCode KSPSolve_FCG(KSP ksp)
 
       l = PetscMax(0,i-mi);
       ndots = i-l;
-      if (ndots){
+      if (ndots) {
         PetscInt    j;
         Vec         *Pold,  *Cold;
         PetscScalar *dots;
 
         ierr = PetscMalloc3(ndots,&dots,ndots,&Cold,ndots,&Pold);CHKERRQ(ierr);
-        for (k=l,j=0;j<ndots;++k,++j){
+        for (k=l,j=0;j<ndots;++k,++j) {
           idx = k % (fcg->mmax+1);
           Cold[j] = fcg->Cvecs[idx];
           Pold[j] = fcg->Pvecs[idx];
         }
         ierr = VecXMDot(Z,ndots,Cold,dots);CHKERRQ(ierr);
-        for (k=0;k<ndots;++k){
+        for (k=0;k<ndots;++k) {
           dots[k] = -dots[k];
         }
         ierr = VecMAXPY(Pcurr,ndots,dots,Pold);CHKERRQ(ierr);
@@ -244,7 +244,7 @@ static PetscErrorCode KSPSolve_FCG(KSP ksp)
     if (ksp->reason) break;
 
     /* Apply PC if not already done for convergence check */
-    if (ksp->normtype == KSP_NORM_UNPRECONDITIONED || ksp->normtype == KSP_NORM_NONE){
+    if (ksp->normtype == KSP_NORM_UNPRECONDITIONED || ksp->normtype == KSP_NORM_NONE) {
       ierr = KSP_PCApply(ksp,R,Z);CHKERRQ(ierr);               /*   z <- Br         */
     }
 
@@ -279,8 +279,8 @@ static PetscErrorCode KSPDestroy_FCG(KSP ksp)
   VecDestroyVecs(ksp->nwork,&ksp->work);
 
   /* Destroy P and C vectors and the arrays that manage pointers to them */
-  if (fcg->nvecs){
-    for (i=0;i<fcg->nchunks;++i){
+  if (fcg->nvecs) {
+    for (i=0;i<fcg->nchunks;++i) {
       ierr = VecDestroyVecs(fcg->chunksizes[i],&fcg->pPvecs[i]);CHKERRQ(ierr);
       ierr = VecDestroyVecs(fcg->chunksizes[i],&fcg->pCvecs[i]);CHKERRQ(ierr);
     }
@@ -345,7 +345,7 @@ PetscErrorCode KSPFCGSetMmax(KSP ksp,PetscInt mmax)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  PetscValidLogicalCollectiveEnum(ksp,mmax,2);
+  PetscValidLogicalCollectiveInt(ksp,mmax,2);
   fcg->mmax = mmax;
   PetscFunctionReturn(0);
 }
@@ -403,7 +403,7 @@ PetscErrorCode KSPFCGSetNprealloc(KSP ksp,PetscInt nprealloc)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  PetscValidLogicalCollectiveEnum(ksp,nprealloc,2);
+  PetscValidLogicalCollectiveInt(ksp,nprealloc,2);
   if (nprealloc > fcg->mmax+1) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Cannot preallocate more than m_max+1 vectors");
   fcg->nprealloc = nprealloc;
   PetscFunctionReturn(0);
