@@ -114,6 +114,6 @@ int main(int argc,char **args)
 
     test:
       args: -f ${DATAFILESPATH}/matrices/indefinite/afiro -ksp_rtol 1.e-3
-      requires: datafilespath double !complex !define(PETSC_USE_64BIT_INDICES)
+      requires: datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES)
 
 TEST*/
