@@ -262,7 +262,7 @@ int main(int argc,char **args)
     ierr = PetscViewerPushFormat(viewer, PETSC_VIEWER_ASCII_MATLAB);CHKERRQ(ierr);
     ierr = MatView(Amat,viewer);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
-    ierr = PetscViewerDestroy(&viewer);
+    ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
   }
 
   /* finish KSP/PC setup */
@@ -339,7 +339,6 @@ int main(int argc,char **args)
 
     ierr = MaybeLogStagePop();CHKERRQ(ierr);
 
-
     ierr = VecNorm(bb, NORM_2, &norm2);CHKERRQ(ierr);
 
     ierr = VecDuplicate(xx, &res);CHKERRQ(ierr);
@@ -949,7 +948,6 @@ PetscErrorCode elem_3d_elast_v_25(PetscScalar *dd)
   PetscFunctionReturn(0);
 }
 
-
 /*TEST
 
    test:
