@@ -1,4 +1,3 @@
-
 #include <petsc/private/petscimpl.h>
 #include <petsc/private/matimpl.h>
 #include <petsc/private/pcimpl.h>
@@ -61,19 +60,19 @@ PetscErrorCode PCTelescopeTestValidSubcomm(MPI_Comm comm_f,MPI_Comm comm_c,Petsc
   PetscFunctionBegin;
   if (comm_f == MPI_COMM_NULL) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"comm_f cannot be MPI_COMM_NULL");
 
-  ierr = MPI_Comm_group(comm_f,&group_f);CHKERRQ(ierr);
+  ierr = MPI_Comm_group(comm_f,&group_f);CHKERRMPI(ierr);
   if (comm_c != MPI_COMM_NULL) {
-    ierr = MPI_Comm_group(comm_c,&group_c);CHKERRQ(ierr);
+    ierr = MPI_Comm_group(comm_c,&group_c);CHKERRMPI(ierr);
   }
 
-  ierr = MPI_Comm_size(comm_f,&size_f);CHKERRQ(ierr);
+  ierr = MPI_Comm_size(comm_f,&size_f);CHKERRMPI(ierr);
   if (comm_c != MPI_COMM_NULL) {
-    ierr = MPI_Comm_size(comm_c,&size_c);CHKERRQ(ierr);
+    ierr = MPI_Comm_size(comm_c,&size_c);CHKERRMPI(ierr);
   }
 
   /* check not all comm_c's are NULL */
   size_c_sum = size_c;
-  ierr = MPI_Allreduce(MPI_IN_PLACE,&size_c_sum,1,MPI_INT,MPI_SUM,comm_f);CHKERRQ(ierr);
+  ierr = MPI_Allreduce(MPI_IN_PLACE,&size_c_sum,1,MPI_INT,MPI_SUM,comm_f);CHKERRMPI(ierr);
   if (size_c_sum == 0) valid = 0;
 
   /* check we can map at least 1 rank in comm_c to comm_f */
@@ -100,15 +99,15 @@ PetscErrorCode PCTelescopeTestValidSubcomm(MPI_Comm comm_f,MPI_Comm comm_c,Petsc
   }
   if (count == size_f) valid = 0;
 
-  ierr = MPI_Allreduce(MPI_IN_PLACE,&valid,1,MPIU_INT,MPI_MIN,comm_f);CHKERRQ(ierr);
+  ierr = MPI_Allreduce(MPI_IN_PLACE,&valid,1,MPIU_INT,MPI_MIN,comm_f);CHKERRMPI(ierr);
   if (valid == 1) *isvalid = PETSC_TRUE;
   else *isvalid = PETSC_FALSE;
 
   ierr = PetscFree(ranks_f);CHKERRQ(ierr);
   ierr = PetscFree(ranks_c);CHKERRQ(ierr);
-  ierr = MPI_Group_free(&group_f);CHKERRQ(ierr);
+  ierr = MPI_Group_free(&group_f);CHKERRMPI(ierr);
   if (comm_c != MPI_COMM_NULL) {
-    ierr = MPI_Group_free(&group_c);CHKERRQ(ierr);
+    ierr = MPI_Group_free(&group_c);CHKERRMPI(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -142,6 +141,7 @@ PetscErrorCode PCTelescopeSetUp_default(PC pc,PC_Telescope sred)
   MPI_Comm       comm,subcomm;
   VecScatter     scatter;
   IS             isin;
+  VecType        vectype;
 
   PetscFunctionBegin;
   ierr = PetscInfo(pc,"PCTelescope: setup (default)\n");CHKERRQ(ierr);
@@ -152,6 +152,7 @@ PetscErrorCode PCTelescopeSetUp_default(PC pc,PC_Telescope sred)
   ierr = MatGetSize(B,&M,NULL);CHKERRQ(ierr);
   ierr = MatGetBlockSize(B,&bs);CHKERRQ(ierr);
   ierr = MatCreateVecs(B,&x,NULL);CHKERRQ(ierr);
+  ierr = MatGetVecType(B,&vectype);CHKERRQ(ierr);
 
   xred = NULL;
   m    = 0;
@@ -159,6 +160,7 @@ PetscErrorCode PCTelescopeSetUp_default(PC pc,PC_Telescope sred)
     ierr = VecCreate(subcomm,&xred);CHKERRQ(ierr);
     ierr = VecSetSizes(xred,PETSC_DECIDE,M);CHKERRQ(ierr);
     ierr = VecSetBlockSize(xred,bs);CHKERRQ(ierr);
+    ierr = VecSetType(xred,vectype);CHKERRQ(ierr); /* Use the preconditioner matrix's vectype by default */
     ierr = VecSetFromOptions(xred);CHKERRQ(ierr);
     ierr = VecGetLocalSize(xred,&m);CHKERRQ(ierr);
   }
@@ -171,7 +173,7 @@ PetscErrorCode PCTelescopeSetUp_default(PC pc,PC_Telescope sred)
   ierr = VecCreate(comm,&xtmp);CHKERRQ(ierr);
   ierr = VecSetSizes(xtmp,m,PETSC_DECIDE);CHKERRQ(ierr);
   ierr = VecSetBlockSize(xtmp,bs);CHKERRQ(ierr);
-  ierr = VecSetType(xtmp,((PetscObject)x)->type_name);CHKERRQ(ierr);
+  ierr = VecSetType(xtmp,vectype);CHKERRQ(ierr);
 
   if (PCTelescope_isActiveRank(sred)) {
     ierr = VecGetOwnershipRange(xred,&st,&ed);CHKERRQ(ierr);
@@ -198,7 +200,7 @@ PetscErrorCode PCTelescopeMatCreate_default(PC pc,PC_Telescope sred,MatReuse reu
   PetscErrorCode ierr;
   MPI_Comm       comm,subcomm;
   Mat            Bred,B;
-  PetscInt       nr,nc;
+  PetscInt       nr,nc,bs;
   IS             isrow,iscol;
   Mat            Blocal,*_Blocal;
 
@@ -211,6 +213,8 @@ PetscErrorCode PCTelescopeMatCreate_default(PC pc,PC_Telescope sred,MatReuse reu
   isrow = sred->isin;
   ierr = ISCreateStride(PETSC_COMM_SELF,nc,0,1,&iscol);CHKERRQ(ierr);
   ierr = ISSetIdentity(iscol);CHKERRQ(ierr);
+  ierr = MatGetBlockSizes(B,NULL,&bs);CHKERRQ(ierr);
+  ierr = ISSetBlockSize(iscol,bs);CHKERRQ(ierr);
   ierr = MatSetOption(B,MAT_SUBMAT_SINGLEIS,PETSC_TRUE);CHKERRQ(ierr);
   ierr = MatCreateSubMatrices(B,1,&isrow,&iscol,MAT_INITIAL_MATRIX,&_Blocal);CHKERRQ(ierr);
   Blocal = *_Blocal;
@@ -341,8 +345,8 @@ static PetscErrorCode PCView_Telescope(PC pc,PetscViewer viewer)
       if (sred->psubcomm) {
         comm = PetscSubcommParent(sred->psubcomm);
         subcomm = PetscSubcommChild(sred->psubcomm);
-        ierr = MPI_Comm_size(comm,&comm_size);CHKERRQ(ierr);
-        ierr = MPI_Comm_size(subcomm,&subcomm_size);CHKERRQ(ierr);
+        ierr = MPI_Comm_size(comm,&comm_size);CHKERRMPI(ierr);
+        ierr = MPI_Comm_size(subcomm,&subcomm_size);CHKERRMPI(ierr);
 
         ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
         ierr = PetscViewerASCIIPrintf(viewer,"petsc subcomm: parent comm size reduction factor = %D\n",sred->redfactor);CHKERRQ(ierr);
@@ -528,18 +532,18 @@ static PetscErrorCode PCSetUp_Telescope(PC pc)
       comm_fine = PetscObjectComm((PetscObject)dm);
       ierr = DMGetCoarseDM(dm,&dm_coarse_partition);CHKERRQ(ierr);
       if (dm_coarse_partition) { cnt = 1; }
-      ierr = MPI_Allreduce(MPI_IN_PLACE,&cnt,1,MPI_INT,MPI_SUM,comm_fine);CHKERRQ(ierr);
+      ierr = MPI_Allreduce(MPI_IN_PLACE,&cnt,1,MPI_INT,MPI_SUM,comm_fine);CHKERRMPI(ierr);
       if (cnt == 0) SETERRQ(comm_fine,PETSC_ERR_SUP,"Zero instances of a coarse DM were found");
 
-      ierr = MPI_Comm_size(comm_fine,&csize_fine);CHKERRQ(ierr);
+      ierr = MPI_Comm_size(comm_fine,&csize_fine);CHKERRMPI(ierr);
       if (dm_coarse_partition) {
         comm_coarse_partition = PetscObjectComm((PetscObject)dm_coarse_partition);
-        ierr = MPI_Comm_size(comm_coarse_partition,&csize_coarse_partition);CHKERRQ(ierr);
+        ierr = MPI_Comm_size(comm_coarse_partition,&csize_coarse_partition);CHKERRMPI(ierr);
       }
 
       cs[0] = csize_fine;
       cs[1] = csize_coarse_partition;
-      ierr = MPI_Allreduce(cs,csg,2,MPI_INT,MPI_MAX,comm_fine);CHKERRQ(ierr);
+      ierr = MPI_Allreduce(cs,csg,2,MPI_INT,MPI_MAX,comm_fine);CHKERRMPI(ierr);
       if (csg[0] == csg[1]) SETERRQ(comm_fine,PETSC_ERR_SUP,"Coarse DM uses the same size communicator as the parent DM attached to the PC");
 
       ierr = PCTelescopeTestValidSubcomm(comm_fine,comm_coarse_partition,&isvalidsubcomm);CHKERRQ(ierr);
@@ -586,7 +590,7 @@ static PetscErrorCode PCSetUp_Telescope(PC pc)
   /* common - no construction */
   if (PCTelescope_isActiveRank(sred)) {
     ierr = KSPSetOperators(sred->ksp,sred->Bred,sred->Bred);CHKERRQ(ierr);
-    if (pc->setfromoptionscalled && !pc->setupcalled){
+    if (pc->setfromoptionscalled && !pc->setupcalled) {
       ierr = KSPSetFromOptions(sred->ksp);CHKERRQ(ierr);
     }
   }
@@ -689,7 +693,7 @@ static PetscErrorCode PCApplyRichardson_Telescope(PC pc,Vec x,Vec y,Vec w,PetscR
 
   if (PCTelescope_isActiveRank(sred)) {
     ierr = KSPGetInitialGuessNonzero(sred->ksp,&default_init_guess_value);CHKERRQ(ierr);
-    if (!zeroguess) ierr = KSPSetInitialGuessNonzero(sred->ksp,PETSC_TRUE);CHKERRQ(ierr);
+    if (!zeroguess) {ierr = KSPSetInitialGuessNonzero(sred->ksp,PETSC_TRUE);CHKERRQ(ierr);}
   }
 
   ierr = PCApply_Telescope(pc,x,y);CHKERRQ(ierr);
@@ -708,6 +712,7 @@ static PetscErrorCode PCReset_Telescope(PC pc)
   PC_Telescope   sred = (PC_Telescope)pc->data;
   PetscErrorCode ierr;
 
+  PetscFunctionBegin;
   ierr = ISDestroy(&sred->isin);CHKERRQ(ierr);
   ierr = VecScatterDestroy(&sred->scatter);CHKERRQ(ierr);
   ierr = VecDestroy(&sred->xred);CHKERRQ(ierr);
@@ -746,7 +751,7 @@ static PetscErrorCode PCSetFromOptions_Telescope(PetscOptionItems *PetscOptionsO
 
   PetscFunctionBegin;
   ierr = PetscObjectGetComm((PetscObject)pc,&comm);CHKERRQ(ierr);
-  ierr = MPI_Comm_size(comm,&size);CHKERRQ(ierr);
+  ierr = MPI_Comm_size(comm,&size);CHKERRMPI(ierr);
   ierr = PetscOptionsHead(PetscOptionsObject,"Telescope options");CHKERRQ(ierr);
   ierr = PetscOptionsEnum("-pc_telescope_subcomm_type","Subcomm type (interlaced or contiguous)","PCTelescopeSetSubcommType",PetscSubcommTypes,(PetscEnum)sred->subcommtype,(PetscEnum*)&subcommtype,&flg);CHKERRQ(ierr);
   if (flg) {
@@ -804,7 +809,7 @@ static PetscErrorCode PCTelescopeSetReductionFactor_Telescope(PC pc,PetscInt fac
   PetscErrorCode   ierr;
 
   PetscFunctionBegin;
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)pc),&size);CHKERRQ(ierr);
+  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)pc),&size);CHKERRMPI(ierr);
   if (fact <= 0) SETERRQ1(PetscObjectComm((PetscObject)pc),PETSC_ERR_ARG_WRONG,"Reduction factor of telescoping PC %D must be positive",fact);
   if (fact > size) SETERRQ1(PetscObjectComm((PetscObject)pc),PETSC_ERR_ARG_WRONG,"Reduction factor of telescoping PC %D must be <= comm.size",fact);
   red->redfactor = fact;
@@ -1190,7 +1195,7 @@ PetscErrorCode PCTelescopeGetDM(PC pc,DM *subdm)
 
  Logically Collective
 
- Input Parameter:
+ Input Parameters:
 +  pc - the preconditioner context
 -  subcommtype - the subcommunicator type (see PetscSubcommType)
 
@@ -1258,7 +1263,7 @@ PetscErrorCode PCTelescopeGetSubcommType(PC pc, PetscSubcommType *subcommtype)
 
    [1] Default setup
    The sub-communicator c' is created via PetscSubcommCreate().
-   Explicitly defined nullspace and near nullspace vectors will be propogated from B to B'.
+   Explicitly defined nullspace and near nullspace vectors will be propagated from B to B'.
    Currently there is no support define nullspaces via a user supplied method (e.g. as passed to MatNullSpaceSetFunction()).
    No support is provided for KSPSetComputeOperators().
    Currently there is no support for the flag -pc_use_amat.
@@ -1286,7 +1291,7 @@ PetscErrorCode PCTelescopeGetSubcommType(PC pc, PetscSubcommType *subcommtype)
    Currently there is no support define nullspaces via a user supplied method (e.g. as passed to MatNullSpaceSetFunction()).
    There is no general method to permute field orderings, hence only KSPSetComputeOperators() is supported.
    The user must use PetscObjectComposeFunction() with dmfine to define the method to scatter fields from dmfine to dmcoarse.
-   Propogation of the user context for KSPSetComputeOperators() on the sub KSP is attempted by querying the DM contexts associated with dmfine and dmcoarse. Alternatively, the user may use PetscObjectComposeFunction() with dmcoarse to define a method which will return the appropriate user context for KSPSetComputeOperators().
+   Propagation of the user context for KSPSetComputeOperators() on the sub KSP is attempted by querying the DM contexts associated with dmfine and dmcoarse. Alternatively, the user may use PetscObjectComposeFunction() with dmcoarse to define a method which will return the appropriate user context for KSPSetComputeOperators().
    Currently there is no support for the flag -pc_use_amat.
    This setup can be invoked by the option -pc_telescope_use_coarse_dm or by calling PCTelescopeSetUseCoarseDM(pc,PETSC_TRUE);
    Further information about the user-provided methods required by this setup type are described here PCTelescopeSetUseCoarseDM().
@@ -1319,9 +1324,9 @@ PetscErrorCode PCTelescopeGetSubcommType(PC pc, PetscSubcommType *subcommtype)
    VecPlaceArray() could be used within PCApply() to improve efficiency and reduce memory usage.
    A unified mechanism to query for user contexts as required by KSPSetComputeOperators() and MatNullSpaceSetFunction().
 
-   The symmetric permutation used when a DMDA is encountered is performed via explicitly assmbleming a permutation matrix P,
+   The symmetric permutation used when a DMDA is encountered is performed via explicitly assembling a permutation matrix P,
    and performing P^T.A.P. Possibly it might be more efficient to use MatPermute(). We opted to use P^T.A.P as it appears
-   VecPermute() does not supported for the use case required here. By computing P, one can permute both the operator and RHS in a
+   VecPermute() does not support the use case required here. By computing P, one can permute both the operator and RHS in a
    consistent manner.
 
    Mapping of vectors (default setup mode) is performed in the following way.
@@ -1352,7 +1357,6 @@ PetscErrorCode PCTelescopeGetSubcommType(PC pc, PetscSubcommType *subcommtype)
 
    The entries on rank 1 and 3 (ranks which do not have a color = 0 in c') have no values
 
-
    [2] Copy the values from ranks 0, 2 (indices with respect to comm c) into the vector xred which is defined on communicator c'.
    Ranks 0 and 2 are the only ranks in the subcomm which have a color = 0.
 
