@@ -1,5 +1,4 @@
 
-
 /**********************************ivec.c**************************************
 
 Author: Henry M. Tufo III
@@ -21,7 +20,6 @@ Last Modification:
 #define   SORT_OPT     6
 #define   SORT_STACK   50000
 
-
 /* allocate an address and size stack for sorter(s) */
 static void     *offset_stack[2*SORT_STACK];
 static PetscInt size_stack[SORT_STACK];
@@ -162,11 +160,17 @@ PetscInt PCTFS_ivec_sum(PetscInt *arg1,  PetscInt n)
 }
 
 /***********************************ivec.c*************************************/
-PetscErrorCode PCTFS_ivec_non_uniform(PetscInt *arg1, PetscInt *arg2,  PetscInt n,  PetscInt *arg3)
+PetscErrorCode PCTFS_ivec_non_uniform(PetscInt *arg1, PetscInt *arg2,  PetscInt n, ...)
 {
   PetscInt i, j, type;
+  PetscInt *arg3;
+  va_list  ap;
 
   PetscFunctionBegin;
+  va_start(ap, n);
+  arg3 = va_arg(ap, PetscInt*);
+  va_end(ap);
+
   /* LATER: if we're really motivated we can sort and then unsort */
   for (i=0; i<n;) {
     /* clump 'em for now */
@@ -512,7 +516,6 @@ PetscInt PCTFS_ivec_linear_search(PetscInt item,  PetscInt *list,  PetscInt n)
 {
   PetscInt tmp = n-1;
 
-  PetscFunctionBegin;
   while (n--) {
     if (*list++ == item) return(tmp-n);
   }
@@ -698,8 +701,3 @@ vfp PCTFS_rvec_fct_addr(PetscInt type)
   return(NULL);
 }
 
-
-
-
-
-
