@@ -8,6 +8,7 @@ PETSC_EXTERN PetscErrorCode PCCreate_VPBJacobi(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_ILU(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_None(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_LU(PC);
+PETSC_EXTERN PetscErrorCode PCCreate_QR(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_SOR(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_Shell(PC);
 PETSC_EXTERN PetscErrorCode PCCreate_MG(PC);
@@ -61,8 +62,8 @@ PETSC_EXTERN PetscErrorCode PCCreate_Deflation(PC);
 #if defined(PETSC_HAVE_HPDDM) && defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
 PETSC_EXTERN PetscErrorCode PCCreate_HPDDM(PC);
 #endif
-#if defined(PETSC_HAVE_HARA)
-PETSC_EXTERN PetscErrorCode PCCreate_HARA(PC);
+#if defined(PETSC_HAVE_H2OPUS)
+PETSC_EXTERN PetscErrorCode PCCreate_H2OPUS(PC);
 #endif
 
 /*@C
@@ -92,6 +93,7 @@ PetscErrorCode  PCRegisterAll(void)
   ierr = PCRegister(PCBJACOBI      ,PCCreate_BJacobi);CHKERRQ(ierr);
   ierr = PCRegister(PCSOR          ,PCCreate_SOR);CHKERRQ(ierr);
   ierr = PCRegister(PCLU           ,PCCreate_LU);CHKERRQ(ierr);
+  ierr = PCRegister(PCQR           ,PCCreate_QR);CHKERRQ(ierr);
   ierr = PCRegister(PCSHELL        ,PCCreate_Shell);CHKERRQ(ierr);
   ierr = PCRegister(PCMG           ,PCCreate_MG);CHKERRQ(ierr);
   ierr = PCRegister(PCEISENSTAT    ,PCCreate_Eisenstat);CHKERRQ(ierr);
@@ -145,8 +147,8 @@ PetscErrorCode  PCRegisterAll(void)
 #if defined(PETSC_HAVE_HPDDM) && defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
   ierr = PCRegister(PCHPDDM        ,PCCreate_HPDDM);CHKERRQ(ierr);
 #endif
-#if defined(PETSC_HAVE_HARA)
-  ierr = PCRegister(PCHARA         ,PCCreate_HARA);CHKERRQ(ierr);
+#if defined(PETSC_HAVE_H2OPUS)
+  ierr = PCRegister(PCH2OPUS       ,PCCreate_H2OPUS);CHKERRQ(ierr);
 #endif
   PetscFunctionReturn(0);
 }
