@@ -1,7 +1,6 @@
-#include <petscconf.h>
+#include <petscvec_kokkos.hpp>
 #include <../src/mat/impls/aij/mpi/mpiaij.h>
 #include <../src/mat/impls/aij/seq/kokkos/aijkokkosimpl.hpp>
-#include <petscveckokkos.hpp>
 
 PetscErrorCode MatAssemblyEnd_MPIAIJKokkos(Mat A,MatAssemblyType mode)
 {
@@ -229,15 +228,12 @@ PetscErrorCode  MatCreateAIJKokkos(MPI_Comm comm,PetscInt m,PetscInt n,PetscInt
 }
 
 // get GPU pointer to stripped down Mat. For both Seq and MPI Mat.
-PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure **B)
+PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure *B)
 {
-  #if defined(PETSC_USE_CTABLE)
-  SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_SUP,"Device metadata does not support ctable (--with-ctable=0)");
-  #else
   PetscMPIInt                size,rank;
   MPI_Comm                   comm;
   PetscErrorCode             ierr;
-  PetscSplitCSRDataStructure *d_mat=NULL;
+  PetscSplitCSRDataStructure d_mat=NULL;
 
   PetscFunctionBegin;
   ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
@@ -260,12 +256,14 @@ PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure **B)
     // SETERRQ(comm,PETSC_ERR_SUP,"Need assemble matrix");
   }
   if (!d_mat) {
-    PetscSplitCSRDataStructure  h_mat; /* host container */
-    Mat_SeqAIJKokkos            *aijkokA;
-    Mat_SeqAIJ                  *jaca;
-    PetscInt                    n = A->rmap->n, nnz;
-    Mat                         Amat;
-    // create and copy
+    struct _n_SplitCSRMat h_mat; /* host container */
+    Mat_SeqAIJKokkos      *aijkokA;
+    Mat_SeqAIJ            *jaca;
+    PetscInt              n = A->rmap->n, nnz;
+    Mat                   Amat;
+    PetscInt              *colmap;
+
+    /* create and copy h_mat */
     ierr = PetscInfo(A,"Create device matrix in Kokkos\n");CHKERRQ(ierr);
     if (size == 1) {
       Amat = A;
@@ -282,47 +280,42 @@ PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure **B)
       Mat_SeqAIJ       *jacb = (Mat_SeqAIJ*)aij->B->data;
       PetscInt         ii;
       Mat_SeqAIJKokkos *aijkokB;
+
       Amat = aij->A;
       aijkokA = static_cast<Mat_SeqAIJKokkos*>(aij->A->spptr);
       aijkokB = static_cast<Mat_SeqAIJKokkos*>(aij->B->spptr);
       aijkokA->i_uncompressed_d = NULL;
       aijkokA->colmap_d = NULL;
       jaca = (Mat_SeqAIJ*)aij->A->data;
-      if (!aij->garray) SETERRQ(comm,PETSC_ERR_PLIB,"MPIAIJ Matrix was assembled but is missing garray");
+      if (aij->B->cmap->n && !aij->garray) SETERRQ(comm,PETSC_ERR_PLIB,"MPIAIJ Matrix was assembled but is missing garray");
       if (aij->B->rmap->n != aij->A->rmap->n) SETERRQ(comm,PETSC_ERR_SUP,"Only support aij->B->rmap->n == aij->A->rmap->n");
-      // create colmap - this is ussually done (lazy) in MatSetValues
       aij->donotstash = PETSC_TRUE;
       aij->A->nooffprocentries = aij->B->nooffprocentries = A->nooffprocentries = PETSC_TRUE;
-      jaca->nonew = jacb->nonew = PETSC_TRUE; // no more dissassembly
-      ierr = PetscCalloc1(A->cmap->N+1,&aij->colmap);CHKERRQ(ierr);
-      aij->colmap[A->cmap->N] = -9;
-      ierr = PetscLogObjectMemory((PetscObject)A,(A->cmap->N+1)*sizeof(PetscInt));CHKERRQ(ierr);
-      for (ii=0; ii<aij->B->cmap->n; ii++) aij->colmap[aij->garray[ii]] = ii+1;
-      if (aij->colmap[A->cmap->N] != -9) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"aij->colmap[A->cmap->N] != -9");
+      jaca->nonew = jacb->nonew = PETSC_TRUE; // no more disassembly
+      ierr = PetscCalloc1(A->cmap->N,&colmap);CHKERRQ(ierr);
+      ierr = PetscLogObjectMemory((PetscObject)A,(A->cmap->N)*sizeof(PetscInt));CHKERRQ(ierr);
+      for (ii=0; ii<aij->B->cmap->n; ii++) colmap[aij->garray[ii]] = ii+1;
       // allocate B copy data
       h_mat.rstart = A->rmap->rstart; h_mat.rend = A->rmap->rend;
       h_mat.cstart = A->cmap->rstart; h_mat.cend = A->cmap->rend;
       nnz = jacb->i[n];
       if (jacb->compressedrow.use) {
         const Kokkos::View<PetscInt*, Kokkos::HostSpace, Kokkos::MemoryTraits<Kokkos::Unmanaged> > h_i_k (jacb->i,n+1);
-        aijkokB->i_uncompressed_d = new Kokkos::View<PetscInt*>(Kokkos::create_mirror(DeviceMemorySpace(),h_i_k));
+        aijkokB->i_uncompressed_d = new Kokkos::View<PetscInt*>(Kokkos::create_mirror(DefaultMemorySpace(),h_i_k));
         Kokkos::deep_copy (*aijkokB->i_uncompressed_d, h_i_k);
         h_mat.offdiag.i = aijkokB->i_uncompressed_d->data();
-        //err = cudaMalloc((void **)&h_mat.offdiag.i,               (n+1)*sizeof(int));CHKERRCUDA(err); // kernel input
-        //err = cudaMemcpy(          h_mat.offdiag.i,    jacb->i,   (n+1)*sizeof(int), cudaMemcpyHostToDevice);CHKERRCUDA(err);
       } else {
          h_mat.offdiag.i = (PetscInt*)aijkokB->i_d.data();
       }
       h_mat.offdiag.j = (PetscInt*)aijkokB->j_d.data();
       h_mat.offdiag.a = aijkokB->a_d.data();
       {
-        Kokkos::View<PetscInt*, Kokkos::HostSpace, Kokkos::MemoryTraits<Kokkos::Unmanaged> > h_colmap_k (aij->colmap,A->cmap->N);
-        aijkokB->colmap_d = new Kokkos::View<PetscInt*>(Kokkos::create_mirror(DeviceMemorySpace(),h_colmap_k));
+        Kokkos::View<PetscInt*, Kokkos::HostSpace, Kokkos::MemoryTraits<Kokkos::Unmanaged> > h_colmap_k (colmap,A->cmap->N);
+        aijkokB->colmap_d = new Kokkos::View<PetscInt*>(Kokkos::create_mirror(DefaultMemorySpace(),h_colmap_k));
         Kokkos::deep_copy (*aijkokB->colmap_d, h_colmap_k);
         h_mat.colmap = aijkokB->colmap_d->data();
+        ierr = PetscFree(colmap);CHKERRQ(ierr);
       }
-      //err = cudaMalloc((void **)&h_mat.colmap,                  (A->cmap->N+1)*sizeof(PetscInt));CHKERRCUDA(err); // kernel output
-      //err = cudaMemcpy(          h_mat.colmap,    aij->colmap,  (A->cmap->N+1)*sizeof(PetscInt), cudaMemcpyHostToDevice);CHKERRCUDA(err);
       h_mat.offdiag.ignorezeroentries = jacb->ignorezeroentries;
       h_mat.offdiag.n = n;
     }
@@ -331,13 +324,10 @@ PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure **B)
     h_mat.diag.n = n;
     h_mat.diag.ignorezeroentries = jaca->ignorezeroentries;
     ierr = MPI_Comm_rank(comm,&h_mat.rank);CHKERRMPI(ierr);
-    if (jaca->compressedrow.use) {
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"A does not suppport compressed row (todo)");
-    } else {
+    if (jaca->compressedrow.use) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"A does not suppport compressed row (todo)");
+    else {
       h_mat.diag.i = (PetscInt*)aijkokA->i_d.data();
     }
-    //h_mat.diag.j = aj;
-    //h_mat.diag.a = aa;
     h_mat.diag.j = (PetscInt*)aijkokA->j_d.data();
     h_mat.diag.a = aijkokA->a_d.data();
     // copy pointers and metdata to device
@@ -348,5 +338,4 @@ PetscErrorCode MatKokkosGetDeviceMatWrite(Mat A, PetscSplitCSRDataStructure **B)
   *B = d_mat; // return it, set it in Mat, and set it up
   A->assembled = PETSC_FALSE; // ready to write with matsetvalues - this done (lazy) in normal MatSetValues
   PetscFunctionReturn(0);
-  #endif
 }
