@@ -11,7 +11,8 @@ PetscErrorCode MatSetUpMultiply_MPIAIJ(Mat mat)
   Mat_MPIAIJ     *aij = (Mat_MPIAIJ*)mat->data;
   Mat_SeqAIJ     *B   = (Mat_SeqAIJ*)(aij->B->data);
   PetscErrorCode ierr;
-  PetscInt       i,j,*aj = B->j,ec = 0,*garray;
+  PetscInt       i,j,*aj = B->j,*garray;
+  PetscInt       ec = 0; /* Number of nonzero external columns */
   IS             from,to;
   Vec            gvec;
 #if defined(PETSC_USE_CTABLE)
@@ -39,7 +40,7 @@ PetscErrorCode MatSetUpMultiply_MPIAIJ(Mat mat)
       }
     }
     /* form array of columns we need */
-    ierr = PetscMalloc1(ec+1,&garray);CHKERRQ(ierr);
+    ierr = PetscMalloc1(ec,&garray);CHKERRQ(ierr);
     ierr = PetscTableGetHeadPosition(gid1_lid1,&tpos);CHKERRQ(ierr);
     while (tpos) {
       ierr = PetscTableGetNext(gid1_lid1,&tpos,&gid,&lid);CHKERRQ(ierr);
@@ -67,7 +68,7 @@ PetscErrorCode MatSetUpMultiply_MPIAIJ(Mat mat)
 #else
     /* Make an array as long as the number of columns */
     /* mark those columns that are in aij->B */
-    ierr = PetscCalloc1(N+1,&indices);CHKERRQ(ierr);
+    ierr = PetscCalloc1(N,&indices);CHKERRQ(ierr);
     for (i=0; i<aij->B->rmap->n; i++) {
       for (j=0; j<B->ilen[i]; j++) {
         if (!indices[aj[B->i[i] + j]]) ec++;
@@ -76,7 +77,7 @@ PetscErrorCode MatSetUpMultiply_MPIAIJ(Mat mat)
     }
 
     /* form array of columns we need */
-    ierr = PetscMalloc1(ec+1,&garray);CHKERRQ(ierr);
+    ierr = PetscMalloc1(ec,&garray);CHKERRQ(ierr);
     ec   = 0;
     for (i=0; i<N; i++) {
       if (indices[i]) garray[ec++] = i;
@@ -120,7 +121,7 @@ PetscErrorCode MatSetUpMultiply_MPIAIJ(Mat mat)
   ierr = VecScatterCreate(gvec,from,aij->lvec,to,&aij->Mvctx);CHKERRQ(ierr);
   ierr = PetscLogObjectParent((PetscObject)mat,(PetscObject)aij->Mvctx);CHKERRQ(ierr);
   ierr = PetscLogObjectParent((PetscObject)mat,(PetscObject)aij->lvec);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory((PetscObject)mat,(ec+1)*sizeof(PetscInt));CHKERRQ(ierr);
+  ierr = PetscLogObjectMemory((PetscObject)mat,ec*sizeof(PetscInt));CHKERRQ(ierr);
   aij->garray = garray;
 
   ierr = PetscLogObjectParent((PetscObject)mat,(PetscObject)from);CHKERRQ(ierr);
@@ -211,7 +212,6 @@ PetscErrorCode MatDisAssemble_MPIAIJ(Mat A)
 static PetscInt *auglyrmapd = NULL,*auglyrmapo = NULL; /* mapping from the local ordering to the "diagonal" and "off-diagonal" parts of the local matrix */
 static Vec auglydd          = NULL,auglyoo     = NULL; /* work vectors used to scale the two parts of the local matrix */
 
-
 PetscErrorCode MatMPIAIJDiagonalScaleLocalSetUp(Mat inA,Vec scale)
 {
   Mat_MPIAIJ     *ina = (Mat_MPIAIJ*) inA->data; /*access private part of matrix */
