@@ -54,7 +54,6 @@ typedef struct {
   PetscBool              CleanUpSuperLU_Dist;  /* Flag to clean up (non-global) SuperLU objects during Destroy */
 } Mat_SuperLU_DIST;
 
-
 PetscErrorCode MatSuperluDistGetDiagU_SuperLU_DIST(Mat F,PetscScalar *diagU)
 {
   Mat_SuperLU_DIST *lu = (Mat_SuperLU_DIST*)F->data;
@@ -93,10 +92,10 @@ PETSC_EXTERN PetscMPIInt MPIAPI Petsc_Superlu_dist_keyval_Delete_Fn(MPI_Comm com
 
   PetscFunctionBegin;
   if (keyval != Petsc_Superlu_dist_keyval) SETERRMPI(PETSC_COMM_SELF,PETSC_ERR_ARG_CORRUPT,"Unexpected keyval");
-  ierr = PetscInfo(NULL,"Removing Petsc_Superlu_dist_keyval attribute from communicator that is being freed\n");
+  ierr = PetscInfo(NULL,"Removing Petsc_Superlu_dist_keyval attribute from communicator that is being freed\n");CHKERRQ(ierr);
   PetscStackCall("SuperLU_DIST:superlu_gridexit",superlu_gridexit(&context->grid));
   ierr = MPI_Comm_free(&context->comm);CHKERRMPI(ierr);
-  ierr = PetscFree(context);
+  ierr = PetscFree(context);CHKERRQ(ierr);
   PetscFunctionReturn(MPI_SUCCESS);
 }
 
@@ -116,7 +115,7 @@ static PetscErrorCode Petsc_Superlu_dist_keyval_free(void)
   PetscMPIInt    Petsc_Superlu_dist_keyval_temp = Petsc_Superlu_dist_keyval;
 
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"Freeing Petsc_Superlu_dist_keyval\n");
+  ierr = PetscInfo(NULL,"Freeing Petsc_Superlu_dist_keyval\n");CHKERRQ(ierr);
   ierr = MPI_Comm_free_keyval(&Petsc_Superlu_dist_keyval_temp);CHKERRMPI(ierr);
   PetscFunctionReturn(0);
 }
@@ -144,18 +143,28 @@ static PetscErrorCode MatDestroy_SuperLU_DIST(Mat A)
     /* Release the SuperLU_DIST process grid. Only if the matrix has its own copy, this is it is not in the communicator context */
     if (lu->comm_superlu) {
       PetscStackCall("SuperLU_DIST:superlu_gridexit",superlu_gridexit(&lu->grid));
-      ierr = MPI_Comm_free(&(lu->comm_superlu));CHKERRMPI(ierr);
-    } else {
-      PetscSuperLU_DIST *context;
-      MPI_Comm          comm;
-      PetscMPIInt       flg;
-
-      ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
-      ierr = MPI_Comm_get_attr(comm,Petsc_Superlu_dist_keyval,&context,&flg);CHKERRMPI(ierr);
-      if (!flg) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Communicator does not have expected Petsc_Superlu_dist_keyval attribute");
-      context->busy = PETSC_FALSE;
     }
   }
+  /*
+   * We always need to release the communicator that was created in MatGetFactor_aij_superlu_dist.
+   * lu->CleanUpSuperLU_Dist was turned on in MatLUFactorSymbolic_SuperLU_DIST. There are some use
+   * cases where we only create a matrix but do not solve mat. In these cases, lu->CleanUpSuperLU_Dist
+   * is off, and the communicator was not released or marked as "not busy " in the old code.
+   * Here we try to release comm regardless.
+  */
+  if (lu->comm_superlu) {
+    ierr = MPI_Comm_free(&(lu->comm_superlu));CHKERRMPI(ierr);
+  } else {
+    PetscSuperLU_DIST *context;
+    MPI_Comm          comm;
+    PetscMPIInt       flg;
+
+    ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
+    ierr = MPI_Comm_get_attr(comm,Petsc_Superlu_dist_keyval,&context,&flg);CHKERRMPI(ierr);
+    if (!flg) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Communicator does not have expected Petsc_Superlu_dist_keyval attribute");
+    context->busy = PETSC_FALSE;
+  }
+
   ierr = PetscFree(A->data);CHKERRQ(ierr);
   /* clear composed functions */
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatFactorGetSolverType_C",NULL);CHKERRQ(ierr);
@@ -580,6 +589,7 @@ static PetscErrorCode MatGetFactor_aij_superlu_dist(Mat A,MatFactorType ftype,Ma
   */
   set_default_options_dist(&options);
 
+  B->trivialsymbolic = PETSC_TRUE;
   if (ftype == MAT_FACTOR_LU) {
     B->factortype = MAT_FACTOR_LU;
     B->ops->lufactorsymbolic = MatLUFactorSymbolic_SuperLU_DIST;
