@@ -1,8 +1,16 @@
-#if !defined(__SEQAIJKOKKOSIMPL_HPP)
-#define __SEQAIJKOKKOSIMPL_HPP
+#if !defined(SEQAIJKOKKOSIMPL_HPP)
+#define SEQAIJKOKKOSIMPL_HPP
 
+#include <petscaijdevice.h>
 #include <petsc/private/vecimpl_kokkos.hpp>
 #include <KokkosSparse_CrsMatrix.hpp>
+#include <KokkosSparse_spiluk.hpp>
+
+/*
+   Kokkos::View<struct _n_SplitCSRMat,DefaultMemorySpace> is not handled correctly so we define SplitCSRMat
+   for the singular purpose of working around this.
+*/
+typedef struct _n_SplitCSRMat SplitCSRMat;
 
 using MatRowOffsetType    = PetscInt;
 using MatColumnIndexType  = PetscInt;
@@ -16,9 +24,13 @@ using KokkosCsrMatrix                     = KokkosCsrMatrixType<DefaultMemorySpa
 
 using KokkosCsrGraphHost                  = KokkosCsrGraphType<DefaultMemorySpace>::HostMirror;
 
-using MatColumnIndexKokkosView            = KokkosCsrGraph::entries_type;
-using MatRowOffsetKokkosView              = KokkosCsrGraph::row_map_type;
-using MatValueKokkosView                  = KokkosCsrMatrix::values_type;
+using ConstMatColumnIndexKokkosView       = KokkosCsrGraph::entries_type;
+using ConstMatRowOffsetKokkosView         = KokkosCsrGraph::row_map_type;
+using ConstMatValueKokkosView             = KokkosCsrMatrix::values_type;
+
+using MatColumnIndexKokkosView            = KokkosCsrGraph::entries_type::non_const_type;
+using MatRowOffsetKokkosView              = KokkosCsrGraph::row_map_type::non_const_type;
+using MatValueKokkosView                  = KokkosCsrMatrix::values_type::non_const_type;
 
 using MatColumnIndexKokkosViewHost        = MatColumnIndexKokkosView::HostMirror;
 using MatRowOffsetKokkosViewHost          = MatRowOffsetKokkosView::HostMirror;
@@ -26,6 +38,32 @@ using MatValueKokkosViewHost              = MatValueKokkosView::HostMirror;
 
 using MatValueKokkosDualView              = Kokkos::DualView<MatValueType*>;
 
+using KernelHandle                        = KokkosKernels::Experimental::KokkosKernelsHandle<MatRowOffsetType,MatColumnIndexType,MatValueType,DefaultExecutionSpace,DefaultMemorySpace,DefaultMemorySpace>;
+
+struct Mat_SeqAIJKokkosTriFactors {
+  MatRowOffsetKokkosView         iL_d,iU_d,iLt_d,iUt_d; /* rowmap for L, U, L^t, U^t of A=LU */
+  MatColumnIndexKokkosView       jL_d,jU_d,jLt_d,jUt_d; /* column ids */
+  MatValueKokkosView             aL_d,aU_d,aLt_d,aUt_d; /* matrix values */
+  KernelHandle                   kh,khL,khU,khLt,khUt;  /* Kernel handles for A, L, U, L^t, U^t */
+  PetscBool                      transpose_updated;     /* Are L^T, U^T updated wrt L, U*/
+  PetscBool                      sptrsv_symbolic_completed; /* Have we completed the symbolic solve for L and U */
+  PetscScalarKokkosView          workVector;
+
+  Mat_SeqAIJKokkosTriFactors(PetscInt n)
+    : transpose_updated(PETSC_FALSE),sptrsv_symbolic_completed(PETSC_FALSE),workVector("workVector",n) {}
+
+  ~Mat_SeqAIJKokkosTriFactors() {Destroy();}
+
+  void Destroy() {
+    kh.destroy_spiluk_handle();
+    khL.destroy_sptrsv_handle();
+    khU.destroy_sptrsv_handle();
+    khLt.destroy_sptrsv_handle();
+    khUt.destroy_sptrsv_handle();
+    transpose_updated = sptrsv_symbolic_completed = PETSC_FALSE;
+  }
+};
+
 struct Mat_SeqAIJKokkos {
   MatRowOffsetKokkosViewHost     i_h;
   MatRowOffsetKokkosView         i_d;
@@ -45,16 +83,16 @@ struct Mat_SeqAIJKokkos {
   PetscObjectState               nonzerostate; /* State of the nonzero pattern (graph) on device */
 
   Mat                            At,Ah; /* Transpose and Hermitian of the matrix in MATAIJKOKKOS type (built on demand) */
-  PetscBool                      need_sync_At_values,need_sync_Ah_values; /* A's values are updated but At, Ah are not */
+  PetscBool                      transpose_updated,hermitian_updated; /* Are At, Ah updated wrt the matrix? */
 
   Kokkos::View<PetscInt*>        *i_uncompressed_d;
   Kokkos::View<PetscInt*>        *colmap_d; // ugh, this is a parallel construct
-  Kokkos::View<PetscSplitCSRDataStructure,DefaultMemorySpace> device_mat_d;
+  Kokkos::View<SplitCSRMat,DefaultMemorySpace> device_mat_d;
   Kokkos::View<PetscInt*>        *diag_d; // factorizations
 
-  /* Construct a nrows by ncols matrix of nnz nonzeros with (i,j,a) for the CSR */
+   /* Construct a nrows by ncols matrix of nnz nonzeros with (i,j,a) for the CSR */
   Mat_SeqAIJKokkos(MatColumnIndexType nrows,MatColumnIndexType ncols,MatRowOffsetType nnz,MatRowOffsetType *i,MatColumnIndexType *j,MatValueType *a)
-   : i_h(i,nrows+1),j_h(j,nnz),a_h(a,nnz),At(NULL),Ah(NULL),need_sync_At_values(PETSC_FALSE),need_sync_Ah_values(PETSC_FALSE),
+   : i_h(i,nrows+1),j_h(j,nnz),a_h(a,nnz),At(NULL),Ah(NULL),transpose_updated(PETSC_FALSE),hermitian_updated(PETSC_FALSE),
      i_uncompressed_d(NULL),colmap_d(NULL),device_mat_d(NULL),diag_d(NULL)
   {
      i_d        = Kokkos::create_mirror_view_and_copy(DefaultMemorySpace(),i_h);
