@@ -62,7 +62,6 @@ typedef struct {
   void *ctx;
 } Mat_Shell;
 
-
 /*
      Store and scale values on zeroed rows
      xx = [x_1, 0], 0 on zeroed columns
@@ -701,7 +700,7 @@ static PetscErrorCode MatProductNumeric_Shell_X(Mat D)
         PetscObjectState axpy_state;
         MatStructure     str = DIFFERENT_NONZERO_PATTERN; /* not sure it is safe to ever use SUBSET_NONZERO_PATTERN */
 
-        ierr = MatShellGetContext(shell->axpy,(void *)&X);CHKERRQ(ierr);
+        ierr = MatShellGetContext(shell->axpy,&X);CHKERRQ(ierr);
         ierr = PetscObjectStateGet((PetscObject)X,&axpy_state);CHKERRQ(ierr);
         if (shell->axpy_state != axpy_state) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ORDER,"Invalid AXPY state: cannot modify the X matrix passed to MatAXPY(Y,a,X,...)");
         if (!mdata->axpy) {
@@ -1078,7 +1077,7 @@ PetscErrorCode MatMult_Shell(Mat A,Vec x,Vec y)
     Mat              X;
     PetscObjectState axpy_state;
 
-    ierr = MatShellGetContext(shell->axpy,(void *)&X);CHKERRQ(ierr);
+    ierr = MatShellGetContext(shell->axpy,&X);CHKERRQ(ierr);
     ierr = PetscObjectStateGet((PetscObject)X,&axpy_state);CHKERRQ(ierr);
     if (shell->axpy_state != axpy_state) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ORDER,"Invalid AXPY state: cannot modify the X matrix passed to MatAXPY(Y,a,X,...)");
 
@@ -1133,7 +1132,7 @@ PetscErrorCode MatMultTranspose_Shell(Mat A,Vec x,Vec y)
     Mat              X;
     PetscObjectState axpy_state;
 
-    ierr = MatShellGetContext(shell->axpy,(void *)&X);CHKERRQ(ierr);
+    ierr = MatShellGetContext(shell->axpy,&X);CHKERRQ(ierr);
     ierr = PetscObjectStateGet((PetscObject)X,&axpy_state);CHKERRQ(ierr);
     if (shell->axpy_state != axpy_state) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ORDER,"Invalid AXPY state: cannot modify the X matrix passed to MatAXPY(Y,a,X,...)");
     ierr = MatCreateVecs(shell->axpy,shell->axpy_right ? NULL : &shell->axpy_right,shell->axpy_left ? NULL : &shell->axpy_left);CHKERRQ(ierr);
@@ -1188,7 +1187,7 @@ PetscErrorCode MatGetDiagonal_Shell(Mat A,Vec v)
     Mat              X;
     PetscObjectState axpy_state;
 
-    ierr = MatShellGetContext(shell->axpy,(void *)&X);CHKERRQ(ierr);
+    ierr = MatShellGetContext(shell->axpy,&X);CHKERRQ(ierr);
     ierr = PetscObjectStateGet((PetscObject)X,&axpy_state);CHKERRQ(ierr);
     if (shell->axpy_state != axpy_state) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_ORDER,"Invalid AXPY state: cannot modify the X matrix passed to MatAXPY(Y,a,X,...)");
     ierr = MatCreateVecs(shell->axpy,NULL,shell->axpy_left ? NULL : &shell->axpy_left);CHKERRQ(ierr);
@@ -1775,11 +1774,9 @@ $     VecDestroy(&y);
 $     VecDestroy(&x);
 $
 
-
    MATSHELL handles MatShift(), MatDiagonalSet(), MatDiagonalScale(), MatAXPY(), MatScale(), MatZeroRows() and MatZeroRowsColumns() internally, so these
    operations cannot be overwritten unless MatShellSetManageScalingShifts() is called.
 
-
     For rectangular matrices do all the scalings and shifts make sense?
 
     Developers Notes:
@@ -1798,7 +1795,7 @@ $
    an update in the preconditioner you must call MatAssemblyBegin()/MatAssemblyEnd() or PetscObjectStateIncrease((PetscObject)mat);
    each time the MATSHELL matrix has changed.
 
-   Matrix product operations (i.e. MatMat, MatTranposeMat etc) can be specified using MatShellSetMatProductOperation()
+   Matrix product operations (i.e. MatMat, MatTransposeMat etc) can be specified using MatShellSetMatProductOperation()
 
    Calling MatAssemblyBegin()/MatAssemblyEnd() on a MATSHELL removes any previously supplied shift and scales that were provided
    with MatDiagonalSet(), MatShift(), MatScale(), or MatDiagonalScale().
@@ -1959,7 +1956,7 @@ PetscErrorCode  MatShellTestMult(Mat mat,PetscErrorCode (*f)(void*,Vec,Vec),Vec
 }
 
 /*@C
-    MatShellTestMultTranpose - Compares the multiply transpose routine provided to the MATSHELL with differencing on a given function.
+    MatShellTestMultTranspose - Compares the multiply transpose routine provided to the MATSHELL with differencing on a given function.
 
    Logically Collective on Mat
 
