@@ -36,10 +36,10 @@ PetscErrorCode  MatNullSpaceSetFunction(MatNullSpace sp, PetscErrorCode (*rem)(M
 
    Not Collective
 
-   Input Arguments:
+   Input Parameter:
 .  sp - null space object
 
-   Output Arguments:
+   Output Parameters:
 +  has_cnst - PETSC_TRUE if the null space contains the constant vector, otherwise PETSC_FALSE
 .  n - number of vectors (excluding constant vector) in null space
 -  vecs - orthonormal vectors that span the null space (excluding the constant vector)
@@ -67,10 +67,10 @@ PetscErrorCode MatNullSpaceGetVecs(MatNullSpace sp,PetscBool *has_const,PetscInt
 
    Collective on Vec
 
-   Input Argument:
+   Input Parameter:
 .  coords - block of coordinates of each node, must have block size set
 
-   Output Argument:
+   Output Parameter:
 .  sp - the null space
 
    Level: advanced
@@ -82,7 +82,6 @@ PetscErrorCode MatNullSpaceGetVecs(MatNullSpace sp,PetscBool *has_const,PetscInt
      If you are solving an elasticity problem with pure Neumann boundary conditions you can use this in conjunction with MatSetNullspace() to
      provide this information to the linear solver so it can handle the null space appropriately in the linear solution.
 
-
 .seealso: MatNullSpaceCreate(), MatSetNearNullspace(), MatSetNullspace()
 @*/
 PetscErrorCode MatNullSpaceCreateRigidBody(Vec coords,MatNullSpace *sp)
@@ -430,7 +429,7 @@ PetscErrorCode  MatNullSpaceTest(MatNullSpace sp,Mat mat,PetscBool  *isNull)
   if (sp->has_cnst) {
     ierr = VecDuplicate(l,&r);CHKERRQ(ierr);
     ierr = VecGetSize(l,&N);CHKERRQ(ierr);
-    sum  = 1.0/N;
+    sum  = 1.0/PetscSqrtReal(N);
     ierr = VecSet(l,sum);CHKERRQ(ierr);
     ierr = MatMult(mat,l,r);CHKERRQ(ierr);
     ierr = VecNorm(r,NORM_2,&nrm);CHKERRQ(ierr);
