@@ -66,7 +66,7 @@ int main(int argc,char **args)
       PetscInt  rows[2];
       PetscBool test_offproc = PETSC_FALSE;
 
-      ierr = PetscOptionsGetBool(NULL,NULL,"-test_offproc",&test_offproc,NULL);
+      ierr = PetscOptionsGetBool(NULL,NULL,"-test_offproc",&test_offproc,NULL);CHKERRQ(ierr);
       if (test_offproc) {
         const PetscInt *ranges;
         PetscMPIInt    rank;
@@ -118,10 +118,16 @@ int main(int argc,char **args)
   /* check conversion routines */
   ierr = MatConvert(A,MATHYPRE,MAT_INITIAL_MATRIX,&B);CHKERRQ(ierr);
   ierr = MatConvert(A,MATHYPRE,MAT_REUSE_MATRIX,&B);CHKERRQ(ierr);
+  ierr = MatMultEqual(B,A,4,&flg);CHKERRQ(ierr);
+  if (!flg) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_PLIB,"Error Mat HYPRE");
   ierr = MatConvert(B,MATIS,MAT_INITIAL_MATRIX,&D);CHKERRQ(ierr);
   ierr = MatConvert(B,MATIS,MAT_REUSE_MATRIX,&D);CHKERRQ(ierr);
+  ierr = MatMultEqual(D,A,4,&flg);CHKERRQ(ierr);
+  if (!flg) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_PLIB,"Error Mat IS");
   ierr = MatConvert(B,MATAIJ,MAT_INITIAL_MATRIX,&C);CHKERRQ(ierr);
   ierr = MatConvert(B,MATAIJ,MAT_REUSE_MATRIX,&C);CHKERRQ(ierr);
+  ierr = MatMultEqual(C,A,4,&flg);CHKERRQ(ierr);
+  if (!flg) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_PLIB,"Error Mat AIJ");
   ierr = MatAXPY(C,-1.,A,SAME_NONZERO_PATTERN);CHKERRQ(ierr);
   ierr = MatNorm(C,NORM_INFINITY,&err);CHKERRQ(ierr);
   if (err > PETSC_SMALL) SETERRQ1(PetscObjectComm((PetscObject)A),PETSC_ERR_PLIB,"Error Mat AIJ %g",err);
@@ -344,60 +350,68 @@ int main(int argc,char **args)
   return ierr;
 }
 
-
 /*TEST
 
    build:
       requires: hypre
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 1
       args: -N 11 -M 11
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 2
       nsize: 3
       args: -N 13 -M 13 -matmatmult_via hypre
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 3
       nsize: 4
       args: -M 13 -N 7 -matmatmult_via hypre
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 4
       nsize: 2
       args: -M 12 -N 19
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 5
       nsize: 3
       args: -M 13 -N 13 -matptap_via hypre -matptap_hypre_outtype hypre
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 6
       nsize: 3
       args: -M 12 -N 19 -test_offproc
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 7
       nsize: 3
       args: -M 19 -N 12 -test_offproc -view_B ::ascii_info_detail
       output_file: output/ex115_7.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 8
       nsize: 3
       args: -M 1 -N 12 -test_offproc
       output_file: output/ex115_1.out
 
    test:
+      requires: !defined(PETSC_HAVE_HYPRE_DEVICE)
       suffix: 9
       nsize: 3
       args: -M 1 -N 2 -test_offproc
