@@ -37,7 +37,7 @@ int main(int argc,char **args)
   ierr = MatGetOwnershipRange(C,&rstart,&rend);CHKERRQ(ierr);
   for (i=rstart; i<rend; i++) {
     ierr = MatGetRow(C,i,&nz,&idx,&values);CHKERRQ(ierr);
-    if (!rank) {
+    if (rank == 0) {
       for (j=0; j<nz; j++) {
         ierr = PetscPrintf(PETSC_COMM_SELF,"%D %g ",idx[j],(double)PetscRealPart(values[j]));CHKERRQ(ierr);
       }
@@ -51,7 +51,6 @@ int main(int argc,char **args)
   return ierr;
 }
 
-
 /*TEST
 
    test:
