@@ -23,7 +23,7 @@ int main(int argc,char **args)
   ierr = MatCreate(PETSC_COMM_WORLD,&A);CHKERRQ(ierr);
   ierr = MatSetFromOptions(A);CHKERRQ(ierr);
   ierr = MatSetBlockSize(A,2);CHKERRQ(ierr);
-  if (!rank) {
+  if (rank == 0) {
     ierr = MatSetSizes(A, 4, PETSC_DETERMINE, PETSC_DETERMINE,PETSC_DETERMINE);CHKERRQ(ierr);
   } else {
     ierr = MatSetSizes(A, 8, PETSC_DETERMINE, PETSC_DETERMINE,PETSC_DETERMINE);CHKERRQ(ierr);
@@ -35,24 +35,23 @@ int main(int argc,char **args)
   return ierr;
 }
 
-
 /*TEST
 
       test:
          nsize: 2
          args: -mat_type aij -mat_view -f ${wPETSC_DIR}/share/petsc/datafiles/matrices/ns-real-int32-float64
-         requires: double !complex !define(PETSC_USE_64BIT_INDICES)
+         requires: double !complex !defined(PETSC_USE_64BIT_INDICES)
 
       test:
          suffix: 2
          nsize: 2
          args: -mat_type baij -mat_view -f ${wPETSC_DIR}/share/petsc/datafiles/matrices/ns-real-int32-float64
-         requires: double !complex !define(PETSC_USE_64BIT_INDICES)
+         requires: double !complex !defined(PETSC_USE_64BIT_INDICES)
 
       test:
          suffix: 3
          nsize: 2
          args: -mat_type sbaij -mat_view -f ${wPETSC_DIR}/share/petsc/datafiles/matrices/ns-real-int32-float64
-         requires: double !complex !define(PETSC_USE_64BIT_INDICES)
+         requires: double !complex !defined(PETSC_USE_64BIT_INDICES)
 
 TEST*/
