@@ -1,4 +1,3 @@
-
 static char help[] = "Tests MatSolve() and MatMatSolve() with MUMPS or MKL_PARDISO sequential solvers in Schur complement mode.\n\
 Example: mpiexec -n 1 ./ex192 -f <matrix binary file> -nrhs 4 -symmetric_solve -hermitian_solve -schur_ratio 0.3\n\n";
 
@@ -69,7 +68,7 @@ int main(int argc,char **args)
   ierr = MatGetSize(A,&m,&n);CHKERRQ(ierr);
   if (m != n) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_SIZ, "This example is not intended for rectangular matrices (%d, %d)", m, n);
 
-  /* Create dense matrix C and X; C holds true solution with identical colums */
+  /* Create dense matrix C and X; C holds true solution with identical columns */
   nrhs = 2;
   ierr = PetscOptionsGetInt(NULL,NULL,"-nrhs",&nrhs,NULL);CHKERRQ(ierr);
   ierr = MatCreate(PETSC_COMM_WORLD,&C);CHKERRQ(ierr);
@@ -303,11 +302,10 @@ int main(int argc,char **args)
   return ierr;
 }
 
-
 /*TEST
 
    testset:
-     requires: mkl_pardiso double !complex !define(PETSC_USE_64BIT_INDICES)
+     requires: mkl_pardiso double !complex
      args: -solver 1
 
      test:
@@ -331,7 +329,7 @@ int main(int argc,char **args)
        args: -symmetric_solve -hermitian_solve
        output_file: output/ex192_mkl_pardiso_3.out
      test:
-       requires: cuda define(PETSC_HAVE_CUSOLVERDNDPOTRI)
+       requires: cuda defined(PETSC_HAVE_CUSOLVERDNDPOTRI)
        suffix: mkl_pardiso_cuda_3
        args: -symmetric_solve -hermitian_solve -cuda_solve
        output_file: output/ex192_mkl_pardiso_3.out
@@ -361,7 +359,7 @@ int main(int argc,char **args)
        args: -symmetric_solve -hermitian_solve
        output_file: output/ex192_mumps_3.out
      test:
-       requires: cuda define(PETSC_HAVE_CUSOLVERDNDPOTRI)
+       requires: cuda defined(PETSC_HAVE_CUSOLVERDNDPOTRI)
        suffix: mumps_cuda_3
        args: -symmetric_solve -hermitian_solve -cuda_solve
        output_file: output/ex192_mumps_3.out
