@@ -9,7 +9,6 @@ static char help[] = "A test for MatAssembly that heavily relies on PetscSortInt
 
    Contributed-by: Fande Kong <fdkong.jd@gmail.com>, John Peterson <jwpeterson@gmail.com>
  */
-#define PETSC_SKIP_CXX_COMPLEX_FIX
 
 // PETSc includes
 #include <petscmat.h>
@@ -157,7 +156,7 @@ int main (int argc, char** argv)
 }
 /*TEST
    build:
-      requires: !define(PETSC_HAVE_SUN_CXX)
+      requires: !defined(PETSC_HAVE_SUN_CXX)
 
    test:
       nsize: 2
