@@ -66,7 +66,7 @@ int main(int argc,char **args)
 
     test:
       args: -fin ${DATAFILESPATH}/matrices/small -fout joe -start 2 -m 4
-      requires: datafilespath double !complex !define(PETSC_USE_64BIT_INDICES)
+      requires: datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES)
 
 TEST*/
 
