@@ -49,10 +49,11 @@ int main(int argc,char **args)
 
   /*  Load the matrices A_save and B */
   ierr = PetscOptionsBegin(PETSC_COMM_WORLD,"","","");CHKERRQ(ierr);
+  ierr = PetscOptionsBool("-test_rart","Test MatRARt","",Test_MatRARt,&Test_MatRARt,NULL);CHKERRQ(ierr);
   ierr = PetscOptionsInt("-PN","Number of columns of P","",PN,&PN,NULL);CHKERRQ(ierr);
   ierr = PetscOptionsInt("-mcheck","Number of matmult checks","",mcheck,&mcheck,NULL);CHKERRQ(ierr);
   ierr = PetscOptionsString("-fA","Path for matrix A","",file[0],file[0],sizeof(file[0]),&flg);CHKERRQ(ierr);
-  if (!flg) SETERRQ(PETSC_COMM_WORLD,1,"Must indicate a file name for matrix A with the -fA option.");
+  if (!flg) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_USER_INPUT,"Must indicate a file name for matrix A with the -fA option.");
   ierr = PetscOptionsString("-fB","Path for matrix B","",file[1],file[1],sizeof(file[1]),&flg);CHKERRQ(ierr);
   ierr = PetscOptionsFList("-A_mat_type","Matrix type","MatSetType",MatList,deft,A_mattype,256,&flgA);CHKERRQ(ierr);
   ierr = PetscOptionsFList("-B_mat_type","Matrix type","MatSetType",MatList,deft,B_mattype,256,&flgB);CHKERRQ(ierr);
@@ -152,7 +153,7 @@ int main(int argc,char **args)
   if (PN < 0) PN = PM/2;
   ierr = MatCreate(PETSC_COMM_WORLD,&P);CHKERRQ(ierr);
   ierr = MatSetSizes(P,PETSC_DECIDE,PETSC_DECIDE,PM,PN);CHKERRQ(ierr);
-  ierr = MatSetType(P,mattype);CHKERRQ(ierr);
+  ierr = MatSetType(P,MATAIJ);CHKERRQ(ierr);
   ierr = MatSeqAIJSetPreallocation(P,nzp,NULL);CHKERRQ(ierr);
   ierr = MatMPIAIJSetPreallocation(P,nzp,NULL,nzp,NULL);CHKERRQ(ierr);
   ierr = MatGetOwnershipRange(P,&rstart,&rend);CHKERRQ(ierr);
@@ -168,9 +169,11 @@ int main(int argc,char **args)
   }
   ierr = MatAssemblyBegin(P,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   ierr = MatAssemblyEnd(P,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatSetFromOptions(P);CHKERRQ(ierr);
 
   ierr = MatTranspose(P,MAT_INITIAL_MATRIX,&R);CHKERRQ(ierr);
+  ierr = MatConvert(P,mattype,MAT_INPLACE_MATRIX,&P);CHKERRQ(ierr);
+  ierr = MatConvert(R,mattype,MAT_INPLACE_MATRIX,&R);CHKERRQ(ierr);
+  ierr = MatSetFromOptions(P);CHKERRQ(ierr);
   ierr = MatSetFromOptions(R);CHKERRQ(ierr);
 
   /* 2) MatTransposeMatMult() */
@@ -183,30 +186,35 @@ int main(int argc,char **args)
     ierr = MatProductSetAlgorithm(C,MATPRODUCTALGORITHM_DEFAULT);CHKERRQ(ierr);
     ierr = MatProductSetFill(C,PETSC_DEFAULT);CHKERRQ(ierr);
     ierr = MatProductSetFromOptions(C);CHKERRQ(ierr);
-    ierr = MatProductSymbolic(C);CHKERRQ(ierr); /* equivalent to MatSetUp() */
-    ierr = MatSetOption(C,MAT_USE_INODES,PETSC_FALSE);CHKERRQ(ierr); /* illustrate how to call MatSetOption() */
-    ierr = MatProductNumeric(C);CHKERRQ(ierr);
-    ierr = MatProductNumeric(C);CHKERRQ(ierr); /* test reuse symbolic C */
+    ierr = MatHasOperation(C,MATOP_PRODUCTSYMBOLIC,&flg);CHKERRQ(ierr);
+    if (flg) { /* run tests if supported */
+      ierr = MatProductSymbolic(C);CHKERRQ(ierr); /* equivalent to MatSetUp() */
+      ierr = MatSetOption(C,MAT_USE_INODES,PETSC_FALSE);CHKERRQ(ierr); /* illustrate how to call MatSetOption() */
+      ierr = MatProductNumeric(C);CHKERRQ(ierr);
+      ierr = MatProductNumeric(C);CHKERRQ(ierr); /* test reuse symbolic C */
 
-    ierr = MatTransposeMatMultEqual(P,B,C,mcheck,&flg);CHKERRQ(ierr);
-    if (!flg) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Error: developer driver C = P^T*B");
-    ierr = MatDestroy(&C);CHKERRQ(ierr);
+      ierr = MatTransposeMatMultEqual(P,B,C,mcheck,&flg);CHKERRQ(ierr);
+      if (!flg) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Error: developer driver C = P^T*B");
+      ierr = MatDestroy(&C);CHKERRQ(ierr);
 
-    /* (2.2) Test user driver C = P^T*B */
-    ierr = MatTransposeMatMult(P,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
-    ierr = MatTransposeMatMult(P,B,MAT_REUSE_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
-    ierr = MatGetInfo(C,MAT_GLOBAL_SUM,&info);CHKERRQ(ierr);
-    ierr = MatProductClear(C);CHKERRQ(ierr);
+      /* (2.2) Test user driver C = P^T*B */
+      ierr = MatTransposeMatMult(P,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
+      ierr = MatTransposeMatMult(P,B,MAT_REUSE_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
+      ierr = MatGetInfo(C,MAT_GLOBAL_SUM,&info);CHKERRQ(ierr);
+      ierr = MatProductClear(C);CHKERRQ(ierr);
 
-    /* Compare P^T*B and R*B */
-    ierr = MatMatMult(R,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&C1);CHKERRQ(ierr);
-    ierr = MatNormDifference(C,C1,&norm);CHKERRQ(ierr);
-    if (norm > PETSC_SMALL) SETERRQ1(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Error in MatTransposeMatMult(): %g",(double)norm);
-    ierr = MatDestroy(&C1);CHKERRQ(ierr);
+      /* Compare P^T*B and R*B */
+      ierr = MatMatMult(R,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&C1);CHKERRQ(ierr);
+      ierr = MatNormDifference(C,C1,&norm);CHKERRQ(ierr);
+      if (norm > PETSC_SMALL) SETERRQ1(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Error in MatTransposeMatMult(): %g",(double)norm);
+      ierr = MatDestroy(&C1);CHKERRQ(ierr);
 
-    /* Test MatDuplicate() of C=P^T*B */
-    ierr = MatDuplicate(C,MAT_COPY_VALUES,&C1);CHKERRQ(ierr);
-    ierr = MatDestroy(&C1);CHKERRQ(ierr);
+      /* Test MatDuplicate() of C=P^T*B */
+      ierr = MatDuplicate(C,MAT_COPY_VALUES,&C1);CHKERRQ(ierr);
+      ierr = MatDestroy(&C1);CHKERRQ(ierr);
+    } else {
+      ierr = PetscPrintf(PETSC_COMM_WORLD,"MatTransposeMatMult not supported\n");CHKERRQ(ierr);
+    }
     ierr = MatDestroy(&C);CHKERRQ(ierr);
   }
 
@@ -271,7 +279,6 @@ int main(int argc,char **args)
     /* ----------------- */
     if (Test_MatRARt) {
       Mat RARt;
-      ierr = MatTranspose(P,MAT_REUSE_MATRIX,&R);CHKERRQ(ierr);
 
       /* (5.1) Test developer driver RARt = R*A*Rt */
       ierr = MatProductCreate(A,R,NULL,&RARt);CHKERRQ(ierr);
@@ -280,18 +287,23 @@ int main(int argc,char **args)
       ierr = MatProductSetAlgorithm(RARt,MATPRODUCTALGORITHM_DEFAULT);CHKERRQ(ierr);
       ierr = MatProductSetFill(RARt,PETSC_DEFAULT);CHKERRQ(ierr);
       ierr = MatProductSetFromOptions(RARt);CHKERRQ(ierr);
-      ierr = MatProductSymbolic(RARt);CHKERRQ(ierr); /* equivalent to MatSetUp() */
-      ierr = MatSetOption(RARt,MAT_USE_INODES,PETSC_FALSE);CHKERRQ(ierr); /* illustrate how to call MatSetOption() */
-      ierr = MatProductNumeric(RARt);CHKERRQ(ierr);
-      ierr = MatProductNumeric(RARt);CHKERRQ(ierr); /* test reuse symbolic RARt */
-      ierr = MatDestroy(&RARt);CHKERRQ(ierr);
+      ierr = MatHasOperation(RARt,MATOP_PRODUCTSYMBOLIC,&flg);CHKERRQ(ierr);
+      if (flg) {
+        ierr = MatProductSymbolic(RARt);CHKERRQ(ierr); /* equivalent to MatSetUp() */
+        ierr = MatSetOption(RARt,MAT_USE_INODES,PETSC_FALSE);CHKERRQ(ierr); /* illustrate how to call MatSetOption() */
+        ierr = MatProductNumeric(RARt);CHKERRQ(ierr);
+        ierr = MatProductNumeric(RARt);CHKERRQ(ierr); /* test reuse symbolic RARt */
+        ierr = MatDestroy(&RARt);CHKERRQ(ierr);
 
-      /* (2.2) Test user driver RARt = R*A*Rt */
-      ierr = MatRARt(A,R,MAT_INITIAL_MATRIX,2.0,&RARt);CHKERRQ(ierr);
-      ierr = MatRARt(A,R,MAT_REUSE_MATRIX,2.0,&RARt);CHKERRQ(ierr);
+        /* (2.2) Test user driver RARt = R*A*Rt */
+        ierr = MatRARt(A,R,MAT_INITIAL_MATRIX,2.0,&RARt);CHKERRQ(ierr);
+        ierr = MatRARt(A,R,MAT_REUSE_MATRIX,2.0,&RARt);CHKERRQ(ierr);
 
-      ierr = MatNormDifference(C,RARt,&norm);CHKERRQ(ierr);
-      if (norm > PETSC_SMALL) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_PLIB,"|PtAP - RARt| = %g",(double)norm);
+        ierr = MatNormDifference(C,RARt,&norm);CHKERRQ(ierr);
+        if (norm > PETSC_SMALL) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_PLIB,"|PtAP - RARt| = %g",(double)norm);
+      } else {
+        ierr = PetscPrintf(PETSC_COMM_WORLD,"MatRARt not supported\n");CHKERRQ(ierr);
+      }
       ierr = MatDestroy(&RARt);CHKERRQ(ierr);
     }
 
@@ -308,171 +320,185 @@ int main(int argc,char **args)
   ierr = MatDestroy(&P);CHKERRQ(ierr);
   ierr = MatDestroy(&R);CHKERRQ(ierr);
 
-  PetscFinalize();
+  ierr = PetscFinalize();
   return ierr;
 }
 
 /*TEST
    test:
      suffix: 1
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium
      output_file: output/ex62_1.out
 
    test:
      suffix: 2_ab_scalable
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via scalable -matmatmult_via scalable -AtB_matproduct_atb_via outerproduct -mattransposematmult_via outerproduct
      output_file: output/ex62_1.out
 
    test:
      suffix: 3_ab_scalable_fast
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via scalable_fast -matmatmult_via scalable_fast -matmattransmult_via color
      output_file: output/ex62_1.out
 
    test:
      suffix: 4_ab_heap
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via heap -matmatmult_via heap -PtAP_matproduct_ptap_via rap -matptap_via rap
      output_file: output/ex62_1.out
 
    test:
      suffix: 5_ab_btheap
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via btheap -matmatmult_via btheap -matrart_via r*art
      output_file: output/ex62_1.out
 
    test:
      suffix: 6_ab_llcondensed
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via llcondensed -matmatmult_via llcondensed -matrart_via coloring_rart
      output_file: output/ex62_1.out
 
    test:
      suffix: 7_ab_rowmerge
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via rowmerge -matmatmult_via rowmerge
      output_file: output/ex62_1.out
 
    test:
      suffix: 8_ab_hypre
-     requires: hypre datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: hypre datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via hypre -matmatmult_via hypre -PtAP_matproduct_ptap_via hypre -matptap_via hypre
      output_file: output/ex62_1.out
 
+   test:
+     suffix: hypre_medium
+     nsize: {{1 3}}
+     requires: hypre datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
+     args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -A_mat_type hypre -B_mat_type hypre -test_rart 0
+     output_file: output/ex62_hypre.out
+
+   test:
+     suffix: hypre_tiny
+     nsize: {{1 3}}
+     requires: hypre !complex double !defined(PETSC_USE_64BIT_INDICES)
+     args: -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -A_mat_type hypre -B_mat_type hypre -test_rart 0
+     output_file: output/ex62_hypre.out
+
    test:
      suffix: 9_mkl
      TODO: broken MatScale?
-     requires: mkl datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: mkl datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -A_mat_type aijmkl -B_mat_type aijmkl
      output_file: output/ex62_1.out
 
    test:
      suffix: 10
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      nsize: 3
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium
      output_file: output/ex62_1.out
 
    test:
      suffix: 10_backend
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      nsize: 3
      args: -fA ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via backend -matmatmult_via backend -AtB_matproduct_atb_via backend -mattransposematmult_via backend -PtAP_matproduct_ptap_via backend -matptap_via backend
      output_file: output/ex62_1.out
 
    test:
      suffix: 11_ab_scalable
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      nsize: 3
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via scalable -matmatmult_via scalable -AtB_matproduct_atb_via scalable -mattransposematmult_via scalable
      output_file: output/ex62_1.out
 
    test:
      suffix: 12_ab_seqmpi
-     requires: datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      nsize: 3
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via seqmpi -matmatmult_via seqmpi -AtB_matproduct_atb_via at*b -mattransposematmult_via at*b
      output_file: output/ex62_1.out
 
    test:
      suffix: 13_ab_hypre
-     requires: hypre datafilespath !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: hypre datafilespath !complex double !defined(PETSC_USE_64BIT_INDICES)
      nsize: 3
      args: -fA ${DATAFILESPATH}/matrices/medium -fB ${DATAFILESPATH}/matrices/medium -AB_matproduct_ab_via hypre -matmatmult_via hypre -PtAP_matproduct_ptap_via hypre -matptap_via hypre
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_seqaij
-     requires: !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_seqaijcusparse
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type aijcusparse -B_mat_type aijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_seqaijcusparse_cpu
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type aijcusparse -B_mat_type aijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -AB_matproduct_ab_backend_cpu -matmatmult_backend_cpu -PtAP_matproduct_ptap_backend_cpu -matptap_backend_cpu -RARt_matproduct_rart_backend_cpu -matrart_backend_cpu
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_mpiaijcusparse_seq
      nsize: 1
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type mpiaijcusparse -B_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_mpiaijcusparse_seq_cpu
      nsize: 1
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type mpiaijcusparse -B_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -AB_matproduct_ab_backend_cpu -matmatmult_backend_cpu -PtAP_matproduct_ptap_backend_cpu -matptap_backend_cpu
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_mpiaijcusparse
      nsize: 3
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type mpiaijcusparse -B_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_mpiaijcusparse_cpu
      nsize: 3
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type mpiaijcusparse -B_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -AB_matproduct_ab_backend_cpu -matmatmult_backend_cpu -PtAP_matproduct_ptap_backend_cpu -matptap_backend_cpu
      output_file: output/ex62_1.out
 
    test:
      suffix: 14_seqaijkokkos
-     requires: kokkos_kernels !complex double !define(PETSC_USE_64BIT_INDICES)
+     requires: kokkos_kernels !complex double !defined(PETSC_USE_64BIT_INDICES)
      args: -A_mat_type aijkokkos -B_mat_type aijkokkos -fA ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system -fB ${wPETSC_DIR}/share/petsc/datafiles/matrices/tiny_system
      output_file: output/ex62_1.out
 
    # these tests use matrices with many zero rows
    test:
      suffix: 15_seqaijcusparse
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES) datafilespath
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES) datafilespath
      args: -A_mat_type aijcusparse -mat_form_explicit_transpose -fA ${DATAFILESPATH}/matrices/matmatmult/A4.BGriffith
      output_file: output/ex62_1.out
 
    test:
      suffix: 15_mpiaijcusparse_seq
      nsize: 1
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES) datafilespath
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES) datafilespath
      args: -A_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${DATAFILESPATH}/matrices/matmatmult/A4.BGriffith
      output_file: output/ex62_1.out
 
    test:
      nsize: 3
      suffix: 15_mpiaijcusparse
-     requires: cuda !complex double !define(PETSC_USE_64BIT_INDICES) datafilespath
+     requires: cuda !complex double !defined(PETSC_USE_64BIT_INDICES) datafilespath
      args: -A_mat_type mpiaijcusparse -mat_form_explicit_transpose -fA ${DATAFILESPATH}/matrices/matmatmult/A4.BGriffith
      output_file: output/ex62_1.out
 
